Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataIndividualDocumentResyncStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Resync status for each document per inconsistency type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataIndividualDocumentResyncStatus

Returns a new instance of GoogleCloudDocumentaiUiv1beta3ResyncDatasetMetadataIndividualDocumentResyncStatus.



2312
2313
2314
# File 'lib/google/apis/documentai_v1/classes.rb', line 2312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_id ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiUiv1beta3DocumentId

Document Identifier. Corresponds to the JSON property documentId



2295
2296
2297
# File 'lib/google/apis/documentai_v1/classes.rb', line 2295

def document_id
  @document_id
end

#document_inconsistency_type ⇒ String

The type of document inconsistency. Corresponds to the JSON property documentInconsistencyType

Returns:

  • (String)


2300
2301
2302
# File 'lib/google/apis/documentai_v1/classes.rb', line 2300

def document_inconsistency_type
  @document_inconsistency_type
end

#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https: //cloud.google.com/apis/design/errors). Corresponds to the JSON property status



2310
2311
2312
# File 'lib/google/apis/documentai_v1/classes.rb', line 2310

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2317
2318
2319
2320
2321
# File 'lib/google/apis/documentai_v1/classes.rb', line 2317

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @document_inconsistency_type = args[:document_inconsistency_type] if args.key?(:document_inconsistency_type)
  @status = args[:status] if args.key?(:status)
end