Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The status of a each individual document in the batch process.
Instance Attribute Summary collapse
-
#human_review_status ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1HumanReviewStatus
The status of human review on a processed document.
-
#input_gcs_source ⇒ String
The source of the document, same as the input_gcs_source field in the request when the batch process started.
-
#output_gcs_destination ⇒ String
The Cloud Storage output destination (in the request as DocumentOutputConfig. GcsOutputConfig.gcs_uri) of the processed document if it was successful, otherwise empty.
-
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
constructor
A new instance of GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus
Returns a new instance of GoogleCloudDocumentaiV1BatchProcessMetadataIndividualProcessStatus.
3020 3021 3022 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#human_review_status ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1HumanReviewStatus
The status of human review on a processed document.
Corresponds to the JSON property humanReviewStatus
2995 2996 2997 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 2995 def human_review_status @human_review_status end |
#input_gcs_source ⇒ String
The source of the document, same as the input_gcs_source field in the request
when the batch process started.
Corresponds to the JSON property inputGcsSource
3001 3002 3003 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3001 def input_gcs_source @input_gcs_source end |
#output_gcs_destination ⇒ String
The Cloud Storage output destination (in the request as DocumentOutputConfig.
GcsOutputConfig.gcs_uri) of the processed document if it was successful,
otherwise empty.
Corresponds to the JSON property outputGcsDestination
3008 3009 3010 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3008 def output_gcs_destination @output_gcs_destination end |
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
3018 3019 3020 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3018 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3025 3026 3027 3028 3029 3030 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3025 def update!(**args) @human_review_status = args[:human_review_status] if args.key?(:human_review_status) @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source) @output_gcs_destination = args[:output_gcs_destination] if args.key?(:output_gcs_destination) @status = args[:status] if args.key?(:status) end |