Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BatchProcessRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Request message for BatchProcessDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1BatchProcessRequest

Returns a new instance of GoogleCloudDocumentaiV1BatchProcessRequest.



3068
3069
3070
# File 'lib/google/apis/documentai_v1/classes.rb', line 3068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_output_configGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentOutputConfig

Config that controls the output of documents. All documents will be written as a JSON file. Corresponds to the JSON property documentOutputConfig



3041
3042
3043
# File 'lib/google/apis/documentai_v1/classes.rb', line 3041

def document_output_config
  @document_output_config
end

#input_documentsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BatchDocumentsInputConfig

The common config to specify a set of documents used as input. Corresponds to the JSON property inputDocuments



3046
3047
3048
# File 'lib/google/apis/documentai_v1/classes.rb', line 3046

def input_documents
  @input_documents
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3055
3056
3057
# File 'lib/google/apis/documentai_v1/classes.rb', line 3055

def labels
  @labels
end

#process_optionsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions

Options for Process API Corresponds to the JSON property processOptions



3060
3061
3062
# File 'lib/google/apis/documentai_v1/classes.rb', line 3060

def process_options
  @process_options
end

#skip_human_reviewBoolean Also known as: skip_human_review?

Whether human review should be skipped for this request. Default to false. Corresponds to the JSON property skipHumanReview

Returns:

  • (Boolean)


3065
3066
3067
# File 'lib/google/apis/documentai_v1/classes.rb', line 3065

def skip_human_review
  @skip_human_review
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3073
3074
3075
3076
3077
3078
3079
# File 'lib/google/apis/documentai_v1/classes.rb', line 3073

def update!(**args)
  @document_output_config = args[:document_output_config] if args.key?(:document_output_config)
  @input_documents = args[:input_documents] if args.key?(:input_documents)
  @labels = args[:labels] if args.key?(:labels)
  @process_options = args[:process_options] if args.key?(:process_options)
  @skip_human_review = args[:skip_human_review] if args.key?(:skip_human_review)
end