Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1Document

Returns a new instance of GoogleCloudDocumentaiV1Document.



3419
3420
3421
# File 'lib/google/apis/documentai_v1/classes.rb', line 3419

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blob_assetsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentBlobAsset>

Optional. The blob assets in this document. This is used to store the content of the inline blobs in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset id. Corresponds to the JSON property blobAssets



3304
3305
3306
# File 'lib/google/apis/documentai_v1/classes.rb', line 3304

def blob_assets
  @blob_assets
end

#chunked_documentGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocument

Represents the chunks that the document is divided into. Corresponds to the JSON property chunkedDocument



3309
3310
3311
# File 'lib/google/apis/documentai_v1/classes.rb', line 3309

def chunked_document
  @chunked_document
end

#contentString

Optional. Inline document content, represented as a stream of bytes. Note: As with all bytes fields, protobuffers use a pure binary representation, whereas JSON representations use base64. Corresponds to the JSON property content NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3317
3318
3319
# File 'lib/google/apis/documentai_v1/classes.rb', line 3317

def content
  @content
end

#docidString

Optional. An internal identifier for document. Should be loggable (no PII). Corresponds to the JSON property docid

Returns:

  • (String)


3322
3323
3324
# File 'lib/google/apis/documentai_v1/classes.rb', line 3322

def docid
  @docid
end

#document_layoutGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayout

Represents the parsed layout of a document as a collection of blocks that the document is divided into. Corresponds to the JSON property documentLayout



3328
3329
3330
# File 'lib/google/apis/documentai_v1/classes.rb', line 3328

def document_layout
  @document_layout
end

#entitiesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntity>

A list of entities detected on Document.text. For document shards, entities in this list may cross shard boundaries. Corresponds to the JSON property entities



3334
3335
3336
# File 'lib/google/apis/documentai_v1/classes.rb', line 3334

def entities
  @entities
end

#entities_revision_idString

The entity revision ID that document.entities field is based on. If this field is set and entities_revisions is not empty, the entities in document. entities field are the entities in the entity revision with this id and document.entity_validation_output field is the entity_validation_output field in this entity revision. Corresponds to the JSON property entitiesRevisionId

Returns:

  • (String)


3343
3344
3345
# File 'lib/google/apis/documentai_v1/classes.rb', line 3343

def entities_revision_id
  @entities_revision_id
end

#entities_revisionsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntitiesRevision>

A list of entity revisions. The entity revisions are appended to the document in the processing order. This field can be used for comparing the entity extraction results at different stages of the processing. Corresponds to the JSON property entitiesRevisions



3350
3351
3352
# File 'lib/google/apis/documentai_v1/classes.rb', line 3350

def entities_revisions
  @entities_revisions
end

#entity_relationsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityRelation>

Placeholder. Relationship among Document.entities. Corresponds to the JSON property entityRelations



3355
3356
3357
# File 'lib/google/apis/documentai_v1/classes.rb', line 3355

def entity_relations
  @entity_relations
end

#entity_validation_outputGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityValidationOutput

The output of the validation given the document and the validation rules. Corresponds to the JSON property entityValidationOutput



3360
3361
3362
# File 'lib/google/apis/documentai_v1/classes.rb', line 3360

def entity_validation_output
  @entity_validation_output
end

#errorGoogle::Apis::DocumentaiV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3370
3371
3372
# File 'lib/google/apis/documentai_v1/classes.rb', line 3370

def error
  @error
end

#mime_typeString

An IANA published media type (MIME type). Corresponds to the JSON property mimeType

Returns:

  • (String)


3376
3377
3378
# File 'lib/google/apis/documentai_v1/classes.rb', line 3376

def mime_type
  @mime_type
end

#pagesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPage>

Visual page layout for the Document. Corresponds to the JSON property pages



3381
3382
3383
# File 'lib/google/apis/documentai_v1/classes.rb', line 3381

def pages
  @pages
end

#revisionsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevision>

Placeholder. Revision history of this document. Corresponds to the JSON property revisions



3386
3387
3388
# File 'lib/google/apis/documentai_v1/classes.rb', line 3386

def revisions
  @revisions
end

#shard_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentShardInfo

For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is. Corresponds to the JSON property shardInfo



3392
3393
3394
# File 'lib/google/apis/documentai_v1/classes.rb', line 3392

def shard_info
  @shard_info
end

#textString

Optional. UTF-8 encoded text in reading order from the document. Corresponds to the JSON property text

Returns:

  • (String)


3397
3398
3399
# File 'lib/google/apis/documentai_v1/classes.rb', line 3397

def text
  @text
end

#text_changesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextChange>

Placeholder. A list of text corrections made to Document.text. This is usually used for annotating corrections to OCR mistakes. Text changes for a given revision may not overlap with each other. Corresponds to the JSON property textChanges



3404
3405
3406
# File 'lib/google/apis/documentai_v1/classes.rb', line 3404

def text_changes
  @text_changes
end

#text_stylesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentStyle>

Styles for the Document.text. Corresponds to the JSON property textStyles



3409
3410
3411
# File 'lib/google/apis/documentai_v1/classes.rb', line 3409

def text_styles
  @text_styles
end

#uriString

Optional. Currently supports Google Cloud Storage URI of the form gs:// bucket_name/object_name. Object versioning is not supported. For more information, refer to Google Cloud Storage Request URIs. Corresponds to the JSON property uri

Returns:

  • (String)


3417
3418
3419
# File 'lib/google/apis/documentai_v1/classes.rb', line 3417

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/google/apis/documentai_v1/classes.rb', line 3424

def update!(**args)
  @blob_assets = args[:blob_assets] if args.key?(:blob_assets)
  @chunked_document = args[:chunked_document] if args.key?(:chunked_document)
  @content = args[:content] if args.key?(:content)
  @docid = args[:docid] if args.key?(:docid)
  @document_layout = args[:document_layout] if args.key?(:document_layout)
  @entities = args[:entities] if args.key?(:entities)
  @entities_revision_id = args[:entities_revision_id] if args.key?(:entities_revision_id)
  @entities_revisions = args[:entities_revisions] if args.key?(:entities_revisions)
  @entity_relations = args[:entity_relations] if args.key?(:entity_relations)
  @entity_validation_output = args[:entity_validation_output] if args.key?(:entity_validation_output)
  @error = args[:error] if args.key?(:error)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @pages = args[:pages] if args.key?(:pages)
  @revisions = args[:revisions] if args.key?(:revisions)
  @shard_info = args[:shard_info] if args.key?(:shard_info)
  @text = args[:text] if args.key?(:text)
  @text_changes = args[:text_changes] if args.key?(:text_changes)
  @text_styles = args[:text_styles] if args.key?(:text_styles)
  @uri = args[:uri] if args.key?(:uri)
end