Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Represents a chunk.
Instance Attribute Summary collapse
-
#chunk_fields ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkField>
Chunk fields inside this chunk.
-
#chunk_id ⇒ String
ID of the chunk.
-
#content ⇒ String
Text content of the chunk.
-
#page_footers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter>
Page footers associated with the chunk.
-
#page_headers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader>
Page headers associated with the chunk.
-
#page_span ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#source_block_ids ⇒ Array<String>
Unused.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
constructor
A new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
Returns a new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk.
3559 3560 3561 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_fields ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkField>
Chunk fields inside this chunk.
Corresponds to the JSON property chunkFields
3527 3528 3529 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3527 def chunk_fields @chunk_fields end |
#chunk_id ⇒ String
ID of the chunk.
Corresponds to the JSON property chunkId
3532 3533 3534 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3532 def chunk_id @chunk_id end |
#content ⇒ String
Text content of the chunk.
Corresponds to the JSON property content
3537 3538 3539 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3537 def content @content end |
#page_footers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter>
Page footers associated with the chunk.
Corresponds to the JSON property pageFooters
3542 3543 3544 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3542 def @page_footers end |
#page_headers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader>
Page headers associated with the chunk.
Corresponds to the JSON property pageHeaders
3547 3548 3549 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3547 def page_headers @page_headers end |
#page_span ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
3552 3553 3554 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3552 def page_span @page_span end |
#source_block_ids ⇒ Array<String>
Unused.
Corresponds to the JSON property sourceBlockIds
3557 3558 3559 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3557 def source_block_ids @source_block_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3564 3565 3566 3567 3568 3569 3570 3571 3572 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3564 def update!(**args) @chunk_fields = args[:chunk_fields] if args.key?(:chunk_fields) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) @content = args[:content] if args.key?(:content) @page_footers = args[:page_footers] if args.key?(:page_footers) @page_headers = args[:page_headers] if args.key?(:page_headers) @page_span = args[:page_span] if args.key?(:page_span) @source_block_ids = args[:source_block_ids] if args.key?(:source_block_ids) end |