Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The table chunk field in the chunk.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentAnnotations
Represents the annotation of a block or a chunk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField
constructor
A new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField
Returns a new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField.
3725 3726 3727 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentAnnotations
Represents the annotation of a block or a chunk.
Corresponds to the JSON property annotations
3723 3724 3725 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3723 def annotations @annotations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3730 3731 3732 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3730 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) end |