Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Represents an image type block.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock

Returns a new instance of GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock.



3849
3850
3851
# File 'lib/google/apis/documentai_v1/classes.rb', line 3849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentAnnotations

Represents the annotation of a block or a chunk. Corresponds to the JSON property annotations



3818
3819
3820
# File 'lib/google/apis/documentai_v1/classes.rb', line 3818

def annotations
  @annotations
end

#blob_asset_idString

Optional. Asset id of the inline image. If set, find the image content in the blob_assets field. Corresponds to the JSON property blobAssetId

Returns:

  • (String)


3824
3825
3826
# File 'lib/google/apis/documentai_v1/classes.rb', line 3824

def blob_asset_id
  @blob_asset_id
end

#data_uriString

Optional. Data uri of the image. It is composed of four parts: a prefix (data:) , a MIME type indicating the type of data, an optional base64 token if non- textual, and the data itself: data:, Corresponds to the JSON property dataUri

Returns:

  • (String)


3831
3832
3833
# File 'lib/google/apis/documentai_v1/classes.rb', line 3831

def data_uri
  @data_uri
end

#gcs_uriString

Optional. Google Cloud Storage uri of the image. Corresponds to the JSON property gcsUri

Returns:

  • (String)


3836
3837
3838
# File 'lib/google/apis/documentai_v1/classes.rb', line 3836

def gcs_uri
  @gcs_uri
end

#image_textString

Text extracted from the image using OCR or alt text describing the image. Corresponds to the JSON property imageText

Returns:

  • (String)


3841
3842
3843
# File 'lib/google/apis/documentai_v1/classes.rb', line 3841

def image_text
  @image_text
end

#mime_typeString

Mime type of the image. An IANA published media type (MIME type). Corresponds to the JSON property mimeType

Returns:

  • (String)


3847
3848
3849
# File 'lib/google/apis/documentai_v1/classes.rb', line 3847

def mime_type
  @mime_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3854
3855
3856
3857
3858
3859
3860
3861
# File 'lib/google/apis/documentai_v1/classes.rb', line 3854

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @blob_asset_id = args[:blob_asset_id] if args.key?(:blob_asset_id)
  @data_uri = args[:data_uri] if args.key?(:data_uri)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @image_text = args[:image_text] if args.key?(:image_text)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
end