Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntity
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
An entity that could be a phrase in the text or a property that belongs to the document. It is a known entity type, such as a person, an organization, or location.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Optional.
-
#id ⇒ String
Optional.
-
#mention_id ⇒ String
Optional.
-
#mention_text ⇒ String
Optional.
-
#method_prop ⇒ String
Optional.
-
#normalized_value ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
Parsed and normalized entity value.
-
#page_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageAnchor
Referencing the visual context of the entity in the Document.pages.
-
#properties ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntity>
Optional.
-
#provenance ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
-
#redacted ⇒ Boolean
(also: #redacted?)
Optional.
-
#text_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntity
constructor
A new instance of GoogleCloudDocumentaiV1DocumentEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntity
Returns a new instance of GoogleCloudDocumentaiV1DocumentEntity.
4173 4174 4175 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Optional. Confidence of detected Schema entity. Range [0, 1].
Corresponds to the JSON property confidence
4110 4111 4112 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4110 def confidence @confidence end |
#id ⇒ String
Optional. Canonical id. This will be a unique value in the entity list for
this document.
Corresponds to the JSON property id
4116 4117 4118 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4116 def id @id end |
#mention_id ⇒ String
Optional. Deprecated. Use id field instead.
Corresponds to the JSON property mentionId
4121 4122 4123 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4121 def mention_id @mention_id end |
#mention_text ⇒ String
Optional. Text value of the entity, for example, 1600 Amphitheatre Pkwy.
Corresponds to the JSON property mentionText
4126 4127 4128 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4126 def mention_text @mention_text end |
#method_prop ⇒ String
Optional. Specifies how the entity's value is obtained.
Corresponds to the JSON property method
4131 4132 4133 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4131 def method_prop @method_prop end |
#normalized_value ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
Parsed and normalized entity value.
Corresponds to the JSON property normalizedValue
4136 4137 4138 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4136 def normalized_value @normalized_value end |
#page_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageAnchor
Referencing the visual context of the entity in the Document.pages. Page
anchors can be cross-page, consist of multiple bounding polygons and
optionally reference specific layout element types.
Corresponds to the JSON property pageAnchor
4143 4144 4145 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4143 def page_anchor @page_anchor end |
#properties ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntity>
Optional. Entities can be nested to form a hierarchical data structure
representing the content in the document.
Corresponds to the JSON property properties
4149 4150 4151 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4149 def properties @properties end |
#provenance ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
4155 4156 4157 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4155 def provenance @provenance end |
#redacted ⇒ Boolean Also known as: redacted?
Optional. Whether the entity will be redacted for de-identification purposes.
Corresponds to the JSON property redacted
4160 4161 4162 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4160 def redacted @redacted end |
#text_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
Corresponds to the JSON property textAnchor
4166 4167 4168 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4166 def text_anchor @text_anchor end |
#type ⇒ String
Required. Entity type from a schema, for example, Address.
Corresponds to the JSON property type
4171 4172 4173 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4171 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4178 4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4178 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @id = args[:id] if args.key?(:id) @mention_id = args[:mention_id] if args.key?(:mention_id) @mention_text = args[:mention_text] if args.key?(:mention_text) @method_prop = args[:method_prop] if args.key?(:method_prop) @normalized_value = args[:normalized_value] if args.key?(:normalized_value) @page_anchor = args[:page_anchor] if args.key?(:page_anchor) @properties = args[:properties] if args.key?(:properties) @provenance = args[:provenance] if args.key?(:provenance) @redacted = args[:redacted] if args.key?(:redacted) @text_anchor = args[:text_anchor] if args.key?(:text_anchor) @type = args[:type] if args.key?(:type) end |