Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Validation result for a single validation rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult

Returns a new instance of GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult.



4389
4390
4391
# File 'lib/google/apis/documentai_v1/classes.rb', line 4389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ruleString

Optional. The name of the rule resource that is used for validation. Format: projects/project/locations/location/rules/rule` Corresponds to the JSON propertyrule`

Returns:

  • (String)


4366
4367
4368
# File 'lib/google/apis/documentai_v1/classes.rb', line 4366

def rule
  @rule
end

#rule_descriptionString

The description of the validation rule. Corresponds to the JSON property ruleDescription

Returns:

  • (String)


4371
4372
4373
# File 'lib/google/apis/documentai_v1/classes.rb', line 4371

def rule_description
  @rule_description
end

#rule_nameString

The display name of the validation rule. Corresponds to the JSON property ruleName

Returns:

  • (String)


4376
4377
4378
# File 'lib/google/apis/documentai_v1/classes.rb', line 4376

def rule_name
  @rule_name
end

#validation_detailsString

The detailed information of the running the validation process using the entity from the document based on the validation rule. Corresponds to the JSON property validationDetails

Returns:

  • (String)


4382
4383
4384
# File 'lib/google/apis/documentai_v1/classes.rb', line 4382

def validation_details
  @validation_details
end

#validation_result_typeString

The result of the validation rule. Corresponds to the JSON property validationResultType

Returns:

  • (String)


4387
4388
4389
# File 'lib/google/apis/documentai_v1/classes.rb', line 4387

def validation_result_type
  @validation_result_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4394
4395
4396
4397
4398
4399
4400
# File 'lib/google/apis/documentai_v1/classes.rb', line 4394

def update!(**args)
  @rule = args[:rule] if args.key?(:rule)
  @rule_description = args[:rule_description] if args.key?(:rule_description)
  @rule_name = args[:rule_name] if args.key?(:rule_name)
  @validation_details = args[:validation_details] if args.key?(:validation_details)
  @validation_result_type = args[:validation_result_type] if args.key?(:validation_result_type)
end