Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageBlock

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A block has a set of lines (collected into paragraphs) that have a common line- spacing and orientation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageBlock

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageBlock.



4468
4469
4470
# File 'lib/google/apis/documentai_v1/classes.rb', line 4468

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_languagesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



4455
4456
4457
# File 'lib/google/apis/documentai_v1/classes.rb', line 4455

def detected_languages
  @detected_languages
end

#layoutGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



4460
4461
4462
# File 'lib/google/apis/documentai_v1/classes.rb', line 4460

def layout
  @layout
end

#provenanceGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



4466
4467
4468
# File 'lib/google/apis/documentai_v1/classes.rb', line 4466

def provenance
  @provenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4473
4474
4475
4476
4477
# File 'lib/google/apis/documentai_v1/classes.rb', line 4473

def update!(**args)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
end