Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Visual element describing a layout unit on a page.
Instance Attribute Summary collapse
-
#bounding_poly ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BoundingPoly
A bounding polygon for the detected image annotation.
-
#confidence ⇒ Float
Confidence of the current Layout within context of the object this layout is for.
-
#orientation ⇒ String
Detected orientation for the Layout.
-
#text_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageLayout
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageLayout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageLayout
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageLayout.
4973 4974 4975 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_poly ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingPoly
4954 4955 4956 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4954 def bounding_poly @bounding_poly end |
#confidence ⇒ Float
Confidence of the current Layout within context of the object this layout is
for. For example, confidence can be for a single token, a table, a visual
element, etc. depending on context. Range [0, 1].
Corresponds to the JSON property confidence
4961 4962 4963 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4961 def confidence @confidence end |
#orientation ⇒ String
Detected orientation for the Layout.
Corresponds to the JSON property orientation
4966 4967 4968 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4966 def orientation @orientation end |
#text_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
Corresponds to the JSON property textAnchor
4971 4972 4973 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4971 def text_anchor @text_anchor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4978 4979 4980 4981 4982 4983 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4978 def update!(**args) @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly) @confidence = args[:confidence] if args.key?(:confidence) @orientation = args[:orientation] if args.key?(:orientation) @text_anchor = args[:text_anchor] if args.key?(:text_anchor) end |