Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageParagraph

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A collection of lines that a human would perceive as a paragraph.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageParagraph

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageParagraph.



5081
5082
5083
# File 'lib/google/apis/documentai_v1/classes.rb', line 5081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_languagesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5068
5069
5070
# File 'lib/google/apis/documentai_v1/classes.rb', line 5068

def detected_languages
  @detected_languages
end

#layoutGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5073
5074
5075
# File 'lib/google/apis/documentai_v1/classes.rb', line 5073

def layout
  @layout
end

#provenanceGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5079
5080
5081
# File 'lib/google/apis/documentai_v1/classes.rb', line 5079

def provenance
  @provenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5086
5087
5088
5089
5090
# File 'lib/google/apis/documentai_v1/classes.rb', line 5086

def update!(**args)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
end