Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A table representation similar to HTML table structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageTable

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageTable.



5148
5149
5150
# File 'lib/google/apis/documentai_v1/classes.rb', line 5148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#body_rowsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageTableTableRow>

Body rows of the table. Corresponds to the JSON property bodyRows



5125
5126
5127
# File 'lib/google/apis/documentai_v1/classes.rb', line 5125

def body_rows
  @body_rows
end

#detected_languagesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5130
5131
5132
# File 'lib/google/apis/documentai_v1/classes.rb', line 5130

def detected_languages
  @detected_languages
end

#header_rowsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageTableTableRow>

Header rows of the table. Corresponds to the JSON property headerRows



5135
5136
5137
# File 'lib/google/apis/documentai_v1/classes.rb', line 5135

def header_rows
  @header_rows
end

#layoutGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5140
5141
5142
# File 'lib/google/apis/documentai_v1/classes.rb', line 5140

def layout
  @layout
end

#provenanceGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5146
5147
5148
# File 'lib/google/apis/documentai_v1/classes.rb', line 5146

def provenance
  @provenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5153
5154
5155
5156
5157
5158
5159
# File 'lib/google/apis/documentai_v1/classes.rb', line 5153

def update!(**args)
  @body_rows = args[:body_rows] if args.key?(:body_rows)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @header_rows = args[:header_rows] if args.key?(:header_rows)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
end