Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A detected token.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageToken

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageToken.



5024
5025
5026
# File 'lib/google/apis/documentai_v1/classes.rb', line 5024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detected_breakGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageTokenDetectedBreak

Detected break at the end of a Token. Corresponds to the JSON property detectedBreak



5001
5002
5003
# File 'lib/google/apis/documentai_v1/classes.rb', line 5001

def detected_break
  @detected_break
end

#detected_languagesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>

A list of detected languages together with confidence. Corresponds to the JSON property detectedLanguages



5006
5007
5008
# File 'lib/google/apis/documentai_v1/classes.rb', line 5006

def detected_languages
  @detected_languages
end

#layoutGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout

Visual element describing a layout unit on a page. Corresponds to the JSON property layout



5011
5012
5013
# File 'lib/google/apis/documentai_v1/classes.rb', line 5011

def layout
  @layout
end

#provenanceGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance

Structure to identify provenance relationships between annotations in different revisions. Corresponds to the JSON property provenance



5017
5018
5019
# File 'lib/google/apis/documentai_v1/classes.rb', line 5017

def provenance
  @provenance
end

#style_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageTokenStyleInfo

Font and other text style attributes. Corresponds to the JSON property styleInfo



5022
5023
5024
# File 'lib/google/apis/documentai_v1/classes.rb', line 5022

def style_info
  @style_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5029
5030
5031
5032
5033
5034
5035
# File 'lib/google/apis/documentai_v1/classes.rb', line 5029

def update!(**args)
  @detected_break = args[:detected_break] if args.key?(:detected_break)
  @detected_languages = args[:detected_languages] if args.key?(:detected_languages)
  @layout = args[:layout] if args.key?(:layout)
  @provenance = args[:provenance] if args.key?(:provenance)
  @style_info = args[:style_info] if args.key?(:style_info)
end