Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Contains past or forward revisions of this document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentRevision

Returns a new instance of GoogleCloudDocumentaiV1DocumentRevision.



5630
5631
5632
# File 'lib/google/apis/documentai_v1/classes.rb', line 5630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

If the change was made by a person specify the name or id of that person. Corresponds to the JSON property agent

Returns:

  • (String)


5591
5592
5593
# File 'lib/google/apis/documentai_v1/classes.rb', line 5591

def agent
  @agent
end

#create_timeString

The time that the revision was created, internally generated by doc proto storage at the time of create. Corresponds to the JSON property createTime

Returns:

  • (String)


5597
5598
5599
# File 'lib/google/apis/documentai_v1/classes.rb', line 5597

def create_time
  @create_time
end

#human_reviewGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview

Human Review information of the document. Corresponds to the JSON property humanReview



5602
5603
5604
# File 'lib/google/apis/documentai_v1/classes.rb', line 5602

def human_review
  @human_review
end

#idString

Id of the revision, internally generated by doc proto storage. Unique within the context of the document. Corresponds to the JSON property id

Returns:

  • (String)


5608
5609
5610
# File 'lib/google/apis/documentai_v1/classes.rb', line 5608

def id
  @id
end

#parentArray<Fixnum>

The revisions that this revision is based on. This can include one or more parent (when documents are merged.) This field represents the index into the revisions field. Corresponds to the JSON property parent

Returns:

  • (Array<Fixnum>)


5615
5616
5617
# File 'lib/google/apis/documentai_v1/classes.rb', line 5615

def parent
  @parent
end

#parent_idsArray<String>

The revisions that this revision is based on. Must include all the ids that have anything to do with this revision - eg. there are provenance.parent. revision fields that index into this field. Corresponds to the JSON property parentIds

Returns:

  • (Array<String>)


5622
5623
5624
# File 'lib/google/apis/documentai_v1/classes.rb', line 5622

def parent_ids
  @parent_ids
end

#processorString

If the annotation was made by processor identify the processor by its resource name. Corresponds to the JSON property processor

Returns:

  • (String)


5628
5629
5630
# File 'lib/google/apis/documentai_v1/classes.rb', line 5628

def processor
  @processor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5635
5636
5637
5638
5639
5640
5641
5642
5643
# File 'lib/google/apis/documentai_v1/classes.rb', line 5635

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
  @create_time = args[:create_time] if args.key?(:create_time)
  @human_review = args[:human_review] if args.key?(:human_review)
  @id = args[:id] if args.key?(:id)
  @parent = args[:parent] if args.key?(:parent)
  @parent_ids = args[:parent_ids] if args.key?(:parent_ids)
  @processor = args[:processor] if args.key?(:processor)
end