Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Human Review information of the document.
Instance Attribute Summary collapse
-
#state ⇒ String
Human review state.
-
#state_message ⇒ String
A message providing more details about the current state of processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentRevisionHumanReview
constructor
A new instance of GoogleCloudDocumentaiV1DocumentRevisionHumanReview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentRevisionHumanReview
Returns a new instance of GoogleCloudDocumentaiV1DocumentRevisionHumanReview.
5437 5438 5439 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5437 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state ⇒ String
Human review state. For example, requested, succeeded, rejected.
Corresponds to the JSON property state
5429 5430 5431 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5429 def state @state end |
#state_message ⇒ String
A message providing more details about the current state of processing. For
example, the rejection reason when the state is rejected.
Corresponds to the JSON property stateMessage
5435 5436 5437 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5435 def @state_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5442 5443 5444 5445 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5442 def update!(**args) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) end |