Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

EntityType is the wrapper of a label of the corresponding model with detailed attributes and limitations for entity-based processors. Multiple types can also compose a dependency tree to represent nested types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentSchemaEntityType

Returns a new instance of GoogleCloudDocumentaiV1DocumentSchemaEntityType.



5532
5533
5534
# File 'lib/google/apis/documentai_v1/classes.rb', line 5532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_typesArray<String>

The entity type that this type is derived from. For now, one and only one should be set. Corresponds to the JSON property baseTypes

Returns:

  • (Array<String>)


5503
5504
5505
# File 'lib/google/apis/documentai_v1/classes.rb', line 5503

def base_types
  @base_types
end

#display_nameString

User defined name for the type. Corresponds to the JSON property displayName

Returns:

  • (String)


5508
5509
5510
# File 'lib/google/apis/documentai_v1/classes.rb', line 5508

def display_name
  @display_name
end

#enum_valuesGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityTypeEnumValues

Defines the a list of enum values. Corresponds to the JSON property enumValues



5513
5514
5515
# File 'lib/google/apis/documentai_v1/classes.rb', line 5513

def enum_values
  @enum_values
end

#nameString

Name of the type. It must be unique within the schema file and cannot be a " Common Type". The following naming conventions are used: - Use snake_casing.

  • Name matching is case-sensitive. - Maximum 64 characters. - Must start with a letter. - Allowed characters: ASCII letters [a-z0-9_-]. (For backward compatibility, internal infrastructure and tooling can handle any ASCII character.) - The / is sometimes used to denote a property of a type. For example line_item/amount. This convention is deprecated, but will still be honored for backward compatibility. Corresponds to the JSON property name

Returns:

  • (String)


5525
5526
5527
# File 'lib/google/apis/documentai_v1/classes.rb', line 5525

def name
  @name
end

#propertiesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty>

Description the nested structure, or composition of an entity. Corresponds to the JSON property properties



5530
5531
5532
# File 'lib/google/apis/documentai_v1/classes.rb', line 5530

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5537
5538
5539
5540
5541
5542
5543
# File 'lib/google/apis/documentai_v1/classes.rb', line 5537

def update!(**args)
  @base_types = args[:base_types] if args.key?(:base_types)
  @display_name = args[:display_name] if args.key?(:display_name)
  @enum_values = args[:enum_values] if args.key?(:enum_values)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end