Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Defines properties that can be part of the entity type.
Instance Attribute Summary collapse
-
#display_name ⇒ String
User defined name for the property.
-
#method_prop ⇒ String
Specifies how the entity's value is obtained.
-
#name ⇒ String
The name of the property.
-
#occurrence_type ⇒ String
Occurrence type limits the number of instances an entity type appears in the document.
-
#value_type ⇒ String
A reference to the value type of the property.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
constructor
A new instance of GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
Returns a new instance of GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty.
5820 5821 5822 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5820 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
User defined name for the property.
Corresponds to the JSON property displayName
5796 5797 5798 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5796 def display_name @display_name end |
#method_prop ⇒ String
Specifies how the entity's value is obtained.
Corresponds to the JSON property method
5801 5802 5803 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5801 def method_prop @method_prop end |
#name ⇒ String
The name of the property. Follows the same guidelines as the EntityType name.
Corresponds to the JSON property name
5806 5807 5808 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5806 def name @name end |
#occurrence_type ⇒ String
Occurrence type limits the number of instances an entity type appears in the
document.
Corresponds to the JSON property occurrenceType
5812 5813 5814 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5812 def occurrence_type @occurrence_type end |
#value_type ⇒ String
A reference to the value type of the property. This type is subject to the
same conventions as the Entity.base_types field.
Corresponds to the JSON property valueType
5818 5819 5820 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5818 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5825 5826 5827 5828 5829 5830 5831 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5825 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @method_prop = args[:method_prop] if args.key?(:method_prop) @name = args[:name] if args.key?(:name) @occurrence_type = args[:occurrence_type] if args.key?(:occurrence_type) @value_type = args[:value_type] if args.key?(:value_type) end |