Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentShardInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentShardInfo

Returns a new instance of GoogleCloudDocumentaiV1DocumentShardInfo.



5906
5907
5908
# File 'lib/google/apis/documentai_v1/classes.rb', line 5906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_offsetFixnum

The index of the first page in Document.pages in the overall document global pages. Available for document shards created by the document splitter. Corresponds to the JSON property pageOffset

Returns:

  • (Fixnum)


5888
5889
5890
# File 'lib/google/apis/documentai_v1/classes.rb', line 5888

def page_offset
  @page_offset
end

#shard_countFixnum

Total number of shards. Corresponds to the JSON property shardCount

Returns:

  • (Fixnum)


5893
5894
5895
# File 'lib/google/apis/documentai_v1/classes.rb', line 5893

def shard_count
  @shard_count
end

#shard_indexFixnum

The 0-based index of this shard. Corresponds to the JSON property shardIndex

Returns:

  • (Fixnum)


5898
5899
5900
# File 'lib/google/apis/documentai_v1/classes.rb', line 5898

def shard_index
  @shard_index
end

#text_offsetFixnum

The index of the first character in Document.text in the overall document global text. Corresponds to the JSON property textOffset

Returns:

  • (Fixnum)


5904
5905
5906
# File 'lib/google/apis/documentai_v1/classes.rb', line 5904

def text_offset
  @text_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5911
5912
5913
5914
5915
5916
# File 'lib/google/apis/documentai_v1/classes.rb', line 5911

def update!(**args)
  @page_offset = args[:page_offset] if args.key?(:page_offset)
  @shard_count = args[:shard_count] if args.key?(:shard_count)
  @shard_index = args[:shard_index] if args.key?(:shard_index)
  @text_offset = args[:text_offset] if args.key?(:text_offset)
end