Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentStyle
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentStyle
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Annotation for common text style attributes. This adheres to CSS conventions as much as possible.
Instance Attribute Summary collapse
-
#background_color ⇒ Google::Apis::DocumentaiV1::GoogleTypeColor
Represents a color in the RGBA color space.
-
#color ⇒ Google::Apis::DocumentaiV1::GoogleTypeColor
Represents a color in the RGBA color space.
-
#font_family ⇒ String
Font family such as
Arial,Times New Roman. -
#font_size ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentStyleFontSize
Font size with unit.
- #font_weight ⇒ String
-
#text_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
- #text_decoration ⇒ String
- #text_style ⇒ String
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentStyle
constructor
A new instance of GoogleCloudDocumentaiV1DocumentStyle.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentStyle
Returns a new instance of GoogleCloudDocumentaiV1DocumentStyle.
6056 6057 6058 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_color ⇒ Google::Apis::DocumentaiV1::GoogleTypeColor
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property backgroundColor
5971 5972 5973 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5971 def background_color @background_color end |
#color ⇒ Google::Apis::DocumentaiV1::GoogleTypeColor
Represents a color in the RGBA color space. This representation is designed
for simplicity of conversion to and from color representations in various
languages over compactness. For example, the fields of this representation can
be trivially provided to the constructor of java.awt.Color in Java; it can
also be trivially provided to UIColor's +colorWithRed:green:blue:alpha
method in iOS; and, with just a little work, it can be easily formatted into a
CSS rgba() string in JavaScript. This reference page doesn't have
information about the absolute color space that should be used to interpret
the RGB value—for example, sRGB, Adobe RGB, DCI-P3, and BT.2020. By default,
applications should assume the sRGB color space. When color equality needs to
be decided, implementations, unless documented otherwise, treat two colors as
equal if all their red, green, blue, and alpha values each differ by at most
1e-5. Example (Java): import com.google.type.Color; // ... public static java.
awt.Color fromProto(Color protocolor) float alpha = protocolor.hasAlpha() ?
protocolor.getAlpha().getValue() : 1.0; return new java.awt.Color( protocolor.
getRed(), protocolor.getGreen(), protocolor.getBlue(), alpha); public static
Color toProto(java.awt.Color color) float red = (float) color.getRed();
float green = (float) color.getGreen(); float blue = (float) color.getBlue();
float denominator = 255.0; Color.Builder resultBuilder = Color .newBuilder() .
setRed(red / denominator) .setGreen(green / denominator) .setBlue(blue /
denominator); int alpha = color.getAlpha(); if (alpha != 255) result.
setAlpha( FloatValue .newBuilder() .setValue(((float) alpha) / denominator) .
build()); return resultBuilder.build(); // ... Example (iOS / Obj-C): // ..
. static UIColor* fromProto(Color* protocolor) float red = [protocolor red];
float green = [protocolor green]; float blue = [protocolor blue]; FloatValue*
alpha_wrapper = [protocolor alpha]; float alpha = 1.0; if (alpha_wrapper !=
nil) alpha = [alpha_wrapper value]; return [UIColor colorWithRed:red green:
green blue:blue alpha:alpha]; static Color* toProto(UIColor* color)
CGFloat red, green, blue, alpha; if (![color getRed:&red green:&green blue:&
blue alpha:&alpha]) return nil; Color* result = [[Color alloc] init]; [
result setRed:red]; [result setGreen:green]; [result setBlue:blue]; if (alpha <
= 0.9999) [result setAlpha:floatWrapperWithValue(alpha)]; [result
autorelease]; return result; // ... Example (JavaScript): // ... var
protoToCssColor = function(rgb_color) var redFrac = rgb_color.red || 0.0;
var greenFrac = rgb_color.green || 0.0; var blueFrac = rgb_color.blue || 0.0;
var red = Math.floor(redFrac * 255); var green = Math.floor(greenFrac * 255);
var blue = Math.floor(blueFrac * 255); if (!('alpha' in rgb_color)) return
rgbToCssColor(red, green, blue); var alphaFrac = rgb_color.alpha.value || 0.
0; var rgbParams = [red, green, blue].join(','); return ['rgba(', rgbParams, ',
', alphaFrac, ')'].join('');; var rgbToCssColor = function(red, green, blue)
var rgbNumber = new Number((red << 16) | (green << 8) | blue); var hexString
= rgbNumber.toString(16); var missingZeros = 6 - hexString.length; var
resultBuilder = ['#']; for (var i = 0; i < missingZeros; i++) resultBuilder.
push('0'); resultBuilder.push(hexString); return resultBuilder.join('');; /
/ ...
Corresponds to the JSON property color
6020 6021 6022 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6020 def color @color end |
#font_family ⇒ String
Font family such as Arial, Times New Roman. https://www.w3schools.com/
cssref/pr_font_font-family.asp
Corresponds to the JSON property fontFamily
6026 6027 6028 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6026 def font_family @font_family end |
#font_size ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentStyleFontSize
Font size with unit.
Corresponds to the JSON property fontSize
6031 6032 6033 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6031 def font_size @font_size end |
#font_weight ⇒ String
Font weight. Possible
values are normal, bold, bolder, and lighter.
Corresponds to the JSON property fontWeight
6037 6038 6039 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6037 def font_weight @font_weight end |
#text_anchor ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextAnchor
Text reference indexing into the Document.text.
Corresponds to the JSON property textAnchor
6042 6043 6044 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6042 def text_anchor @text_anchor end |
#text_decoration ⇒ String
Text decoration
. Follows CSS standard.
Corresponds to the JSON property textDecoration
6048 6049 6050 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6048 def text_decoration @text_decoration end |
#text_style ⇒ String
Text style.
Possible values are normal, italic, and oblique.
Corresponds to the JSON property textStyle
6054 6055 6056 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6054 def text_style @text_style end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6061 6062 6063 6064 6065 6066 6067 6068 6069 6070 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6061 def update!(**args) @background_color = args[:background_color] if args.key?(:background_color) @color = args[:color] if args.key?(:color) @font_family = args[:font_family] if args.key?(:font_family) @font_size = args[:font_size] if args.key?(:font_size) @font_weight = args[:font_weight] if args.key?(:font_weight) @text_anchor = args[:text_anchor] if args.key?(:text_anchor) @text_decoration = args[:text_decoration] if args.key?(:text_decoration) @text_style = args[:text_style] if args.key?(:text_style) end |