Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A text segment in the Document.text. The indices may be out of bounds which indicate that the text extends into another document shard for large sharded documents. See ShardInfo.text_offset

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment

Returns a new instance of GoogleCloudDocumentaiV1DocumentTextAnchorTextSegment.



5900
5901
5902
# File 'lib/google/apis/documentai_v1/classes.rb', line 5900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_indexFixnum

TextSegment half open end UTF-8 char index in the Document.text. Corresponds to the JSON property endIndex

Returns:

  • (Fixnum)


5893
5894
5895
# File 'lib/google/apis/documentai_v1/classes.rb', line 5893

def end_index
  @end_index
end

#start_indexFixnum

TextSegment start UTF-8 char index in the Document.text. Corresponds to the JSON property startIndex

Returns:

  • (Fixnum)


5898
5899
5900
# File 'lib/google/apis/documentai_v1/classes.rb', line 5898

def start_index
  @start_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5905
5906
5907
5908
# File 'lib/google/apis/documentai_v1/classes.rb', line 5905

def update!(**args)
  @end_index = args[:end_index] if args.key?(:end_index)
  @start_index = args[:start_index] if args.key?(:start_index)
end