Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Evaluates the given ProcessorVersion against the supplied documents.
Instance Attribute Summary collapse
-
#evaluation_documents ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BatchDocumentsInputConfig
The common config to specify a set of documents used as input.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest
constructor
A new instance of GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest
Returns a new instance of GoogleCloudDocumentaiV1EvaluateProcessorVersionRequest.
6035 6036 6037 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_documents ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BatchDocumentsInputConfig
The common config to specify a set of documents used as input.
Corresponds to the JSON property evaluationDocuments
6033 6034 6035 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6033 def evaluation_documents @evaluation_documents end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6040 6041 6042 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6040 def update!(**args) @evaluation_documents = args[:evaluation_documents] if args.key?(:evaluation_documents) end |