Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Metrics across multiple confidence levels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics

Returns a new instance of GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics.



6589
6590
6591
# File 'lib/google/apis/documentai_v1/classes.rb', line 6589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auprcFloat

The calculated area under the precision recall curve (AUPRC), computed by integrating over all confidence thresholds. Corresponds to the JSON property auprc

Returns:

  • (Float)


6555
6556
6557
# File 'lib/google/apis/documentai_v1/classes.rb', line 6555

def auprc
  @auprc
end

#auprc_exactFloat

The AUPRC for metrics with fuzzy matching disabled, i.e., exact matching only. Corresponds to the JSON property auprcExact

Returns:

  • (Float)


6560
6561
6562
# File 'lib/google/apis/documentai_v1/classes.rb', line 6560

def auprc_exact
  @auprc_exact
end

#confidence_level_metricsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics>

Metrics across confidence levels with fuzzy matching enabled. Corresponds to the JSON property confidenceLevelMetrics



6565
6566
6567
# File 'lib/google/apis/documentai_v1/classes.rb', line 6565

def confidence_level_metrics
  @confidence_level_metrics
end

#confidence_level_metrics_exactArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics>

Metrics across confidence levels with only exact matching. Corresponds to the JSON property confidenceLevelMetricsExact



6570
6571
6572
# File 'lib/google/apis/documentai_v1/classes.rb', line 6570

def confidence_level_metrics_exact
  @confidence_level_metrics_exact
end

#estimated_calibration_errorFloat

The Estimated Calibration Error (ECE) of the confidence of the predicted entities. Corresponds to the JSON property estimatedCalibrationError

Returns:

  • (Float)


6576
6577
6578
# File 'lib/google/apis/documentai_v1/classes.rb', line 6576

def estimated_calibration_error
  @estimated_calibration_error
end

#estimated_calibration_error_exactFloat

The ECE for the predicted entities with fuzzy matching disabled, i.e., exact matching only. Corresponds to the JSON property estimatedCalibrationErrorExact

Returns:

  • (Float)


6582
6583
6584
# File 'lib/google/apis/documentai_v1/classes.rb', line 6582

def estimated_calibration_error_exact
  @estimated_calibration_error_exact
end

#metrics_typeString

The metrics type for the label. Corresponds to the JSON property metricsType

Returns:

  • (String)


6587
6588
6589
# File 'lib/google/apis/documentai_v1/classes.rb', line 6587

def metrics_type
  @metrics_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6594
6595
6596
6597
6598
6599
6600
6601
6602
# File 'lib/google/apis/documentai_v1/classes.rb', line 6594

def update!(**args)
  @auprc = args[:auprc] if args.key?(:auprc)
  @auprc_exact = args[:auprc_exact] if args.key?(:auprc_exact)
  @confidence_level_metrics = args[:confidence_level_metrics] if args.key?(:confidence_level_metrics)
  @confidence_level_metrics_exact = args[:confidence_level_metrics_exact] if args.key?(:confidence_level_metrics_exact)
  @estimated_calibration_error = args[:estimated_calibration_error] if args.key?(:estimated_calibration_error)
  @estimated_calibration_error_exact = args[:estimated_calibration_error_exact] if args.key?(:estimated_calibration_error_exact)
  @metrics_type = args[:metrics_type] if args.key?(:metrics_type)
end