Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GenerateSchemaVersionResponse
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GenerateSchemaVersionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Response message for GenerateSchemaVersion.
Instance Attribute Summary collapse
-
#schema_version ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1GenerateSchemaVersionResponse
constructor
A new instance of GoogleCloudDocumentaiV1GenerateSchemaVersionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1GenerateSchemaVersionResponse
Returns a new instance of GoogleCloudDocumentaiV1GenerateSchemaVersionResponse.
6585 6586 6587 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6585 def initialize(**args) update!(**args) end |
Instance Attribute Details
#schema_version ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Corresponds to the JSON property schemaVersion
6583 6584 6585 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6583 def schema_version @schema_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6590 6591 6592 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6590 def update!(**args) @schema_version = args[:schema_version] if args.key?(:schema_version) end |