Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfigHints

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Hints for OCR Engine

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1OcrConfigHints

Returns a new instance of GoogleCloudDocumentaiV1OcrConfigHints.



6939
6940
6941
# File 'lib/google/apis/documentai_v1/classes.rb', line 6939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_hintsArray<String>

List of BCP-47 language codes to use for OCR. In most cases, not specifying it yields the best results since it enables automatic language detection. For languages based on the Latin alphabet, setting hints is not needed. In rare cases, when the language of the text in the image is known, setting a hint will help get better results (although it will be a significant hindrance if the hint is wrong). Corresponds to the JSON property languageHints

Returns:

  • (Array<String>)


6937
6938
6939
# File 'lib/google/apis/documentai_v1/classes.rb', line 6937

def language_hints
  @language_hints
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6944
6945
6946
# File 'lib/google/apis/documentai_v1/classes.rb', line 6944

def update!(**args)
  @language_hints = args[:language_hints] if args.key?(:language_hints)
end