Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfigPremiumFeatures
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfigPremiumFeatures
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Configurations for premium OCR features.
Instance Attribute Summary collapse
-
#compute_style_info ⇒ Boolean
(also: #compute_style_info?)
Turn on font identification model and return font style information.
-
#enable_math_ocr ⇒ Boolean
(also: #enable_math_ocr?)
Turn on the model that can extract LaTeX math formulas.
-
#enable_selection_mark_detection ⇒ Boolean
(also: #enable_selection_mark_detection?)
Turn on selection mark detector in OCR engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1OcrConfigPremiumFeatures
constructor
A new instance of GoogleCloudDocumentaiV1OcrConfigPremiumFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1OcrConfigPremiumFeatures
Returns a new instance of GoogleCloudDocumentaiV1OcrConfigPremiumFeatures.
6913 6914 6915 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compute_style_info ⇒ Boolean Also known as: compute_style_info?
Turn on font identification model and return font style information.
Corresponds to the JSON property computeStyleInfo
6897 6898 6899 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6897 def compute_style_info @compute_style_info end |
#enable_math_ocr ⇒ Boolean Also known as: enable_math_ocr?
Turn on the model that can extract LaTeX math formulas.
Corresponds to the JSON property enableMathOcr
6903 6904 6905 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6903 def enable_math_ocr @enable_math_ocr end |
#enable_selection_mark_detection ⇒ Boolean Also known as: enable_selection_mark_detection?
Turn on selection mark detector in OCR engine. Only available in OCR 2.0 (and
later) processors.
Corresponds to the JSON property enableSelectionMarkDetection
6910 6911 6912 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6910 def enable_selection_mark_detection @enable_selection_mark_detection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6918 6919 6920 6921 6922 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6918 def update!(**args) @compute_style_info = args[:compute_style_info] if args.key?(:compute_style_info) @enable_math_ocr = args[:enable_math_ocr] if args.key?(:enable_math_ocr) @enable_selection_mark_detection = args[:enable_selection_mark_detection] if args.key?(:enable_selection_mark_detection) end |