Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Options for Process API
Instance Attribute Summary collapse
-
#from_end ⇒ Fixnum
Only process certain pages from the end, same as above.
-
#from_start ⇒ Fixnum
Only process certain pages from the start.
-
#individual_page_selector ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsIndividualPageSelector
A list of individual page numbers.
-
#layout_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
Serving config for layout parser processor.
-
#ocr_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfig
Config for Document OCR.
-
#schema_override ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptions
constructor
A new instance of GoogleCloudDocumentaiV1ProcessOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptions
Returns a new instance of GoogleCloudDocumentaiV1ProcessOptions.
7243 7244 7245 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#from_end ⇒ Fixnum
Only process certain pages from the end, same as above.
Corresponds to the JSON property fromEnd
7215 7216 7217 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7215 def from_end @from_end end |
#from_start ⇒ Fixnum
Only process certain pages from the start. Process all if the document has
fewer pages.
Corresponds to the JSON property fromStart
7221 7222 7223 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7221 def from_start @from_start end |
#individual_page_selector ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsIndividualPageSelector
A list of individual page numbers.
Corresponds to the JSON property individualPageSelector
7226 7227 7228 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7226 def individual_page_selector @individual_page_selector end |
#layout_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
Serving config for layout parser processor.
Corresponds to the JSON property layoutConfig
7231 7232 7233 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7231 def layout_config @layout_config end |
#ocr_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfig
Config for Document OCR.
Corresponds to the JSON property ocrConfig
7236 7237 7238 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7236 def ocr_config @ocr_config end |
#schema_override ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property schemaOverride
7241 7242 7243 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7241 def schema_override @schema_override end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7248 7249 7250 7251 7252 7253 7254 7255 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7248 def update!(**args) @from_end = args[:from_end] if args.key?(:from_end) @from_start = args[:from_start] if args.key?(:from_start) @individual_page_selector = args[:individual_page_selector] if args.key?(:individual_page_selector) @layout_config = args[:layout_config] if args.key?(:layout_config) @ocr_config = args[:ocr_config] if args.key?(:ocr_config) @schema_override = args[:schema_override] if args.key?(:schema_override) end |