Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Serving config for chunking.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig

Returns a new instance of GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig.



7057
7058
7059
# File 'lib/google/apis/documentai_v1/classes.rb', line 7057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunk_sizeFixnum

Optional. The chunk sizes to use when splitting documents, in order of level. Corresponds to the JSON property chunkSize

Returns:

  • (Fixnum)


7049
7050
7051
# File 'lib/google/apis/documentai_v1/classes.rb', line 7049

def chunk_size
  @chunk_size
end

#include_ancestor_headingsBoolean Also known as: include_ancestor_headings?

Optional. Whether or not to include ancestor headings when splitting. Corresponds to the JSON property includeAncestorHeadings

Returns:

  • (Boolean)


7054
7055
7056
# File 'lib/google/apis/documentai_v1/classes.rb', line 7054

def include_ancestor_headings
  @include_ancestor_headings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7062
7063
7064
7065
# File 'lib/google/apis/documentai_v1/classes.rb', line 7062

def update!(**args)
  @chunk_size = args[:chunk_size] if args.key?(:chunk_size)
  @include_ancestor_headings = args[:include_ancestor_headings] if args.key?(:include_ancestor_headings)
end