Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Request message for the ProcessDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessRequest

Returns a new instance of GoogleCloudDocumentaiV1ProcessRequest.



7406
7407
7408
# File 'lib/google/apis/documentai_v1/classes.rb', line 7406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_maskString

Specifies which fields to include in the ProcessResponse.document output. Only supports top-level document and pages field, so it must be in the form of document_field_name or pages.page_field_name`. Corresponds to the JSON propertyfieldMask`

Returns:

  • (String)


7360
7361
7362
# File 'lib/google/apis/documentai_v1/classes.rb', line 7360

def field_mask
  @field_mask
end

#gcs_documentGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GcsDocument

Specifies a document stored on Cloud Storage. Corresponds to the JSON property gcsDocument



7365
7366
7367
# File 'lib/google/apis/documentai_v1/classes.rb', line 7365

def gcs_document
  @gcs_document
end

#imageless_modeBoolean Also known as: imageless_mode?

Optional. Option to remove images from the document. Corresponds to the JSON property imagelessMode

Returns:

  • (Boolean)


7370
7371
7372
# File 'lib/google/apis/documentai_v1/classes.rb', line 7370

def imageless_mode
  @imageless_mode
end

#inline_documentGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property inlineDocument



7379
7380
7381
# File 'lib/google/apis/documentai_v1/classes.rb', line 7379

def inline_document
  @inline_document
end

#labelsHash<String,String>

Optional. The labels with user-defined metadata for the request. Label keys and values can be no longer than 63 characters (Unicode codepoints) and can only contain lowercase letters, numeric characters, underscores, and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7388
7389
7390
# File 'lib/google/apis/documentai_v1/classes.rb', line 7388

def labels
  @labels
end

#process_optionsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions

Options for Process API Corresponds to the JSON property processOptions



7393
7394
7395
# File 'lib/google/apis/documentai_v1/classes.rb', line 7393

def process_options
  @process_options
end

#raw_documentGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1RawDocument

Payload message of raw document content (bytes). Corresponds to the JSON property rawDocument



7398
7399
7400
# File 'lib/google/apis/documentai_v1/classes.rb', line 7398

def raw_document
  @raw_document
end

#skip_human_reviewBoolean Also known as: skip_human_review?

Whether human review should be skipped for this request. Default to false. Corresponds to the JSON property skipHumanReview

Returns:

  • (Boolean)


7403
7404
7405
# File 'lib/google/apis/documentai_v1/classes.rb', line 7403

def skip_human_review
  @skip_human_review
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
# File 'lib/google/apis/documentai_v1/classes.rb', line 7411

def update!(**args)
  @field_mask = args[:field_mask] if args.key?(:field_mask)
  @gcs_document = args[:gcs_document] if args.key?(:gcs_document)
  @imageless_mode = args[:imageless_mode] if args.key?(:imageless_mode)
  @inline_document = args[:inline_document] if args.key?(:inline_document)
  @labels = args[:labels] if args.key?(:labels)
  @process_options = args[:process_options] if args.key?(:process_options)
  @raw_document = args[:raw_document] if args.key?(:raw_document)
  @skip_human_review = args[:skip_human_review] if args.key?(:skip_human_review)
end