Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Processor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1Processor

Returns a new instance of GoogleCloudDocumentaiV1Processor.



7524
7525
7526
# File 'lib/google/apis/documentai_v1/classes.rb', line 7524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_schema_versionString

Optional. SchemaVersion used by the Processor. It is the same as Processor's DatasetSchema.schema_version Format is projects/project/locations/location /schemas/schema/schemaVersions/schema_version Corresponds to the JSON propertyactiveSchemaVersion`

Returns:

  • (String)


7461
7462
7463
# File 'lib/google/apis/documentai_v1/classes.rb', line 7461

def active_schema_version
  @active_schema_version
end

#create_timeString

Output only. The time the processor was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7466
7467
7468
# File 'lib/google/apis/documentai_v1/classes.rb', line 7466

def create_time
  @create_time
end

#default_processor_versionString

The default processor version. Corresponds to the JSON property defaultProcessorVersion

Returns:

  • (String)


7471
7472
7473
# File 'lib/google/apis/documentai_v1/classes.rb', line 7471

def default_processor_version
  @default_processor_version
end

#display_nameString

The display name of the processor. Corresponds to the JSON property displayName

Returns:

  • (String)


7476
7477
7478
# File 'lib/google/apis/documentai_v1/classes.rb', line 7476

def display_name
  @display_name
end

#kms_key_nameString

The KMS key used for encryption and decryption in CMEK scenarios. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


7482
7483
7484
# File 'lib/google/apis/documentai_v1/classes.rb', line 7482

def kms_key_name
  @kms_key_name
end

#nameString

Output only. Immutable. The resource name of the processor. Format: projects/ project/locations/location/processors/processor` Corresponds to the JSON propertyname`

Returns:

  • (String)


7488
7489
7490
# File 'lib/google/apis/documentai_v1/classes.rb', line 7488

def name
  @name
end

#process_endpointString

Output only. Immutable. The http endpoint that can be called to invoke processing. Corresponds to the JSON property processEndpoint

Returns:

  • (String)


7494
7495
7496
# File 'lib/google/apis/documentai_v1/classes.rb', line 7494

def process_endpoint
  @process_endpoint
end

#processor_version_aliasesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionAlias>

Output only. The processor version aliases. Corresponds to the JSON property processorVersionAliases



7499
7500
7501
# File 'lib/google/apis/documentai_v1/classes.rb', line 7499

def processor_version_aliases
  @processor_version_aliases
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


7504
7505
7506
# File 'lib/google/apis/documentai_v1/classes.rb', line 7504

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


7510
7511
7512
# File 'lib/google/apis/documentai_v1/classes.rb', line 7510

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The state of the processor. Corresponds to the JSON property state

Returns:

  • (String)


7516
7517
7518
# File 'lib/google/apis/documentai_v1/classes.rb', line 7516

def state
  @state
end

#typeString

The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR. To get a list of processor types, see FetchProcessorTypes. Corresponds to the JSON property type

Returns:

  • (String)


7522
7523
7524
# File 'lib/google/apis/documentai_v1/classes.rb', line 7522

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7529
7530
7531
7532
7533
7534
7535
7536
7537
7538
7539
7540
7541
7542
# File 'lib/google/apis/documentai_v1/classes.rb', line 7529

def update!(**args)
  @active_schema_version = args[:active_schema_version] if args.key?(:active_schema_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_processor_version = args[:default_processor_version] if args.key?(:default_processor_version)
  @display_name = args[:display_name] if args.key?(:display_name)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @name = args[:name] if args.key?(:name)
  @process_endpoint = args[:process_endpoint] if args.key?(:process_endpoint)
  @processor_version_aliases = args[:processor_version_aliases] if args.key?(:processor_version_aliases)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end