Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessorVersion

Returns a new instance of GoogleCloudDocumentaiV1ProcessorVersion.



7706
7707
7708
# File 'lib/google/apis/documentai_v1/classes.rb', line 7706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the processor version was created. Corresponds to the JSON property createTime

Returns:

  • (String)


7634
7635
7636
# File 'lib/google/apis/documentai_v1/classes.rb', line 7634

def create_time
  @create_time
end

#deprecation_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo

Information about the upcoming deprecation of this processor version. Corresponds to the JSON property deprecationInfo



7639
7640
7641
# File 'lib/google/apis/documentai_v1/classes.rb', line 7639

def deprecation_info
  @deprecation_info
end

#display_nameString

The display name of the processor version. Corresponds to the JSON property displayName

Returns:

  • (String)


7644
7645
7646
# File 'lib/google/apis/documentai_v1/classes.rb', line 7644

def display_name
  @display_name
end

#document_schemaGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property documentSchema



7649
7650
7651
# File 'lib/google/apis/documentai_v1/classes.rb', line 7649

def document_schema
  @document_schema
end

#gen_ai_model_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo

Information about Generative AI model-based processor versions. Corresponds to the JSON property genAiModelInfo



7654
7655
7656
# File 'lib/google/apis/documentai_v1/classes.rb', line 7654

def gen_ai_model_info
  @gen_ai_model_info
end

#google_managedBoolean Also known as: google_managed?

Output only. Denotes that this ProcessorVersion is managed by Google. Corresponds to the JSON property googleManaged

Returns:

  • (Boolean)


7659
7660
7661
# File 'lib/google/apis/documentai_v1/classes.rb', line 7659

def google_managed
  @google_managed
end

#kms_key_nameString

Output only. The KMS key name used for encryption. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


7665
7666
7667
# File 'lib/google/apis/documentai_v1/classes.rb', line 7665

def kms_key_name
  @kms_key_name
end

#kms_key_version_nameString

Output only. The KMS key version with which data is encrypted. Corresponds to the JSON property kmsKeyVersionName

Returns:

  • (String)


7670
7671
7672
# File 'lib/google/apis/documentai_v1/classes.rb', line 7670

def kms_key_version_name
  @kms_key_version_name
end

#latest_evaluationGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationReference

Gives a short summary of an evaluation, and links to the evaluation itself. Corresponds to the JSON property latestEvaluation



7675
7676
7677
# File 'lib/google/apis/documentai_v1/classes.rb', line 7675

def latest_evaluation
  @latest_evaluation
end

#model_typeString

Output only. The model type of this processor version. Corresponds to the JSON property modelType

Returns:

  • (String)


7680
7681
7682
# File 'lib/google/apis/documentai_v1/classes.rb', line 7680

def model_type
  @model_type
end

#nameString

Identifier. The resource name of the processor version. Format: projects/ project/locations/location/processors/processor/processorVersions/ processor_version` Corresponds to the JSON propertyname`

Returns:

  • (String)


7687
7688
7689
# File 'lib/google/apis/documentai_v1/classes.rb', line 7687

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


7692
7693
7694
# File 'lib/google/apis/documentai_v1/classes.rb', line 7692

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


7698
7699
7700
# File 'lib/google/apis/documentai_v1/classes.rb', line 7698

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The state of the processor version. Corresponds to the JSON property state

Returns:

  • (String)


7704
7705
7706
# File 'lib/google/apis/documentai_v1/classes.rb', line 7704

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7711
7712
7713
7714
7715
7716
7717
7718
7719
7720
7721
7722
7723
7724
7725
7726
# File 'lib/google/apis/documentai_v1/classes.rb', line 7711

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deprecation_info = args[:deprecation_info] if args.key?(:deprecation_info)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_schema = args[:document_schema] if args.key?(:document_schema)
  @gen_ai_model_info = args[:gen_ai_model_info] if args.key?(:gen_ai_model_info)
  @google_managed = args[:google_managed] if args.key?(:google_managed)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @kms_key_version_name = args[:kms_key_version_name] if args.key?(:kms_key_version_name)
  @latest_evaluation = args[:latest_evaluation] if args.key?(:latest_evaluation)
  @model_type = args[:model_type] if args.key?(:model_type)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
end