Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Information about Generative AI model-based processor versions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo.



7795
7796
7797
# File 'lib/google/apis/documentai_v1/classes.rb', line 7795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_gen_ai_model_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Information for a custom Generative AI model created by the user. These are created with Create New Version in either the Call foundation model or Fine tuning tabs. Corresponds to the JSON property customGenAiModelInfo



7788
7789
7790
# File 'lib/google/apis/documentai_v1/classes.rb', line 7788

def custom_gen_ai_model_info
  @custom_gen_ai_model_info
end

#foundation_gen_ai_model_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Information for a pretrained Google-managed foundation model. Corresponds to the JSON property foundationGenAiModelInfo



7793
7794
7795
# File 'lib/google/apis/documentai_v1/classes.rb', line 7793

def foundation_gen_ai_model_info
  @foundation_gen_ai_model_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7800
7801
7802
7803
# File 'lib/google/apis/documentai_v1/classes.rb', line 7800

def update!(**args)
  @custom_gen_ai_model_info = args[:custom_gen_ai_model_info] if args.key?(:custom_gen_ai_model_info)
  @foundation_gen_ai_model_info = args[:foundation_gen_ai_model_info] if args.key?(:foundation_gen_ai_model_info)
end