Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ReviewDocumentResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Response message for the ReviewDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ReviewDocumentResponse

Returns a new instance of GoogleCloudDocumentaiV1ReviewDocumentResponse.



7716
7717
7718
# File 'lib/google/apis/documentai_v1/classes.rb', line 7716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_destinationString

The Cloud Storage uri for the human reviewed document if the review is succeeded. Corresponds to the JSON property gcsDestination

Returns:

  • (String)


7704
7705
7706
# File 'lib/google/apis/documentai_v1/classes.rb', line 7704

def gcs_destination
  @gcs_destination
end

#rejection_reasonString

The reason why the review is rejected by reviewer. Corresponds to the JSON property rejectionReason

Returns:

  • (String)


7709
7710
7711
# File 'lib/google/apis/documentai_v1/classes.rb', line 7709

def rejection_reason
  @rejection_reason
end

#stateString

The state of the review operation. Corresponds to the JSON property state

Returns:

  • (String)


7714
7715
7716
# File 'lib/google/apis/documentai_v1/classes.rb', line 7714

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7721
7722
7723
7724
7725
# File 'lib/google/apis/documentai_v1/classes.rb', line 7721

def update!(**args)
  @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination)
  @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason)
  @state = args[:state] if args.key?(:state)
end