Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaGenerationIteration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A single iteration of the schema generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaGenerationIteration

Returns a new instance of GoogleCloudDocumentaiV1SchemaGenerationIteration.



8049
8050
8051
# File 'lib/google/apis/documentai_v1/classes.rb', line 8049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjusted_schemaGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion

SchemaVersion is a version of the Schema which is created in SchemaGroup. Corresponds to the JSON property adjustedSchema



8037
8038
8039
# File 'lib/google/apis/documentai_v1/classes.rb', line 8037

def adjusted_schema
  @adjusted_schema
end

#generated_schemaGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion

SchemaVersion is a version of the Schema which is created in SchemaGroup. Corresponds to the JSON property generatedSchema



8042
8043
8044
# File 'lib/google/apis/documentai_v1/classes.rb', line 8042

def generated_schema
  @generated_schema
end

#promptString

Optional. The prompt used for the iteration. Corresponds to the JSON property prompt

Returns:

  • (String)


8047
8048
8049
# File 'lib/google/apis/documentai_v1/classes.rb', line 8047

def prompt
  @prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8054
8055
8056
8057
8058
# File 'lib/google/apis/documentai_v1/classes.rb', line 8054

def update!(**args)
  @adjusted_schema = args[:adjusted_schema] if args.key?(:adjusted_schema)
  @generated_schema = args[:generated_schema] if args.key?(:generated_schema)
  @prompt = args[:prompt] if args.key?(:prompt)
end