Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

SchemaVersion is a version of the Schema which is created in SchemaGroup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaVersion

Returns a new instance of GoogleCloudDocumentaiV1SchemaVersion.



8091
8092
8093
# File 'lib/google/apis/documentai_v1/classes.rb', line 8091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time when the SchemaVersion was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8068
8069
8070
# File 'lib/google/apis/documentai_v1/classes.rb', line 8068

def create_time
  @create_time
end

#display_nameString

Required. The user-defined name of the SchemaVersion. Corresponds to the JSON property displayName

Returns:

  • (String)


8073
8074
8075
# File 'lib/google/apis/documentai_v1/classes.rb', line 8073

def display_name
  @display_name
end

#labelsHash<String,String>

Optional. The gcp_name_short labels for the SchemaVersion. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8078
8079
8080
# File 'lib/google/apis/documentai_v1/classes.rb', line 8078

def labels
  @labels
end

#nameString

Identifier. The resource name of the SchemaVersion. Format: projects/project /locations/location/schemas/schema/schemaVersions/schema_version` Corresponds to the JSON propertyname`

Returns:

  • (String)


8084
8085
8086
# File 'lib/google/apis/documentai_v1/classes.rb', line 8084

def name
  @name
end

#schemaGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property schema



8089
8090
8091
# File 'lib/google/apis/documentai_v1/classes.rb', line 8089

def schema
  @schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8096
8097
8098
8099
8100
8101
8102
# File 'lib/google/apis/documentai_v1/classes.rb', line 8096

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @schema = args[:schema] if args.key?(:schema)
end