Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The dataset validation information. This includes any and all errors with documents and the dataset.
Instance Attribute Summary collapse
-
#dataset_error_count ⇒ Fixnum
The total number of dataset errors.
-
#dataset_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information for the dataset as a whole.
-
#document_error_count ⇒ Fixnum
The total number of document errors.
-
#document_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information pertaining to specific documents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
constructor
A new instance of GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
Returns a new instance of GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation.
8219 8220 8221 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_error_count ⇒ Fixnum
The total number of dataset errors.
Corresponds to the JSON property datasetErrorCount
8199 8200 8201 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8199 def dataset_error_count @dataset_error_count end |
#dataset_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information for the dataset as a whole. A maximum of 10 dataset errors
will be returned. A single dataset error is terminal for training.
Corresponds to the JSON property datasetErrors
8205 8206 8207 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8205 def dataset_errors @dataset_errors end |
#document_error_count ⇒ Fixnum
The total number of document errors.
Corresponds to the JSON property documentErrorCount
8210 8211 8212 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8210 def document_error_count @document_error_count end |
#document_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information pertaining to specific documents. A maximum of 10 document
errors will be returned. Any document with errors will not be used throughout
training.
Corresponds to the JSON property documentErrors
8217 8218 8219 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8217 def document_errors @document_errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8224 8225 8226 8227 8228 8229 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8224 def update!(**args) @dataset_error_count = args[:dataset_error_count] if args.key?(:dataset_error_count) @dataset_errors = args[:dataset_errors] if args.key?(:dataset_errors) @document_error_count = args[:document_error_count] if args.key?(:document_error_count) @document_errors = args[:document_errors] if args.key?(:document_errors) end |