Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Request message for the TrainProcessorVersion method.
Instance Attribute Summary collapse
-
#base_processor_version ⇒ String
Optional.
-
#custom_document_extraction_options ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestCustomDocumentExtractionOptions
Options to control the training of the Custom Document Extraction (CDE) Processor.
-
#document_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
-
#foundation_model_tuning_options ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
Options to control foundation model tuning of the processor.
-
#input_data ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestInputData
The input data used to train a new ProcessorVersion.
-
#processor_version ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersion
A processor version is an implementation of a processor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionRequest
constructor
A new instance of GoogleCloudDocumentaiV1TrainProcessorVersionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionRequest
Returns a new instance of GoogleCloudDocumentaiV1TrainProcessorVersionRequest.
8272 8273 8274 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_processor_version ⇒ String
Optional. The processor version to use as a base for training. This processor
version must be a child of parent. Format: projects/project/locations/
location/processors/processor/processorVersions/processorVersion`.
Corresponds to the JSON propertybaseProcessorVersion`
8241 8242 8243 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8241 def base_processor_version @base_processor_version end |
#custom_document_extraction_options ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestCustomDocumentExtractionOptions
Options to control the training of the Custom Document Extraction (CDE)
Processor.
Corresponds to the JSON property customDocumentExtractionOptions
8247 8248 8249 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8247 def @custom_document_extraction_options end |
#document_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property documentSchema
8252 8253 8254 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8252 def document_schema @document_schema end |
#foundation_model_tuning_options ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
Options to control foundation model tuning of the processor.
Corresponds to the JSON property foundationModelTuningOptions
8257 8258 8259 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8257 def @foundation_model_tuning_options end |
#input_data ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestInputData
The input data used to train a new ProcessorVersion.
Corresponds to the JSON property inputData
8262 8263 8264 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8262 def input_data @input_data end |
#processor_version ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersion
A processor version is an implementation of a processor. Each processor can
have multiple versions, pretrained by Google internally or uptrained by the
customer. A processor can only have one default version at a time. Its
document-processing behavior is defined by that version.
Corresponds to the JSON property processorVersion
8270 8271 8272 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8270 def processor_version @processor_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8277 8278 8279 8280 8281 8282 8283 8284 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8277 def update!(**args) @base_processor_version = args[:base_processor_version] if args.key?(:base_processor_version) @custom_document_extraction_options = args[:custom_document_extraction_options] if args.key?(:custom_document_extraction_options) @document_schema = args[:document_schema] if args.key?(:document_schema) @foundation_model_tuning_options = args[:foundation_model_tuning_options] if args.key?(:foundation_model_tuning_options) @input_data = args[:input_data] if args.key?(:input_data) @processor_version = args[:processor_version] if args.key?(:processor_version) end |