Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Options to control foundation model tuning of the processor.
Instance Attribute Summary collapse
-
#learning_rate_multiplier ⇒ Float
Optional.
-
#previous_fine_tuned_processor_version_name ⇒ String
Optional.
-
#train_steps ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
constructor
A new instance of GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
Returns a new instance of GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions.
8333 8334 8335 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#learning_rate_multiplier ⇒ Float
Optional. The multiplier to apply to the recommended learning rate. Valid
values are between 0.1 and 10. If not provided, recommended learning rate will
be used.
Corresponds to the JSON property learningRateMultiplier
8316 8317 8318 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8316 def learning_rate_multiplier @learning_rate_multiplier end |
#previous_fine_tuned_processor_version_name ⇒ String
Optional. Resource name of a previously fine tuned version id to copy the
overwritten configs from. The base_processor_version should be newer than the
base processor version used to fine tune this provided processor version.
Format: projects/project/locations/location/processors/processor/
processorVersions/processorVersion`.
Corresponds to the JSON propertypreviousFineTunedProcessorVersionName`
8325 8326 8327 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8325 def previous_fine_tuned_processor_version_name @previous_fine_tuned_processor_version_name end |
#train_steps ⇒ Fixnum
Optional. The number of steps to run for model tuning. Valid values are
between 1 and 400. If not provided, recommended steps will be used.
Corresponds to the JSON property trainSteps
8331 8332 8333 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8331 def train_steps @train_steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8338 8339 8340 8341 8342 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8338 def update!(**args) @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier) @previous_fine_tuned_processor_version_name = args[:previous_fine_tuned_processor_version_name] if args.key?(:previous_fine_tuned_processor_version_name) @train_steps = args[:train_steps] if args.key?(:train_steps) end |