Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The common metadata for long running operations.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The creation time of the operation.
-
#resource ⇒ String
A related resource to this operation.
-
#state ⇒ String
The state of the operation.
-
#state_message ⇒ String
A message providing more details about the current state of processing.
-
#update_time ⇒ String
The last update time of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3CommonOperationMetadata
constructor
A new instance of GoogleCloudDocumentaiV1beta3CommonOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3CommonOperationMetadata
Returns a new instance of GoogleCloudDocumentaiV1beta3CommonOperationMetadata.
8446 8447 8448 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The creation time of the operation.
Corresponds to the JSON property createTime
8424 8425 8426 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8424 def create_time @create_time end |
#resource ⇒ String
A related resource to this operation.
Corresponds to the JSON property resource
8429 8430 8431 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8429 def resource @resource end |
#state ⇒ String
The state of the operation.
Corresponds to the JSON property state
8434 8435 8436 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8434 def state @state end |
#state_message ⇒ String
A message providing more details about the current state of processing.
Corresponds to the JSON property stateMessage
8439 8440 8441 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8439 def @state_message end |
#update_time ⇒ String
The last update time of the operation.
Corresponds to the JSON property updateTime
8444 8445 8446 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8444 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8451 8452 8453 8454 8455 8456 8457 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8451 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @resource = args[:resource] if args.key?(:resource) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @update_time = args[:update_time] if args.key?(:update_time) end |