Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaEntityType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

EntityType is the wrapper of a label of the corresponding model with detailed attributes and limitations for entity-based processors. Multiple types can also compose a dependency tree to represent nested types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaEntityType

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaEntityType.



8864
8865
8866
# File 'lib/google/apis/documentai_v1/classes.rb', line 8864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_typesArray<String>

The entity type that this type is derived from. For now, one and only one should be set. Corresponds to the JSON property baseTypes

Returns:

  • (Array<String>)


8824
8825
8826
# File 'lib/google/apis/documentai_v1/classes.rb', line 8824

def base_types
  @base_types
end

#descriptionString

The description of the entity type. Could be used to provide more information about the entity type for model calls. Corresponds to the JSON property description

Returns:

  • (String)


8830
8831
8832
# File 'lib/google/apis/documentai_v1/classes.rb', line 8830

def description
  @description
end

#display_nameString

User defined name for the type. Corresponds to the JSON property displayName

Returns:

  • (String)


8835
8836
8837
# File 'lib/google/apis/documentai_v1/classes.rb', line 8835

def display_name
  @display_name
end

#entity_type_metadataGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EntityTypeMetadata

Metadata about an entity type. Corresponds to the JSON property entityTypeMetadata



8840
8841
8842
# File 'lib/google/apis/documentai_v1/classes.rb', line 8840

def 
  @entity_type_metadata
end

#enum_valuesGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeEnumValues

Defines the a list of enum values. Corresponds to the JSON property enumValues



8845
8846
8847
# File 'lib/google/apis/documentai_v1/classes.rb', line 8845

def enum_values
  @enum_values
end

#nameString

Name of the type. It must be unique within the schema file and cannot be a " Common Type". The following naming conventions are used: - Use snake_casing.

  • Name matching is case-sensitive. - Maximum 64 characters. - Must start with a letter. - Allowed characters: ASCII letters [a-z0-9_-]. (For backward compatibility, internal infrastructure and tooling can handle any ASCII character.) - The / is sometimes used to denote a property of a type. For example line_item/amount. This convention is deprecated, but will still be honored for backward compatibility. Corresponds to the JSON property name

Returns:

  • (String)


8857
8858
8859
# File 'lib/google/apis/documentai_v1/classes.rb', line 8857

def name
  @name
end

#propertiesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty>

Description the nested structure, or composition of an entity. Corresponds to the JSON property properties



8862
8863
8864
# File 'lib/google/apis/documentai_v1/classes.rb', line 8862

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8869
8870
8871
8872
8873
8874
8875
8876
8877
# File 'lib/google/apis/documentai_v1/classes.rb', line 8869

def update!(**args)
  @base_types = args[:base_types] if args.key?(:base_types)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_type_metadata = args[:entity_type_metadata] if args.key?(:entity_type_metadata)
  @enum_values = args[:enum_values] if args.key?(:enum_values)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end