Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationReference
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Gives a short summary of an evaluation, and links to the evaluation itself.
Instance Attribute Summary collapse
-
#aggregate_metrics ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
-
#aggregate_metrics_exact ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
-
#evaluation ⇒ String
The resource name of the evaluation.
-
#operation ⇒ String
The resource name of the Long Running Operation for the evaluation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationReference
constructor
A new instance of GoogleCloudDocumentaiV1beta3EvaluationReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationReference
Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationReference.
9138 9139 9140 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9138 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_metrics ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
Corresponds to the JSON property aggregateMetrics
9121 9122 9123 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9121 def aggregate_metrics @aggregate_metrics end |
#aggregate_metrics_exact ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
Corresponds to the JSON property aggregateMetricsExact
9126 9127 9128 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9126 def aggregate_metrics_exact @aggregate_metrics_exact end |
#evaluation ⇒ String
The resource name of the evaluation.
Corresponds to the JSON property evaluation
9131 9132 9133 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9131 def evaluation @evaluation end |
#operation ⇒ String
The resource name of the Long Running Operation for the evaluation.
Corresponds to the JSON property operation
9136 9137 9138 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9136 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9143 9144 9145 9146 9147 9148 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9143 def update!(**args) @aggregate_metrics = args[:aggregate_metrics] if args.key?(:aggregate_metrics) @aggregate_metrics_exact = args[:aggregate_metrics_exact] if args.key?(:aggregate_metrics_exact) @evaluation = args[:evaluation] if args.key?(:evaluation) @operation = args[:operation] if args.key?(:operation) end |