Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Information about Generative AI model-based processor versions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfo.



9926
9927
9928
# File 'lib/google/apis/documentai_v1/classes.rb', line 9926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_gen_ai_model_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Information for a custom Generative AI model created by the user. These are created with Create New Version in either the Call foundation model or Fine tuning tabs. Corresponds to the JSON property customGenAiModelInfo



9919
9920
9921
# File 'lib/google/apis/documentai_v1/classes.rb', line 9919

def custom_gen_ai_model_info
  @custom_gen_ai_model_info
end

#foundation_gen_ai_model_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Information for a pretrained Google-managed foundation model. Corresponds to the JSON property foundationGenAiModelInfo



9924
9925
9926
# File 'lib/google/apis/documentai_v1/classes.rb', line 9924

def foundation_gen_ai_model_info
  @foundation_gen_ai_model_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9931
9932
9933
9934
# File 'lib/google/apis/documentai_v1/classes.rb', line 9931

def update!(**args)
  @custom_gen_ai_model_info = args[:custom_gen_ai_model_info] if args.key?(:custom_gen_ai_model_info)
  @foundation_gen_ai_model_info = args[:foundation_gen_ai_model_info] if args.key?(:foundation_gen_ai_model_info)
end