Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Information for a custom Generative AI model created by the user. These are created with Create New Version in either the Call foundation model or Fine tuning tabs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoCustomGenAiModelInfo.



9729
9730
9731
# File 'lib/google/apis/documentai_v1/classes.rb', line 9729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_processor_version_idString

The base processor version ID for the custom model. Corresponds to the JSON property baseProcessorVersionId

Returns:

  • (String)


9722
9723
9724
# File 'lib/google/apis/documentai_v1/classes.rb', line 9722

def base_processor_version_id
  @base_processor_version_id
end

#custom_model_typeString

The type of custom model created by the user. Corresponds to the JSON property customModelType

Returns:

  • (String)


9727
9728
9729
# File 'lib/google/apis/documentai_v1/classes.rb', line 9727

def custom_model_type
  @custom_model_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9734
9735
9736
9737
# File 'lib/google/apis/documentai_v1/classes.rb', line 9734

def update!(**args)
  @base_processor_version_id = args[:base_processor_version_id] if args.key?(:base_processor_version_id)
  @custom_model_type = args[:custom_model_type] if args.key?(:custom_model_type)
end