Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Information for a pretrained Google-managed foundation model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo.



9746
9747
9748
# File 'lib/google/apis/documentai_v1/classes.rb', line 9746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#finetuning_allowedBoolean Also known as: finetuning_allowed?

Whether fine tuning is allowed for this base processor version. Corresponds to the JSON property finetuningAllowed

Returns:

  • (Boolean)


9737
9738
9739
# File 'lib/google/apis/documentai_v1/classes.rb', line 9737

def finetuning_allowed
  @finetuning_allowed
end

#min_train_labeled_documentsFixnum

The minimum number of labeled documents in the training dataset required for fine tuning. Corresponds to the JSON property minTrainLabeledDocuments

Returns:

  • (Fixnum)


9744
9745
9746
# File 'lib/google/apis/documentai_v1/classes.rb', line 9744

def min_train_labeled_documents
  @min_train_labeled_documents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9751
9752
9753
9754
# File 'lib/google/apis/documentai_v1/classes.rb', line 9751

def update!(**args)
  @finetuning_allowed = args[:finetuning_allowed] if args.key?(:finetuning_allowed)
  @min_train_labeled_documents = args[:min_train_labeled_documents] if args.key?(:min_train_labeled_documents)
end