Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The long-running operation metadata for the ReviewDocument method.
Instance Attribute Summary collapse
-
#common_metadata ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
The common metadata for long running operations.
-
#create_time ⇒ String
The creation time of the operation.
-
#question_id ⇒ String
The Crowd Compute question ID.
-
#state ⇒ String
Used only when Operation.done is false.
-
#state_message ⇒ String
A message providing more details about the current state of processing.
-
#update_time ⇒ String
The last update time of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
constructor
A new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata
Returns a new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentOperationMetadata.
9770 9771 9772 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9770 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_metadata ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3CommonOperationMetadata
The common metadata for long running operations.
Corresponds to the JSON property commonMetadata
9742 9743 9744 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9742 def @common_metadata end |
#create_time ⇒ String
The creation time of the operation.
Corresponds to the JSON property createTime
9747 9748 9749 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9747 def create_time @create_time end |
#question_id ⇒ String
The Crowd Compute question ID.
Corresponds to the JSON property questionId
9752 9753 9754 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9752 def question_id @question_id end |
#state ⇒ String
Used only when Operation.done is false.
Corresponds to the JSON property state
9757 9758 9759 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9757 def state @state end |
#state_message ⇒ String
A message providing more details about the current state of processing. For
example, the error message if the operation is failed.
Corresponds to the JSON property stateMessage
9763 9764 9765 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9763 def @state_message end |
#update_time ⇒ String
The last update time of the operation.
Corresponds to the JSON property updateTime
9768 9769 9770 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9768 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9775 9776 9777 9778 9779 9780 9781 9782 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9775 def update!(**args) @common_metadata = args[:common_metadata] if args.key?(:common_metadata) @create_time = args[:create_time] if args.key?(:create_time) @question_id = args[:question_id] if args.key?(:question_id) @state = args[:state] if args.key?(:state) @state_message = args[:state_message] if args.key?(:state_message) @update_time = args[:update_time] if args.key?(:update_time) end |