Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The status of individual documents in the auto-labeling process.
Instance Attribute Summary collapse
-
#document_id ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiUiv1beta3DocumentId
Document Identifier.
-
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus
constructor
A new instance of GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus
Returns a new instance of GoogleCloudDocumentaiUiv1beta3AutoLabelDocumentsMetadataIndividualAutoLabelStatus.
416 417 418 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_id ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiUiv1beta3DocumentId
Document Identifier.
Corresponds to the JSON property documentId
404 405 406 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 404 def document_id @document_id end |
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the [API Design Guide](https:
//cloud.google.com/apis/design/errors).
Corresponds to the JSON property status
414 415 416 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 414 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
421 422 423 424 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 421 def update!(**args) @document_id = args[:document_id] if args.key?(:document_id) @status = args[:status] if args.key?(:status) end |