Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1Document

Returns a new instance of GoogleCloudDocumentaiV1Document.



3412
3413
3414
# File 'lib/google/apis/documentai_v1/classes.rb', line 3412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunked_documentGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocument

Represents the chunks that the document is divided into. Corresponds to the JSON property chunkedDocument



3302
3303
3304
# File 'lib/google/apis/documentai_v1/classes.rb', line 3302

def chunked_document
  @chunked_document
end

#contentString

Optional. Inline document content, represented as a stream of bytes. Note: As with all bytes fields, protobuffers use a pure binary representation, whereas JSON representations use base64. Corresponds to the JSON property content NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3310
3311
3312
# File 'lib/google/apis/documentai_v1/classes.rb', line 3310

def content
  @content
end

#docidString

Optional. An internal identifier for document. Should be loggable (no PII). Corresponds to the JSON property docid

Returns:

  • (String)


3315
3316
3317
# File 'lib/google/apis/documentai_v1/classes.rb', line 3315

def docid
  @docid
end

#document_layoutGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayout

Represents the parsed layout of a document as a collection of blocks that the document is divided into. Corresponds to the JSON property documentLayout



3321
3322
3323
# File 'lib/google/apis/documentai_v1/classes.rb', line 3321

def document_layout
  @document_layout
end

#entitiesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntity>

A list of entities detected on Document.text. For document shards, entities in this list may cross shard boundaries. Corresponds to the JSON property entities



3327
3328
3329
# File 'lib/google/apis/documentai_v1/classes.rb', line 3327

def entities
  @entities
end

#entities_revision_idString

The entity revision id that document.entities field is based on. If this field is set and entities_revisions is not empty, the entities in document. entities field are the entities in the entity revision with this id and document.entity_validation_output field is the entity_validation_output field in this entity revision. Corresponds to the JSON property entitiesRevisionId

Returns:

  • (String)


3336
3337
3338
# File 'lib/google/apis/documentai_v1/classes.rb', line 3336

def entities_revision_id
  @entities_revision_id
end

#entities_revisionsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntitiesRevision>

A list of entity revisions. The entity revisions are appended to the document in the processing order. This field can be used for comparing the entity extraction results at different stages of the processing. Corresponds to the JSON property entitiesRevisions



3343
3344
3345
# File 'lib/google/apis/documentai_v1/classes.rb', line 3343

def entities_revisions
  @entities_revisions
end

#entity_relationsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityRelation>

Placeholder. Relationship among Document.entities. Corresponds to the JSON property entityRelations



3348
3349
3350
# File 'lib/google/apis/documentai_v1/classes.rb', line 3348

def entity_relations
  @entity_relations
end

#entity_validation_outputGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityValidationOutput

The output of the validation given the document and the validation rules. Corresponds to the JSON property entityValidationOutput



3353
3354
3355
# File 'lib/google/apis/documentai_v1/classes.rb', line 3353

def entity_validation_output
  @entity_validation_output
end

#errorGoogle::Apis::DocumentaiV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3363
3364
3365
# File 'lib/google/apis/documentai_v1/classes.rb', line 3363

def error
  @error
end

#mime_typeString

An IANA published media type (MIME type). Corresponds to the JSON property mimeType

Returns:

  • (String)


3369
3370
3371
# File 'lib/google/apis/documentai_v1/classes.rb', line 3369

def mime_type
  @mime_type
end

#pagesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPage>

Visual page layout for the Document. Corresponds to the JSON property pages



3374
3375
3376
# File 'lib/google/apis/documentai_v1/classes.rb', line 3374

def pages
  @pages
end

#revisionsArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevision>

Placeholder. Revision history of this document. Corresponds to the JSON property revisions



3379
3380
3381
# File 'lib/google/apis/documentai_v1/classes.rb', line 3379

def revisions
  @revisions
end

#shard_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentShardInfo

For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is. Corresponds to the JSON property shardInfo



3385
3386
3387
# File 'lib/google/apis/documentai_v1/classes.rb', line 3385

def shard_info
  @shard_info
end

#textString

Optional. UTF-8 encoded text in reading order from the document. Corresponds to the JSON property text

Returns:

  • (String)


3390
3391
3392
# File 'lib/google/apis/documentai_v1/classes.rb', line 3390

def text
  @text
end

#text_changesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentTextChange>

Placeholder. A list of text corrections made to Document.text. This is usually used for annotating corrections to OCR mistakes. Text changes for a given revision may not overlap with each other. Corresponds to the JSON property textChanges



3397
3398
3399
# File 'lib/google/apis/documentai_v1/classes.rb', line 3397

def text_changes
  @text_changes
end

#text_stylesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentStyle>

Styles for the Document.text. Corresponds to the JSON property textStyles



3402
3403
3404
# File 'lib/google/apis/documentai_v1/classes.rb', line 3402

def text_styles
  @text_styles
end

#uriString

Optional. Currently supports Google Cloud Storage URI of the form gs:// bucket_name/object_name. Object versioning is not supported. For more information, refer to Google Cloud Storage Request URIs. Corresponds to the JSON property uri

Returns:

  • (String)


3410
3411
3412
# File 'lib/google/apis/documentai_v1/classes.rb', line 3410

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3417
3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
# File 'lib/google/apis/documentai_v1/classes.rb', line 3417

def update!(**args)
  @chunked_document = args[:chunked_document] if args.key?(:chunked_document)
  @content = args[:content] if args.key?(:content)
  @docid = args[:docid] if args.key?(:docid)
  @document_layout = args[:document_layout] if args.key?(:document_layout)
  @entities = args[:entities] if args.key?(:entities)
  @entities_revision_id = args[:entities_revision_id] if args.key?(:entities_revision_id)
  @entities_revisions = args[:entities_revisions] if args.key?(:entities_revisions)
  @entity_relations = args[:entity_relations] if args.key?(:entity_relations)
  @entity_validation_output = args[:entity_validation_output] if args.key?(:entity_validation_output)
  @error = args[:error] if args.key?(:error)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @pages = args[:pages] if args.key?(:pages)
  @revisions = args[:revisions] if args.key?(:revisions)
  @shard_info = args[:shard_info] if args.key?(:shard_info)
  @text = args[:text] if args.key?(:text)
  @text_changes = args[:text_changes] if args.key?(:text_changes)
  @text_styles = args[:text_styles] if args.key?(:text_styles)
  @uri = args[:uri] if args.key?(:uri)
end