Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Represents a chunk.
Instance Attribute Summary collapse
-
#chunk_id ⇒ String
ID of the chunk.
-
#content ⇒ String
Text content of the chunk.
-
#page_footers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter>
Page footers associated with the chunk.
-
#page_headers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader>
Page headers associated with the chunk.
-
#page_span ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
-
#source_block_ids ⇒ Array<String>
Unused.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
constructor
A new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk
Returns a new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunk.
3492 3493 3494 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunk_id ⇒ String
ID of the chunk.
Corresponds to the JSON property chunkId
3465 3466 3467 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3465 def chunk_id @chunk_id end |
#content ⇒ String
Text content of the chunk.
Corresponds to the JSON property content
3470 3471 3472 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3470 def content @content end |
#page_footers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageFooter>
Page footers associated with the chunk.
Corresponds to the JSON property pageFooters
3475 3476 3477 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3475 def @page_footers end |
#page_headers ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageHeader>
Page headers associated with the chunk.
Corresponds to the JSON property pageHeaders
3480 3481 3482 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3480 def page_headers @page_headers end |
#page_span ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkPageSpan
Represents where the chunk starts and ends in the document.
Corresponds to the JSON property pageSpan
3485 3486 3487 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3485 def page_span @page_span end |
#source_block_ids ⇒ Array<String>
Unused.
Corresponds to the JSON property sourceBlockIds
3490 3491 3492 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3490 def source_block_ids @source_block_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3497 def update!(**args) @chunk_id = args[:chunk_id] if args.key?(:chunk_id) @content = args[:content] if args.key?(:content) @page_footers = args[:page_footers] if args.key?(:page_footers) @page_headers = args[:page_headers] if args.key?(:page_headers) @page_span = args[:page_span] if args.key?(:page_span) @source_block_ids = args[:source_block_ids] if args.key?(:source_block_ids) end |