Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The image chunk field in the chunk.
Instance Attribute Summary collapse
-
#annotations ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentAnnotations
Represents the annotation of a block or a chunk.
-
#blob_asset_id ⇒ String
Optional.
-
#data_uri ⇒ String
Optional.
-
#gcs_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField
constructor
A new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField
Returns a new instance of GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField.
3703 3704 3705 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentAnnotations
Represents the annotation of a block or a chunk.
Corresponds to the JSON property annotations
3683 3684 3685 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3683 def annotations @annotations end |
#blob_asset_id ⇒ String
Optional. Asset id of the inline image. If set, find the image content in the
blob_assets field.
Corresponds to the JSON property blobAssetId
3689 3690 3691 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3689 def blob_asset_id @blob_asset_id end |
#data_uri ⇒ String
Optional. Data uri of the image. It is composed of four parts: a prefix (data:)
, a MIME type indicating the type of data, an optional base64 token if non-
textual, and the data itself: data:,
Corresponds to the JSON property dataUri
3696 3697 3698 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3696 def data_uri @data_uri end |
#gcs_uri ⇒ String
Optional. Google Cloud Storage uri of the image.
Corresponds to the JSON property gcsUri
3701 3702 3703 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3701 def gcs_uri @gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3708 3709 3710 3711 3712 3713 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3708 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @blob_asset_id = args[:blob_asset_id] if args.key?(:blob_asset_id) @data_uri = args[:data_uri] if args.key?(:data_uri) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) end |