Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Represents a block. A block could be one of the various types (text, table, list) supported.
Instance Attribute Summary collapse
-
#block_id ⇒ String
ID of the block.
-
#bounding_box ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BoundingPoly
A bounding polygon for the detected image annotation.
-
#list_block ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock
Represents a list type block.
-
#page_span ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan
Represents where the block starts and ends in the document.
-
#table_block ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
Represents a table type block.
-
#text_block ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
Represents a text type block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock
constructor
A new instance of GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock
Returns a new instance of GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock.
3637 3638 3639 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block_id ⇒ String
ID of the block.
Corresponds to the JSON property blockId
3610 3611 3612 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3610 def block_id @block_id end |
#bounding_box ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingBox
3615 3616 3617 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3615 def bounding_box @bounding_box end |
#list_block ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock
Represents a list type block.
Corresponds to the JSON property listBlock
3620 3621 3622 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3620 def list_block @list_block end |
#page_span ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan
Represents where the block starts and ends in the document.
Corresponds to the JSON property pageSpan
3625 3626 3627 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3625 def page_span @page_span end |
#table_block ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock
Represents a table type block.
Corresponds to the JSON property tableBlock
3630 3631 3632 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3630 def table_block @table_block end |
#text_block ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock
Represents a text type block.
Corresponds to the JSON property textBlock
3635 3636 3637 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3635 def text_block @text_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3642 3643 3644 3645 3646 3647 3648 3649 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3642 def update!(**args) @block_id = args[:block_id] if args.key?(:block_id) @bounding_box = args[:bounding_box] if args.key?(:bounding_box) @list_block = args[:list_block] if args.key?(:list_block) @page_span = args[:page_span] if args.key?(:page_span) @table_block = args[:table_block] if args.key?(:table_block) @text_block = args[:text_block] if args.key?(:text_block) end |