Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Parsed and normalized entity value.
Instance Attribute Summary collapse
-
#address_value ⇒ Google::Apis::DocumentaiV1::GoogleTypePostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
Boolean value.
-
#date_value ⇒ Google::Apis::DocumentaiV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#datetime_value ⇒ Google::Apis::DocumentaiV1::GoogleTypeDateTime
Represents civil time (or occasionally physical time).
-
#float_value ⇒ Float
Float value.
-
#integer_value ⇒ Fixnum
Integer value.
-
#money_value ⇒ Google::Apis::DocumentaiV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#signature_value ⇒ Boolean
(also: #signature_value?)
A signature - a graphical representation of a person's name, often used to sign a document.
-
#text ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
constructor
A new instance of GoogleCloudDocumentaiV1DocumentEntityNormalizedValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntityNormalizedValue
Returns a new instance of GoogleCloudDocumentaiV1DocumentEntityNormalizedValue.
4059 4060 4061 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_value ⇒ Google::Apis::DocumentaiV1::GoogleTypePostalAddress
Represents a postal address, such as for postal delivery or payments addresses.
With a postal address, a postal service can deliver items to a premise, P.O.
box, or similar. A postal address is not intended to model geographical
locations like roads, towns, or mountains. In typical usage, an address would
be created by user input or from importing existing data, depending on the
type of process. Advice on address input or editing: - Use an
internationalization-ready address widget such as https://github.com/google/
libaddressinput. - Users should not be presented with UI elements for input or
editing of fields outside countries where that field is used. For more
guidance on how to use this schema, see: https://support.google.com/business/
answer/6397478.
Corresponds to the JSON property addressValue
3987 3988 3989 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3987 def address_value @address_value end |
#boolean_value ⇒ Boolean Also known as: boolean_value?
Boolean value. Can be used for entities with binary values, or for checkboxes.
Corresponds to the JSON property booleanValue
3992 3993 3994 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 3992 def boolean_value @boolean_value end |
#date_value ⇒ Google::Apis::DocumentaiV1::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property dateValue
4005 4006 4007 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4005 def date_value @date_value end |
#datetime_value ⇒ Google::Apis::DocumentaiV1::GoogleTypeDateTime
Represents civil time (or occasionally physical time). This type can represent
a civil time in one of a few possible ways: * When utc_offset is set and
time_zone is unset: a civil time on a calendar day with a particular offset
from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
calendar day in a particular time zone. * When neither time_zone nor
utc_offset is set: a civil time on a calendar day in local time. The date is
relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
the DateTime is considered not to have a specific year, month, or day
respectively. This type may also be used to represent a physical time if all
the date and time fields are set and either case of the time_offset oneof is
set. Consider using Timestamp message for physical time instead. If your use
case also would like to store the user's timezone, that can be done in another
field. This type is more flexible than some applications may want. Make sure
to document and validate your application's limitations.
Corresponds to the JSON property datetimeValue
4023 4024 4025 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4023 def datetime_value @datetime_value end |
#float_value ⇒ Float
Float value.
Corresponds to the JSON property floatValue
4028 4029 4030 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4028 def float_value @float_value end |
#integer_value ⇒ Fixnum
Integer value.
Corresponds to the JSON property integerValue
4033 4034 4035 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4033 def integer_value @integer_value end |
#money_value ⇒ Google::Apis::DocumentaiV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property moneyValue
4038 4039 4040 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4038 def money_value @money_value end |
#signature_value ⇒ Boolean Also known as: signature_value?
A signature - a graphical representation of a person's name, often used to
sign a document.
Corresponds to the JSON property signatureValue
4044 4045 4046 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4044 def signature_value @signature_value end |
#text ⇒ String
Optional. An optional field to store a normalized string. For some entity
types, one of respective structured_value fields may also be populated. Also
not all the types of structured_value will be normalized. For example, some
processors may not generate float or integer normalized text by default.
Below are sample formats mapped to structured values. - Money/Currency type (
money_value) is in the ISO 4217 text format. - Date type (date_value) is in
the ISO 8601 text format. - Datetime type (datetime_value) is in the ISO
8601 text format.
Corresponds to the JSON property text
4057 4058 4059 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4057 def text @text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4064 def update!(**args) @address_value = args[:address_value] if args.key?(:address_value) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @date_value = args[:date_value] if args.key?(:date_value) @datetime_value = args[:datetime_value] if args.key?(:datetime_value) @float_value = args[:float_value] if args.key?(:float_value) @integer_value = args[:integer_value] if args.key?(:integer_value) @money_value = args[:money_value] if args.key?(:money_value) @signature_value = args[:signature_value] if args.key?(:signature_value) @text = args[:text] if args.key?(:text) end |