Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Validation result for a single validation rule.
Instance Attribute Summary collapse
-
#rule ⇒ String
Optional.
-
#rule_description ⇒ String
The description of the validation rule.
-
#rule_name ⇒ String
The display name of the validation rule.
-
#validation_details ⇒ String
The detailed information of the running the validation process using the entity from the document based on the validation rule.
-
#validation_result_type ⇒ String
The result of the validation rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult
constructor
A new instance of GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult
Returns a new instance of GoogleCloudDocumentaiV1DocumentEntityValidationOutputValidationResult.
4165 4166 4167 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rule ⇒ String
Optional. The name of the rule resource that is used for validation. Format:
projects/project/locations/location/rules/rule`
Corresponds to the JSON propertyrule`
4142 4143 4144 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4142 def rule @rule end |
#rule_description ⇒ String
The description of the validation rule.
Corresponds to the JSON property ruleDescription
4147 4148 4149 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4147 def rule_description @rule_description end |
#rule_name ⇒ String
The display name of the validation rule.
Corresponds to the JSON property ruleName
4152 4153 4154 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4152 def rule_name @rule_name end |
#validation_details ⇒ String
The detailed information of the running the validation process using the
entity from the document based on the validation rule.
Corresponds to the JSON property validationDetails
4158 4159 4160 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4158 def validation_details @validation_details end |
#validation_result_type ⇒ String
The result of the validation rule.
Corresponds to the JSON property validationResultType
4163 4164 4165 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4163 def validation_result_type @validation_result_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4170 4171 4172 4173 4174 4175 4176 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4170 def update!(**args) @rule = args[:rule] if args.key?(:rule) @rule_description = args[:rule_description] if args.key?(:rule_description) @rule_name = args[:rule_name] if args.key?(:rule_name) @validation_details = args[:validation_details] if args.key?(:validation_details) @validation_result_type = args[:validation_result_type] if args.key?(:validation_result_type) end |