Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPage
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
A page in a Document.
Instance Attribute Summary collapse
-
#blocks ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageBlock>
A list of visually detected text blocks on the page.
-
#detected_barcodes ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedBarcode>
A list of detected barcodes.
-
#detected_languages ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
-
#dimension ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDimension
Dimension for the page.
-
#form_fields ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageFormField>
A list of visually detected form fields on the page.
-
#image ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageImage
Rendered image contents for this page.
-
#image_quality_scores ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageImageQualityScores
Image quality scores for the page image.
-
#layout ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
-
#lines ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLine>
A list of visually detected text lines on the page.
-
#page_number ⇒ Fixnum
1-based index for current Page in a parent Document.
-
#paragraphs ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageParagraph>
A list of visually detected text paragraphs on the page.
-
#provenance ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
-
#symbols ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageSymbol>
A list of visually detected symbols on the page.
-
#tables ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageTable>
A list of visually detected tables on the page.
-
#tokens ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageToken>
A list of visually detected tokens on the page.
-
#transforms ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageMatrix>
Transformation matrices that were applied to the original document image to produce Page.image.
-
#visual_elements ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageVisualElement>
A list of detected non-text visual elements e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPage
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPage
Returns a new instance of GoogleCloudDocumentaiV1DocumentPage.
4354 4355 4356 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocks ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageBlock>
A list of visually detected text blocks on the page. A block has a set of
lines (collected into paragraphs) that have a common line-spacing and
orientation.
Corresponds to the JSON property blocks
4266 4267 4268 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4266 def blocks @blocks end |
#detected_barcodes ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedBarcode>
A list of detected barcodes.
Corresponds to the JSON property detectedBarcodes
4271 4272 4273 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4271 def @detected_barcodes end |
#detected_languages ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages together with confidence.
Corresponds to the JSON property detectedLanguages
4276 4277 4278 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4276 def detected_languages @detected_languages end |
#dimension ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDimension
Dimension for the page.
Corresponds to the JSON property dimension
4281 4282 4283 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4281 def dimension @dimension end |
#form_fields ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageFormField>
A list of visually detected form fields on the page.
Corresponds to the JSON property formFields
4286 4287 4288 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4286 def form_fields @form_fields end |
#image ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageImage
Rendered image contents for this page.
Corresponds to the JSON property image
4291 4292 4293 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4291 def image @image end |
#image_quality_scores ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageImageQualityScores
Image quality scores for the page image.
Corresponds to the JSON property imageQualityScores
4296 4297 4298 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4296 def image_quality_scores @image_quality_scores end |
#layout ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property layout
4301 4302 4303 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4301 def layout @layout end |
#lines ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLine>
A list of visually detected text lines on the page. A collection of tokens
that a human would perceive as a line.
Corresponds to the JSON property lines
4307 4308 4309 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4307 def lines @lines end |
#page_number ⇒ Fixnum
1-based index for current Page in a parent Document. Useful when a page is
taken out of a Document for individual processing.
Corresponds to the JSON property pageNumber
4313 4314 4315 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4313 def page_number @page_number end |
#paragraphs ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageParagraph>
A list of visually detected text paragraphs on the page. A collection of lines
that a human would perceive as a paragraph.
Corresponds to the JSON property paragraphs
4319 4320 4321 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4319 def paragraphs @paragraphs end |
#provenance ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
4325 4326 4327 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4325 def provenance @provenance end |
#symbols ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageSymbol>
A list of visually detected symbols on the page.
Corresponds to the JSON property symbols
4330 4331 4332 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4330 def symbols @symbols end |
#tables ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageTable>
A list of visually detected tables on the page.
Corresponds to the JSON property tables
4335 4336 4337 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4335 def tables @tables end |
#tokens ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageToken>
A list of visually detected tokens on the page.
Corresponds to the JSON property tokens
4340 4341 4342 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4340 def tokens @tokens end |
#transforms ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageMatrix>
Transformation matrices that were applied to the original document image to
produce Page.image.
Corresponds to the JSON property transforms
4346 4347 4348 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4346 def transforms @transforms end |
#visual_elements ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageVisualElement>
A list of detected non-text visual elements e.g. checkbox, signature etc. on
the page.
Corresponds to the JSON property visualElements
4352 4353 4354 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4352 def visual_elements @visual_elements end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4359 4360 4361 4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 4377 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4359 def update!(**args) @blocks = args[:blocks] if args.key?(:blocks) @detected_barcodes = args[:detected_barcodes] if args.key?(:detected_barcodes) @detected_languages = args[:detected_languages] if args.key?(:detected_languages) @dimension = args[:dimension] if args.key?(:dimension) @form_fields = args[:form_fields] if args.key?(:form_fields) @image = args[:image] if args.key?(:image) @image_quality_scores = args[:image_quality_scores] if args.key?(:image_quality_scores) @layout = args[:layout] if args.key?(:layout) @lines = args[:lines] if args.key?(:lines) @page_number = args[:page_number] if args.key?(:page_number) @paragraphs = args[:paragraphs] if args.key?(:paragraphs) @provenance = args[:provenance] if args.key?(:provenance) @symbols = args[:symbols] if args.key?(:symbols) @tables = args[:tables] if args.key?(:tables) @tokens = args[:tokens] if args.key?(:tokens) @transforms = args[:transforms] if args.key?(:transforms) @visual_elements = args[:visual_elements] if args.key?(:visual_elements) end |