Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageAnchorPageRef
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageAnchorPageRef
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Represents a weak reference to a page element within a document.
Instance Attribute Summary collapse
-
#bounding_poly ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BoundingPoly
A bounding polygon for the detected image annotation.
-
#confidence ⇒ Float
Optional.
-
#layout_id ⇒ String
Optional.
-
#layout_type ⇒ String
Optional.
-
#page ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageAnchorPageRef
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageAnchorPageRef.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageAnchorPageRef
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageAnchorPageRef.
4657 4658 4659 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounding_poly ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BoundingPoly
A bounding polygon for the detected image annotation.
Corresponds to the JSON property boundingPoly
4632 4633 4634 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4632 def bounding_poly @bounding_poly end |
#confidence ⇒ Float
Optional. Confidence of detected page element, if applicable. Range [0, 1].
Corresponds to the JSON property confidence
4637 4638 4639 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4637 def confidence @confidence end |
#layout_id ⇒ String
Optional. Deprecated. Use PageRef.bounding_poly instead.
Corresponds to the JSON property layoutId
4642 4643 4644 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4642 def layout_id @layout_id end |
#layout_type ⇒ String
Optional. The type of the layout element that is being referenced if any.
Corresponds to the JSON property layoutType
4647 4648 4649 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4647 def layout_type @layout_type end |
#page ⇒ Fixnum
Required. Index into the Document.pages element, for example using Document.
pages to locate the related page element. This field is skipped when its
value is the default 0. See https://developers.google.com/protocol-buffers/
docs/proto3#json.
Corresponds to the JSON property page
4655 4656 4657 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4655 def page @page end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4662 4663 4664 4665 4666 4667 4668 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4662 def update!(**args) @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly) @confidence = args[:confidence] if args.key?(:confidence) @layout_id = args[:layout_id] if args.key?(:layout_id) @layout_type = args[:layout_type] if args.key?(:layout_type) @page = args[:page] if args.key?(:page) end |