Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageAnchorPageRef

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Represents a weak reference to a page element within a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageAnchorPageRef

Returns a new instance of GoogleCloudDocumentaiV1DocumentPageAnchorPageRef.



4433
4434
4435
# File 'lib/google/apis/documentai_v1/classes.rb', line 4433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounding_polyGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1BoundingPoly

A bounding polygon for the detected image annotation. Corresponds to the JSON property boundingPoly



4408
4409
4410
# File 'lib/google/apis/documentai_v1/classes.rb', line 4408

def bounding_poly
  @bounding_poly
end

#confidenceFloat

Optional. Confidence of detected page element, if applicable. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


4413
4414
4415
# File 'lib/google/apis/documentai_v1/classes.rb', line 4413

def confidence
  @confidence
end

#layout_idString

Optional. Deprecated. Use PageRef.bounding_poly instead. Corresponds to the JSON property layoutId

Returns:

  • (String)


4418
4419
4420
# File 'lib/google/apis/documentai_v1/classes.rb', line 4418

def layout_id
  @layout_id
end

#layout_typeString

Optional. The type of the layout element that is being referenced if any. Corresponds to the JSON property layoutType

Returns:

  • (String)


4423
4424
4425
# File 'lib/google/apis/documentai_v1/classes.rb', line 4423

def layout_type
  @layout_type
end

#pageFixnum

Required. Index into the Document.pages element, for example using Document. pages to locate the related page element. This field is skipped when its value is the default 0. See https://developers.google.com/protocol-buffers/ docs/proto3#json. Corresponds to the JSON property page

Returns:

  • (Fixnum)


4431
4432
4433
# File 'lib/google/apis/documentai_v1/classes.rb', line 4431

def page
  @page
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4438
4439
4440
4441
4442
4443
4444
# File 'lib/google/apis/documentai_v1/classes.rb', line 4438

def update!(**args)
  @bounding_poly = args[:bounding_poly] if args.key?(:bounding_poly)
  @confidence = args[:confidence] if args.key?(:confidence)
  @layout_id = args[:layout_id] if args.key?(:layout_id)
  @layout_type = args[:layout_type] if args.key?(:layout_type)
  @page = args[:page] if args.key?(:page)
end