Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageFormField
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageFormField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
A form field detected on the page.
Instance Attribute Summary collapse
-
#corrected_key_text ⇒ String
Created for Labeling UI to export key text.
-
#corrected_value_text ⇒ String
Created for Labeling UI to export value text.
-
#field_name ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
-
#field_value ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
-
#name_detected_languages ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for name together with confidence.
-
#provenance ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in different revisions.
-
#value_detected_languages ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for value together with confidence.
-
#value_type ⇒ String
If the value is non-textual, this field represents the type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageFormField
constructor
A new instance of GoogleCloudDocumentaiV1DocumentPageFormField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentPageFormField
Returns a new instance of GoogleCloudDocumentaiV1DocumentPageFormField.
4613 4614 4615 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4613 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corrected_key_text ⇒ String
Created for Labeling UI to export key text. If corrections were made to the
text identified by the field_name.text_anchor, this field will contain the
correction.
Corresponds to the JSON property correctedKeyText
4571 4572 4573 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4571 def corrected_key_text @corrected_key_text end |
#corrected_value_text ⇒ String
Created for Labeling UI to export value text. If corrections were made to the
text identified by the field_value.text_anchor, this field will contain the
correction.
Corresponds to the JSON property correctedValueText
4578 4579 4580 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4578 def corrected_value_text @corrected_value_text end |
#field_name ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property fieldName
4583 4584 4585 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4583 def field_name @field_name end |
#field_value ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageLayout
Visual element describing a layout unit on a page.
Corresponds to the JSON property fieldValue
4588 4589 4590 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4588 def field_value @field_value end |
#name_detected_languages ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for name together with confidence.
Corresponds to the JSON property nameDetectedLanguages
4593 4594 4595 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4593 def name_detected_languages @name_detected_languages end |
#provenance ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenance
Structure to identify provenance relationships between annotations in
different revisions.
Corresponds to the JSON property provenance
4599 4600 4601 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4599 def provenance @provenance end |
#value_detected_languages ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentPageDetectedLanguage>
A list of detected languages for value together with confidence.
Corresponds to the JSON property valueDetectedLanguages
4604 4605 4606 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4604 def value_detected_languages @value_detected_languages end |
#value_type ⇒ String
If the value is non-textual, this field represents the type. Current valid
values are: - blank (this indicates the field_value is normal text) -
unfilled_checkbox - filled_checkbox
Corresponds to the JSON property valueType
4611 4612 4613 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4611 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 4618 def update!(**args) @corrected_key_text = args[:corrected_key_text] if args.key?(:corrected_key_text) @corrected_value_text = args[:corrected_value_text] if args.key?(:corrected_value_text) @field_name = args[:field_name] if args.key?(:field_name) @field_value = args[:field_value] if args.key?(:field_value) @name_detected_languages = args[:name_detected_languages] if args.key?(:name_detected_languages) @provenance = args[:provenance] if args.key?(:provenance) @value_detected_languages = args[:value_detected_languages] if args.key?(:value_detected_languages) @value_type = args[:value_type] if args.key?(:value_type) end |