Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentProvenanceParent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

The parent element the current element is based on. Used for referencing/ aligning, removal and replacement operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentProvenanceParent

Returns a new instance of GoogleCloudDocumentaiV1DocumentProvenanceParent.



5348
5349
5350
# File 'lib/google/apis/documentai_v1/classes.rb', line 5348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idFixnum

The id of the parent provenance. Corresponds to the JSON property id

Returns:

  • (Fixnum)


5335
5336
5337
# File 'lib/google/apis/documentai_v1/classes.rb', line 5335

def id
  @id
end

#indexFixnum

The index of the parent item in the corresponding item list (eg. list of entities, properties within entities, etc.) in the parent revision. Corresponds to the JSON property index

Returns:

  • (Fixnum)


5341
5342
5343
# File 'lib/google/apis/documentai_v1/classes.rb', line 5341

def index
  @index
end

#revisionFixnum

The index of the index into current revision's parent_ids list. Corresponds to the JSON property revision

Returns:

  • (Fixnum)


5346
5347
5348
# File 'lib/google/apis/documentai_v1/classes.rb', line 5346

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5353
5354
5355
5356
5357
# File 'lib/google/apis/documentai_v1/classes.rb', line 5353

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @index = args[:index] if args.key?(:index)
  @revision = args[:revision] if args.key?(:revision)
end