Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevision
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Contains past or forward revisions of this document.
Instance Attribute Summary collapse
-
#agent ⇒ String
If the change was made by a person specify the name or id of that person.
-
#create_time ⇒ String
The time that the revision was created, internally generated by doc proto storage at the time of create.
-
#human_review ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview
Human Review information of the document.
-
#id ⇒ String
Id of the revision, internally generated by doc proto storage.
-
#parent ⇒ Array<Fixnum>
The revisions that this revision is based on.
-
#parent_ids ⇒ Array<String>
The revisions that this revision is based on.
-
#processor ⇒ String
If the annotation was made by processor identify the processor by its resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentRevision
constructor
A new instance of GoogleCloudDocumentaiV1DocumentRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentRevision
Returns a new instance of GoogleCloudDocumentaiV1DocumentRevision.
5406 5407 5408 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
If the change was made by a person specify the name or id of that person.
Corresponds to the JSON property agent
5367 5368 5369 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5367 def agent @agent end |
#create_time ⇒ String
The time that the revision was created, internally generated by doc proto
storage at the time of create.
Corresponds to the JSON property createTime
5373 5374 5375 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5373 def create_time @create_time end |
#human_review ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentRevisionHumanReview
Human Review information of the document.
Corresponds to the JSON property humanReview
5378 5379 5380 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5378 def human_review @human_review end |
#id ⇒ String
Id of the revision, internally generated by doc proto storage. Unique within
the context of the document.
Corresponds to the JSON property id
5384 5385 5386 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5384 def id @id end |
#parent ⇒ Array<Fixnum>
The revisions that this revision is based on. This can include one or more
parent (when documents are merged.) This field represents the index into the
revisions field.
Corresponds to the JSON property parent
5391 5392 5393 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5391 def parent @parent end |
#parent_ids ⇒ Array<String>
The revisions that this revision is based on. Must include all the ids that
have anything to do with this revision - eg. there are provenance.parent.
revision fields that index into this field.
Corresponds to the JSON property parentIds
5398 5399 5400 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5398 def parent_ids @parent_ids end |
#processor ⇒ String
If the annotation was made by processor identify the processor by its resource
name.
Corresponds to the JSON property processor
5404 5405 5406 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5404 def processor @processor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5411 5412 5413 5414 5415 5416 5417 5418 5419 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5411 def update!(**args) @agent = args[:agent] if args.key?(:agent) @create_time = args[:create_time] if args.key?(:create_time) @human_review = args[:human_review] if args.key?(:human_review) @id = args[:id] if args.key?(:id) @parent = args[:parent] if args.key?(:parent) @parent_ids = args[:parent_ids] if args.key?(:parent_ids) @processor = args[:processor] if args.key?(:processor) end |