Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Defines properties that can be part of the entity type.
Instance Attribute Summary collapse
-
#display_name ⇒ String
User defined name for the property.
-
#method_prop ⇒ String
Specifies how the entity's value is obtained.
-
#name ⇒ String
The name of the property.
-
#occurrence_type ⇒ String
Occurrence type limits the number of instances an entity type appears in the document.
-
#value_type ⇒ String
A reference to the value type of the property.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
constructor
A new instance of GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty
Returns a new instance of GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty.
5596 5597 5598 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
User defined name for the property.
Corresponds to the JSON property displayName
5572 5573 5574 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5572 def display_name @display_name end |
#method_prop ⇒ String
Specifies how the entity's value is obtained.
Corresponds to the JSON property method
5577 5578 5579 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5577 def method_prop @method_prop end |
#name ⇒ String
The name of the property. Follows the same guidelines as the EntityType name.
Corresponds to the JSON property name
5582 5583 5584 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5582 def name @name end |
#occurrence_type ⇒ String
Occurrence type limits the number of instances an entity type appears in the
document.
Corresponds to the JSON property occurrenceType
5588 5589 5590 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5588 def occurrence_type @occurrence_type end |
#value_type ⇒ String
A reference to the value type of the property. This type is subject to the
same conventions as the Entity.base_types field.
Corresponds to the JSON property valueType
5594 5595 5596 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5594 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5601 5602 5603 5604 5605 5606 5607 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 5601 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @method_prop = args[:method_prop] if args.key?(:method_prop) @name = args[:name] if args.key?(:name) @occurrence_type = args[:occurrence_type] if args.key?(:occurrence_type) @value_type = args[:value_type] if args.key?(:value_type) end |