Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Defines properties that can be part of the entity type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty

Returns a new instance of GoogleCloudDocumentaiV1DocumentSchemaEntityTypeProperty.



5587
5588
5589
# File 'lib/google/apis/documentai_v1/classes.rb', line 5587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

User defined name for the property. Corresponds to the JSON property displayName

Returns:

  • (String)


5563
5564
5565
# File 'lib/google/apis/documentai_v1/classes.rb', line 5563

def display_name
  @display_name
end

#method_propString

Specifies how the entity's value is obtained. Corresponds to the JSON property method

Returns:

  • (String)


5568
5569
5570
# File 'lib/google/apis/documentai_v1/classes.rb', line 5568

def method_prop
  @method_prop
end

#nameString

The name of the property. Follows the same guidelines as the EntityType name. Corresponds to the JSON property name

Returns:

  • (String)


5573
5574
5575
# File 'lib/google/apis/documentai_v1/classes.rb', line 5573

def name
  @name
end

#occurrence_typeString

Occurrence type limits the number of instances an entity type appears in the document. Corresponds to the JSON property occurrenceType

Returns:

  • (String)


5579
5580
5581
# File 'lib/google/apis/documentai_v1/classes.rb', line 5579

def occurrence_type
  @occurrence_type
end

#value_typeString

A reference to the value type of the property. This type is subject to the same conventions as the Entity.base_types field. Corresponds to the JSON property valueType

Returns:

  • (String)


5585
5586
5587
# File 'lib/google/apis/documentai_v1/classes.rb', line 5585

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5592
5593
5594
5595
5596
5597
5598
# File 'lib/google/apis/documentai_v1/classes.rb', line 5592

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @name = args[:name] if args.key?(:name)
  @occurrence_type = args[:occurrence_type] if args.key?(:occurrence_type)
  @value_type = args[:value_type] if args.key?(:value_type)
end