Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchemaMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Metadata for global schema behavior.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentSchemaMetadata

Returns a new instance of GoogleCloudDocumentaiV1DocumentSchemaMetadata.



5642
5643
5644
# File 'lib/google/apis/documentai_v1/classes.rb', line 5642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_allow_multiple_labelsBoolean Also known as: document_allow_multiple_labels?

If true, on a given page, there can be multiple document annotations covering it. Corresponds to the JSON property documentAllowMultipleLabels

Returns:

  • (Boolean)


5618
5619
5620
# File 'lib/google/apis/documentai_v1/classes.rb', line 5618

def document_allow_multiple_labels
  @document_allow_multiple_labels
end

#document_splitterBoolean Also known as: document_splitter?

If true, a document entity type can be applied to subdocument (splitting). Otherwise, it can only be applied to the entire document (classification). Corresponds to the JSON property documentSplitter

Returns:

  • (Boolean)


5625
5626
5627
# File 'lib/google/apis/documentai_v1/classes.rb', line 5625

def document_splitter
  @document_splitter
end

#prefixed_naming_on_propertiesBoolean Also known as: prefixed_naming_on_properties?

If set, all the nested entities must be prefixed with the parents. Corresponds to the JSON property prefixedNamingOnProperties

Returns:

  • (Boolean)


5631
5632
5633
# File 'lib/google/apis/documentai_v1/classes.rb', line 5631

def prefixed_naming_on_properties
  @prefixed_naming_on_properties
end

#skip_naming_validationBoolean Also known as: skip_naming_validation?

If set, this will skip the naming format validation in the schema. So the string values in DocumentSchema.EntityType.name and DocumentSchema. EntityType.Property.name will not be checked. Corresponds to the JSON property skipNamingValidation

Returns:

  • (Boolean)


5639
5640
5641
# File 'lib/google/apis/documentai_v1/classes.rb', line 5639

def skip_naming_validation
  @skip_naming_validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5647
5648
5649
5650
5651
5652
# File 'lib/google/apis/documentai_v1/classes.rb', line 5647

def update!(**args)
  @document_allow_multiple_labels = args[:document_allow_multiple_labels] if args.key?(:document_allow_multiple_labels)
  @document_splitter = args[:document_splitter] if args.key?(:document_splitter)
  @prefixed_naming_on_properties = args[:prefixed_naming_on_properties] if args.key?(:prefixed_naming_on_properties)
  @skip_naming_validation = args[:skip_naming_validation] if args.key?(:skip_naming_validation)
end