Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentShardInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

For a large document, sharding may be performed to produce several document shards. Each document shard contains this field to detail which shard it is.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1DocumentShardInfo

Returns a new instance of GoogleCloudDocumentaiV1DocumentShardInfo.



5667
5668
5669
# File 'lib/google/apis/documentai_v1/classes.rb', line 5667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#shard_countFixnum

Total number of shards. Corresponds to the JSON property shardCount

Returns:

  • (Fixnum)


5654
5655
5656
# File 'lib/google/apis/documentai_v1/classes.rb', line 5654

def shard_count
  @shard_count
end

#shard_indexFixnum

The 0-based index of this shard. Corresponds to the JSON property shardIndex

Returns:

  • (Fixnum)


5659
5660
5661
# File 'lib/google/apis/documentai_v1/classes.rb', line 5659

def shard_index
  @shard_index
end

#text_offsetFixnum

The index of the first character in Document.text in the overall document global text. Corresponds to the JSON property textOffset

Returns:

  • (Fixnum)


5665
5666
5667
# File 'lib/google/apis/documentai_v1/classes.rb', line 5665

def text_offset
  @text_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5672
5673
5674
5675
5676
# File 'lib/google/apis/documentai_v1/classes.rb', line 5672

def update!(**args)
  @shard_count = args[:shard_count] if args.key?(:shard_count)
  @shard_index = args[:shard_index] if args.key?(:shard_index)
  @text_offset = args[:text_offset] if args.key?(:text_offset)
end