Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Evaluation metrics, either in aggregate or about a specific entity.
Instance Attribute Summary collapse
-
#f1_score ⇒ Float
The calculated F1 score.
-
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
-
#false_positives_count ⇒ Fixnum
The amount of false positives.
-
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
-
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
-
#precision ⇒ Float
The calculated precision.
-
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
-
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
-
#recall ⇒ Float
The calculated recall.
-
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
-
#true_positives_count ⇒ Fixnum
The amount of true positives.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationMetrics
constructor
A new instance of GoogleCloudDocumentaiV1EvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationMetrics
Returns a new instance of GoogleCloudDocumentaiV1EvaluationMetrics.
6303 6304 6305 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#f1_score ⇒ Float
The calculated F1 score.
Corresponds to the JSON property f1Score
6251 6252 6253 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6251 def f1_score @f1_score end |
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
Corresponds to the JSON property falseNegativesCount
6256 6257 6258 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6256 def false_negatives_count @false_negatives_count end |
#false_positives_count ⇒ Fixnum
The amount of false positives.
Corresponds to the JSON property falsePositivesCount
6261 6262 6263 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6261 def false_positives_count @false_positives_count end |
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
Corresponds to the JSON property groundTruthDocumentCount
6266 6267 6268 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6266 def ground_truth_document_count @ground_truth_document_count end |
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
Corresponds to the JSON property groundTruthOccurrencesCount
6271 6272 6273 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6271 def ground_truth_occurrences_count @ground_truth_occurrences_count end |
#precision ⇒ Float
The calculated precision.
Corresponds to the JSON property precision
6276 6277 6278 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6276 def precision @precision end |
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
Corresponds to the JSON property predictedDocumentCount
6281 6282 6283 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6281 def predicted_document_count @predicted_document_count end |
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
Corresponds to the JSON property predictedOccurrencesCount
6286 6287 6288 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6286 def predicted_occurrences_count @predicted_occurrences_count end |
#recall ⇒ Float
The calculated recall.
Corresponds to the JSON property recall
6291 6292 6293 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6291 def recall @recall end |
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
Corresponds to the JSON property totalDocumentsCount
6296 6297 6298 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6296 def total_documents_count @total_documents_count end |
#true_positives_count ⇒ Fixnum
The amount of true positives.
Corresponds to the JSON property truePositivesCount
6301 6302 6303 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6301 def true_positives_count @true_positives_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6308 6309 6310 6311 6312 6313 6314 6315 6316 6317 6318 6319 6320 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6308 def update!(**args) @f1_score = args[:f1_score] if args.key?(:f1_score) @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count) @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count) @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count) @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count) @precision = args[:precision] if args.key?(:precision) @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count) @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count) @recall = args[:recall] if args.key?(:recall) @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count) @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count) end |