Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Evaluation metrics, either in aggregate or about a specific entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationMetrics

Returns a new instance of GoogleCloudDocumentaiV1EvaluationMetrics.



6244
6245
6246
# File 'lib/google/apis/documentai_v1/classes.rb', line 6244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#f1_scoreFloat

The calculated f1 score. Corresponds to the JSON property f1Score

Returns:

  • (Float)


6192
6193
6194
# File 'lib/google/apis/documentai_v1/classes.rb', line 6192

def f1_score
  @f1_score
end

#false_negatives_countFixnum

The amount of false negatives. Corresponds to the JSON property falseNegativesCount

Returns:

  • (Fixnum)


6197
6198
6199
# File 'lib/google/apis/documentai_v1/classes.rb', line 6197

def false_negatives_count
  @false_negatives_count
end

#false_positives_countFixnum

The amount of false positives. Corresponds to the JSON property falsePositivesCount

Returns:

  • (Fixnum)


6202
6203
6204
# File 'lib/google/apis/documentai_v1/classes.rb', line 6202

def false_positives_count
  @false_positives_count
end

#ground_truth_document_countFixnum

The amount of documents with a ground truth occurrence. Corresponds to the JSON property groundTruthDocumentCount

Returns:

  • (Fixnum)


6207
6208
6209
# File 'lib/google/apis/documentai_v1/classes.rb', line 6207

def ground_truth_document_count
  @ground_truth_document_count
end

#ground_truth_occurrences_countFixnum

The amount of occurrences in ground truth documents. Corresponds to the JSON property groundTruthOccurrencesCount

Returns:

  • (Fixnum)


6212
6213
6214
# File 'lib/google/apis/documentai_v1/classes.rb', line 6212

def ground_truth_occurrences_count
  @ground_truth_occurrences_count
end

#precisionFloat

The calculated precision. Corresponds to the JSON property precision

Returns:

  • (Float)


6217
6218
6219
# File 'lib/google/apis/documentai_v1/classes.rb', line 6217

def precision
  @precision
end

#predicted_document_countFixnum

The amount of documents with a predicted occurrence. Corresponds to the JSON property predictedDocumentCount

Returns:

  • (Fixnum)


6222
6223
6224
# File 'lib/google/apis/documentai_v1/classes.rb', line 6222

def predicted_document_count
  @predicted_document_count
end

#predicted_occurrences_countFixnum

The amount of occurrences in predicted documents. Corresponds to the JSON property predictedOccurrencesCount

Returns:

  • (Fixnum)


6227
6228
6229
# File 'lib/google/apis/documentai_v1/classes.rb', line 6227

def predicted_occurrences_count
  @predicted_occurrences_count
end

#recallFloat

The calculated recall. Corresponds to the JSON property recall

Returns:

  • (Float)


6232
6233
6234
# File 'lib/google/apis/documentai_v1/classes.rb', line 6232

def recall
  @recall
end

#total_documents_countFixnum

The amount of documents that had an occurrence of this label. Corresponds to the JSON property totalDocumentsCount

Returns:

  • (Fixnum)


6237
6238
6239
# File 'lib/google/apis/documentai_v1/classes.rb', line 6237

def total_documents_count
  @total_documents_count
end

#true_positives_countFixnum

The amount of true positives. Corresponds to the JSON property truePositivesCount

Returns:

  • (Fixnum)


6242
6243
6244
# File 'lib/google/apis/documentai_v1/classes.rb', line 6242

def true_positives_count
  @true_positives_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6249
6250
6251
6252
6253
6254
6255
6256
6257
6258
6259
6260
6261
# File 'lib/google/apis/documentai_v1/classes.rb', line 6249

def update!(**args)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count)
  @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count)
  @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count)
  @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count)
  @precision = args[:precision] if args.key?(:precision)
  @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count)
  @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count)
  @recall = args[:recall] if args.key?(:recall)
  @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count)
  @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count)
end