Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Metrics across multiple confidence levels.
Instance Attribute Summary collapse
-
#auprc ⇒ Float
The calculated area under the precision recall curve (AUPRC), computed by integrating over all confidence thresholds.
-
#auprc_exact ⇒ Float
The AUPRC for metrics with fuzzy matching disabled, i.e., exact matching only.
-
#confidence_level_metrics ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics>
Metrics across confidence levels with fuzzy matching enabled.
-
#confidence_level_metrics_exact ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics>
Metrics across confidence levels with only exact matching.
-
#estimated_calibration_error ⇒ Float
The Estimated Calibration Error (ECE) of the confidence of the predicted entities.
-
#estimated_calibration_error_exact ⇒ Float
The ECE for the predicted entities with fuzzy matching disabled, i.e., exact matching only.
-
#metrics_type ⇒ String
The metrics type for the label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics
constructor
A new instance of GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics
Returns a new instance of GoogleCloudDocumentaiV1EvaluationMultiConfidenceMetrics.
6365 6366 6367 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auprc ⇒ Float
The calculated area under the precision recall curve (AUPRC), computed by
integrating over all confidence thresholds.
Corresponds to the JSON property auprc
6331 6332 6333 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6331 def auprc @auprc end |
#auprc_exact ⇒ Float
The AUPRC for metrics with fuzzy matching disabled, i.e., exact matching only.
Corresponds to the JSON property auprcExact
6336 6337 6338 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6336 def auprc_exact @auprc_exact end |
#confidence_level_metrics ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics>
Metrics across confidence levels with fuzzy matching enabled.
Corresponds to the JSON property confidenceLevelMetrics
6341 6342 6343 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6341 def confidence_level_metrics @confidence_level_metrics end |
#confidence_level_metrics_exact ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationConfidenceLevelMetrics>
Metrics across confidence levels with only exact matching.
Corresponds to the JSON property confidenceLevelMetricsExact
6346 6347 6348 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6346 def confidence_level_metrics_exact @confidence_level_metrics_exact end |
#estimated_calibration_error ⇒ Float
The Estimated Calibration Error (ECE) of the confidence of the predicted
entities.
Corresponds to the JSON property estimatedCalibrationError
6352 6353 6354 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6352 def estimated_calibration_error @estimated_calibration_error end |
#estimated_calibration_error_exact ⇒ Float
The ECE for the predicted entities with fuzzy matching disabled, i.e., exact
matching only.
Corresponds to the JSON property estimatedCalibrationErrorExact
6358 6359 6360 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6358 def estimated_calibration_error_exact @estimated_calibration_error_exact end |
#metrics_type ⇒ String
The metrics type for the label.
Corresponds to the JSON property metricsType
6363 6364 6365 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6363 def metrics_type @metrics_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6370 6371 6372 6373 6374 6375 6376 6377 6378 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6370 def update!(**args) @auprc = args[:auprc] if args.key?(:auprc) @auprc_exact = args[:auprc_exact] if args.key?(:auprc_exact) @confidence_level_metrics = args[:confidence_level_metrics] if args.key?(:confidence_level_metrics) @confidence_level_metrics_exact = args[:confidence_level_metrics_exact] if args.key?(:confidence_level_metrics_exact) @estimated_calibration_error = args[:estimated_calibration_error] if args.key?(:estimated_calibration_error) @estimated_calibration_error_exact = args[:estimated_calibration_error_exact] if args.key?(:estimated_calibration_error_exact) @metrics_type = args[:metrics_type] if args.key?(:metrics_type) end |