Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationReference
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Gives a short summary of an evaluation, and links to the evaluation itself.
Instance Attribute Summary collapse
-
#aggregate_metrics ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
-
#aggregate_metrics_exact ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
-
#evaluation ⇒ String
The resource name of the evaluation.
-
#operation ⇒ String
The resource name of the Long Running Operation for the evaluation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationReference
constructor
A new instance of GoogleCloudDocumentaiV1EvaluationReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1EvaluationReference
Returns a new instance of GoogleCloudDocumentaiV1EvaluationReference.
6346 6347 6348 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_metrics ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
Corresponds to the JSON property aggregateMetrics
6329 6330 6331 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6329 def aggregate_metrics @aggregate_metrics end |
#aggregate_metrics_exact ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationMetrics
Evaluation metrics, either in aggregate or about a specific entity.
Corresponds to the JSON property aggregateMetricsExact
6334 6335 6336 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6334 def aggregate_metrics_exact @aggregate_metrics_exact end |
#evaluation ⇒ String
The resource name of the evaluation.
Corresponds to the JSON property evaluation
6339 6340 6341 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6339 def evaluation @evaluation end |
#operation ⇒ String
The resource name of the Long Running Operation for the evaluation.
Corresponds to the JSON property operation
6344 6345 6346 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6344 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6351 6352 6353 6354 6355 6356 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6351 def update!(**args) @aggregate_metrics = args[:aggregate_metrics] if args.key?(:aggregate_metrics) @aggregate_metrics_exact = args[:aggregate_metrics_exact] if args.key?(:aggregate_metrics_exact) @evaluation = args[:evaluation] if args.key?(:evaluation) @operation = args[:operation] if args.key?(:operation) end |