Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GenerateSchemaVersionRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Request message for GenerateSchemaVersion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1GenerateSchemaVersionRequest

Returns a new instance of GoogleCloudDocumentaiV1GenerateSchemaVersionRequest.



6477
6478
6479
# File 'lib/google/apis/documentai_v1/classes.rb', line 6477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_schema_versionString

The base schema version name to use for the schema generation. Format: projects/project/locations/location/schemas/schema/schemaVersions/ schema_version` Corresponds to the JSON propertybaseSchemaVersion`

Returns:

  • (String)


6450
6451
6452
# File 'lib/google/apis/documentai_v1/classes.rb', line 6450

def base_schema_version
  @base_schema_version
end

#gcs_documentsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GcsDocuments

Specifies a set of documents on Cloud Storage. Corresponds to the JSON property gcsDocuments



6455
6456
6457
# File 'lib/google/apis/documentai_v1/classes.rb', line 6455

def gcs_documents
  @gcs_documents
end

#gcs_prefixGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GcsPrefix

Specifies all documents on Cloud Storage with a common prefix. Corresponds to the JSON property gcsPrefix



6460
6461
6462
# File 'lib/google/apis/documentai_v1/classes.rb', line 6460

def gcs_prefix
  @gcs_prefix
end

#generate_schema_version_paramsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GenerateSchemaVersionRequestGenerateSchemaVersionParams

The parameters for the schema generation. Corresponds to the JSON property generateSchemaVersionParams



6465
6466
6467
# File 'lib/google/apis/documentai_v1/classes.rb', line 6465

def generate_schema_version_params
  @generate_schema_version_params
end

#inline_documentsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Documents

A set of inline documents. Corresponds to the JSON property inlineDocuments



6470
6471
6472
# File 'lib/google/apis/documentai_v1/classes.rb', line 6470

def inline_documents
  @inline_documents
end

#raw_documentsGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1RawDocuments

Specifies a set of raw documents. Corresponds to the JSON property rawDocuments



6475
6476
6477
# File 'lib/google/apis/documentai_v1/classes.rb', line 6475

def raw_documents
  @raw_documents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6482
6483
6484
6485
6486
6487
6488
6489
# File 'lib/google/apis/documentai_v1/classes.rb', line 6482

def update!(**args)
  @base_schema_version = args[:base_schema_version] if args.key?(:base_schema_version)
  @gcs_documents = args[:gcs_documents] if args.key?(:gcs_documents)
  @gcs_prefix = args[:gcs_prefix] if args.key?(:gcs_prefix)
  @generate_schema_version_params = args[:generate_schema_version_params] if args.key?(:generate_schema_version_params)
  @inline_documents = args[:inline_documents] if args.key?(:inline_documents)
  @raw_documents = args[:raw_documents] if args.key?(:raw_documents)
end