Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfigHints
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfigHints
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Hints for OCR Engine
Instance Attribute Summary collapse
-
#language_hints ⇒ Array<String>
List of BCP-47 language codes to use for OCR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1OcrConfigHints
constructor
A new instance of GoogleCloudDocumentaiV1OcrConfigHints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1OcrConfigHints
Returns a new instance of GoogleCloudDocumentaiV1OcrConfigHints.
6880 6881 6882 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6880 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_hints ⇒ Array<String>
List of BCP-47 language codes to use for OCR. In most cases, not specifying it
yields the best results since it enables automatic language detection. For
languages based on the Latin alphabet, setting hints is not needed. In rare
cases, when the language of the text in the image is known, setting a hint
will help get better results (although it will be a significant hindrance if
the hint is wrong).
Corresponds to the JSON property languageHints
6878 6879 6880 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6878 def language_hints @language_hints end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6885 6886 6887 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 6885 def update!(**args) @language_hints = args[:language_hints] if args.key?(:language_hints) end |