Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Options for Process API

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptions

Returns a new instance of GoogleCloudDocumentaiV1ProcessOptions.



7019
7020
7021
# File 'lib/google/apis/documentai_v1/classes.rb', line 7019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#from_endFixnum

Only process certain pages from the end, same as above. Corresponds to the JSON property fromEnd

Returns:

  • (Fixnum)


6991
6992
6993
# File 'lib/google/apis/documentai_v1/classes.rb', line 6991

def from_end
  @from_end
end

#from_startFixnum

Only process certain pages from the start. Process all if the document has fewer pages. Corresponds to the JSON property fromStart

Returns:

  • (Fixnum)


6997
6998
6999
# File 'lib/google/apis/documentai_v1/classes.rb', line 6997

def from_start
  @from_start
end

#individual_page_selectorGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsIndividualPageSelector

A list of individual page numbers. Corresponds to the JSON property individualPageSelector



7002
7003
7004
# File 'lib/google/apis/documentai_v1/classes.rb', line 7002

def individual_page_selector
  @individual_page_selector
end

#layout_configGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig

Serving config for layout parser processor. Corresponds to the JSON property layoutConfig



7007
7008
7009
# File 'lib/google/apis/documentai_v1/classes.rb', line 7007

def layout_config
  @layout_config
end

#ocr_configGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfig

Config for Document OCR. Corresponds to the JSON property ocrConfig



7012
7013
7014
# File 'lib/google/apis/documentai_v1/classes.rb', line 7012

def ocr_config
  @ocr_config
end

#schema_overrideGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property schemaOverride



7017
7018
7019
# File 'lib/google/apis/documentai_v1/classes.rb', line 7017

def schema_override
  @schema_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7024
7025
7026
7027
7028
7029
7030
7031
# File 'lib/google/apis/documentai_v1/classes.rb', line 7024

def update!(**args)
  @from_end = args[:from_end] if args.key?(:from_end)
  @from_start = args[:from_start] if args.key?(:from_start)
  @individual_page_selector = args[:individual_page_selector] if args.key?(:individual_page_selector)
  @layout_config = args[:layout_config] if args.key?(:layout_config)
  @ocr_config = args[:ocr_config] if args.key?(:ocr_config)
  @schema_override = args[:schema_override] if args.key?(:schema_override)
end