Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Options for Process API

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptions

Returns a new instance of GoogleCloudDocumentaiV1ProcessOptions.



6960
6961
6962
# File 'lib/google/apis/documentai_v1/classes.rb', line 6960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#from_endFixnum

Only process certain pages from the end, same as above. Corresponds to the JSON property fromEnd

Returns:

  • (Fixnum)


6932
6933
6934
# File 'lib/google/apis/documentai_v1/classes.rb', line 6932

def from_end
  @from_end
end

#from_startFixnum

Only process certain pages from the start. Process all if the document has fewer pages. Corresponds to the JSON property fromStart

Returns:

  • (Fixnum)


6938
6939
6940
# File 'lib/google/apis/documentai_v1/classes.rb', line 6938

def from_start
  @from_start
end

#individual_page_selectorGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsIndividualPageSelector

A list of individual page numbers. Corresponds to the JSON property individualPageSelector



6943
6944
6945
# File 'lib/google/apis/documentai_v1/classes.rb', line 6943

def individual_page_selector
  @individual_page_selector
end

#layout_configGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig

Serving config for layout parser processor. Corresponds to the JSON property layoutConfig



6948
6949
6950
# File 'lib/google/apis/documentai_v1/classes.rb', line 6948

def layout_config
  @layout_config
end

#ocr_configGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1OcrConfig

Config for Document OCR. Corresponds to the JSON property ocrConfig



6953
6954
6955
# File 'lib/google/apis/documentai_v1/classes.rb', line 6953

def ocr_config
  @ocr_config
end

#schema_overrideGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property schemaOverride



6958
6959
6960
# File 'lib/google/apis/documentai_v1/classes.rb', line 6958

def schema_override
  @schema_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6965
6966
6967
6968
6969
6970
6971
6972
# File 'lib/google/apis/documentai_v1/classes.rb', line 6965

def update!(**args)
  @from_end = args[:from_end] if args.key?(:from_end)
  @from_start = args[:from_start] if args.key?(:from_start)
  @individual_page_selector = args[:individual_page_selector] if args.key?(:individual_page_selector)
  @layout_config = args[:layout_config] if args.key?(:layout_config)
  @ocr_config = args[:ocr_config] if args.key?(:ocr_config)
  @schema_override = args[:schema_override] if args.key?(:schema_override)
end