Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Serving config for layout parser processor.
Instance Attribute Summary collapse
-
#chunking_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig
Serving config for chunking.
-
#enable_image_annotation ⇒ Boolean
(also: #enable_image_annotation?)
Optional.
-
#enable_table_annotation ⇒ Boolean
(also: #enable_table_annotation?)
Optional.
-
#return_bounding_boxes ⇒ Boolean
(also: #return_bounding_boxes?)
Optional.
-
#return_images ⇒ Boolean
(also: #return_images?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
constructor
A new instance of GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
Returns a new instance of GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig.
7311 7312 7313 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunking_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig
Serving config for chunking.
Corresponds to the JSON property chunkingConfig
7284 7285 7286 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7284 def chunking_config @chunking_config end |
#enable_image_annotation ⇒ Boolean Also known as: enable_image_annotation?
Optional. Whether to include image annotations in layout parser response.
Corresponds to the JSON property enableImageAnnotation
7289 7290 7291 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7289 def enable_image_annotation @enable_image_annotation end |
#enable_table_annotation ⇒ Boolean Also known as: enable_table_annotation?
Optional. Whether to include table annotations in layout parser response.
Corresponds to the JSON property enableTableAnnotation
7295 7296 7297 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7295 def enable_table_annotation @enable_table_annotation end |
#return_bounding_boxes ⇒ Boolean Also known as: return_bounding_boxes?
Optional. Whether to include bounding boxes in layout parser processor
response.
Corresponds to the JSON property returnBoundingBoxes
7302 7303 7304 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7302 def return_bounding_boxes @return_bounding_boxes end |
#return_images ⇒ Boolean Also known as: return_images?
Optional. Whether to include images in layout parser processor response.
Corresponds to the JSON property returnImages
7308 7309 7310 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7308 def return_images @return_images end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7316 7317 7318 7319 7320 7321 7322 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7316 def update!(**args) @chunking_config = args[:chunking_config] if args.key?(:chunking_config) @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation) @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation) @return_bounding_boxes = args[:return_bounding_boxes] if args.key?(:return_bounding_boxes) @return_images = args[:return_images] if args.key?(:return_images) end |