Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Serving config for layout parser processor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig

Returns a new instance of GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig.



7087
7088
7089
# File 'lib/google/apis/documentai_v1/classes.rb', line 7087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunking_configGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig

Serving config for chunking. Corresponds to the JSON property chunkingConfig



7060
7061
7062
# File 'lib/google/apis/documentai_v1/classes.rb', line 7060

def chunking_config
  @chunking_config
end

#enable_image_annotationBoolean Also known as: enable_image_annotation?

Optional. Whether to include image annotations in layout parser response. Corresponds to the JSON property enableImageAnnotation

Returns:

  • (Boolean)


7065
7066
7067
# File 'lib/google/apis/documentai_v1/classes.rb', line 7065

def enable_image_annotation
  @enable_image_annotation
end

#enable_table_annotationBoolean Also known as: enable_table_annotation?

Optional. Whether to include table annotations in layout parser response. Corresponds to the JSON property enableTableAnnotation

Returns:

  • (Boolean)


7071
7072
7073
# File 'lib/google/apis/documentai_v1/classes.rb', line 7071

def enable_table_annotation
  @enable_table_annotation
end

#return_bounding_boxesBoolean Also known as: return_bounding_boxes?

Optional. Whether to include bounding boxes in layout parser processor response. Corresponds to the JSON property returnBoundingBoxes

Returns:

  • (Boolean)


7078
7079
7080
# File 'lib/google/apis/documentai_v1/classes.rb', line 7078

def return_bounding_boxes
  @return_bounding_boxes
end

#return_imagesBoolean Also known as: return_images?

Optional. Whether to include images in layout parser processor response. Corresponds to the JSON property returnImages

Returns:

  • (Boolean)


7084
7085
7086
# File 'lib/google/apis/documentai_v1/classes.rb', line 7084

def return_images
  @return_images
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7092
7093
7094
7095
7096
7097
7098
# File 'lib/google/apis/documentai_v1/classes.rb', line 7092

def update!(**args)
  @chunking_config = args[:chunking_config] if args.key?(:chunking_config)
  @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation)
  @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation)
  @return_bounding_boxes = args[:return_bounding_boxes] if args.key?(:return_bounding_boxes)
  @return_images = args[:return_images] if args.key?(:return_images)
end