Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Serving config for layout parser processor.
Instance Attribute Summary collapse
-
#chunking_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig
Serving config for chunking.
-
#enable_image_annotation ⇒ Boolean
(also: #enable_image_annotation?)
Optional.
-
#enable_table_annotation ⇒ Boolean
(also: #enable_table_annotation?)
Optional.
-
#return_bounding_boxes ⇒ Boolean
(also: #return_bounding_boxes?)
Optional.
-
#return_images ⇒ Boolean
(also: #return_images?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
constructor
A new instance of GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig
Returns a new instance of GoogleCloudDocumentaiV1ProcessOptionsLayoutConfig.
7028 7029 7030 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chunking_config ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig
Serving config for chunking.
Corresponds to the JSON property chunkingConfig
7001 7002 7003 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7001 def chunking_config @chunking_config end |
#enable_image_annotation ⇒ Boolean Also known as: enable_image_annotation?
Optional. Whether to include image annotations in layout parser response.
Corresponds to the JSON property enableImageAnnotation
7006 7007 7008 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7006 def enable_image_annotation @enable_image_annotation end |
#enable_table_annotation ⇒ Boolean Also known as: enable_table_annotation?
Optional. Whether to include table annotations in layout parser response.
Corresponds to the JSON property enableTableAnnotation
7012 7013 7014 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7012 def enable_table_annotation @enable_table_annotation end |
#return_bounding_boxes ⇒ Boolean Also known as: return_bounding_boxes?
Optional. Whether to include bounding boxes in layout parser processor
response.
Corresponds to the JSON property returnBoundingBoxes
7019 7020 7021 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7019 def return_bounding_boxes @return_bounding_boxes end |
#return_images ⇒ Boolean Also known as: return_images?
Optional. Whether to include images in layout parser processor response.
Corresponds to the JSON property returnImages
7025 7026 7027 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7025 def return_images @return_images end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7033 7034 7035 7036 7037 7038 7039 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7033 def update!(**args) @chunking_config = args[:chunking_config] if args.key?(:chunking_config) @enable_image_annotation = args[:enable_image_annotation] if args.key?(:enable_image_annotation) @enable_table_annotation = args[:enable_table_annotation] if args.key?(:enable_table_annotation) @return_bounding_boxes = args[:return_bounding_boxes] if args.key?(:return_bounding_boxes) @return_images = args[:return_images] if args.key?(:return_images) end |