Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Request message for the ProcessDocument method.
Instance Attribute Summary collapse
-
#field_mask ⇒ String
Specifies which fields to include in the ProcessResponse.document output.
-
#gcs_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GcsDocument
Specifies a document stored on Cloud Storage.
-
#imageless_mode ⇒ Boolean
(also: #imageless_mode?)
Optional.
-
#inline_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document
Document represents the canonical document resource in Document AI.
-
#labels ⇒ Hash<String,String>
Optional.
-
#process_options ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions
Options for Process API Corresponds to the JSON property
processOptions. -
#raw_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1RawDocument
Payload message of raw document content (bytes).
-
#skip_human_review ⇒ Boolean
(also: #skip_human_review?)
Whether human review should be skipped for this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessRequest
constructor
A new instance of GoogleCloudDocumentaiV1ProcessRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessRequest
Returns a new instance of GoogleCloudDocumentaiV1ProcessRequest.
7182 7183 7184 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_mask ⇒ String
Specifies which fields to include in the ProcessResponse.document output. Only
supports top-level document and pages field, so it must be in the form of
document_field_name or pages.page_field_name`.
Corresponds to the JSON propertyfieldMask`
7136 7137 7138 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7136 def field_mask @field_mask end |
#gcs_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1GcsDocument
Specifies a document stored on Cloud Storage.
Corresponds to the JSON property gcsDocument
7141 7142 7143 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7141 def gcs_document @gcs_document end |
#imageless_mode ⇒ Boolean Also known as: imageless_mode?
Optional. Option to remove images from the document.
Corresponds to the JSON property imagelessMode
7146 7147 7148 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7146 def imageless_mode @imageless_mode end |
#inline_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property inlineDocument
7155 7156 7157 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7155 def inline_document @inline_document end |
#labels ⇒ Hash<String,String>
Optional. The labels with user-defined metadata for the request. Label keys
and values can be no longer than 63 characters (Unicode codepoints) and can
only contain lowercase letters, numeric characters, underscores, and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter.
Corresponds to the JSON property labels
7164 7165 7166 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7164 def labels @labels end |
#process_options ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessOptions
Options for Process API
Corresponds to the JSON property processOptions
7169 7170 7171 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7169 def @process_options end |
#raw_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1RawDocument
Payload message of raw document content (bytes).
Corresponds to the JSON property rawDocument
7174 7175 7176 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7174 def raw_document @raw_document end |
#skip_human_review ⇒ Boolean Also known as: skip_human_review?
Whether human review should be skipped for this request. Default to false.
Corresponds to the JSON property skipHumanReview
7179 7180 7181 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7179 def skip_human_review @skip_human_review end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7187 7188 7189 7190 7191 7192 7193 7194 7195 7196 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7187 def update!(**args) @field_mask = args[:field_mask] if args.key?(:field_mask) @gcs_document = args[:gcs_document] if args.key?(:gcs_document) @imageless_mode = args[:imageless_mode] if args.key?(:imageless_mode) @inline_document = args[:inline_document] if args.key?(:inline_document) @labels = args[:labels] if args.key?(:labels) @process_options = args[:process_options] if args.key?(:process_options) @raw_document = args[:raw_document] if args.key?(:raw_document) @skip_human_review = args[:skip_human_review] if args.key?(:skip_human_review) end |