Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessResponse
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Response message for the ProcessDocument method.
Instance Attribute Summary collapse
-
#document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document
Document represents the canonical document resource in Document AI.
-
#human_review_status ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1HumanReviewStatus
The status of human review on a processed document.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessResponse
constructor
A new instance of GoogleCloudDocumentaiV1ProcessResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessResponse
Returns a new instance of GoogleCloudDocumentaiV1ProcessResponse.
7216 7217 7218 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property document
7209 7210 7211 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7209 def document @document end |
#human_review_status ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1HumanReviewStatus
The status of human review on a processed document.
Corresponds to the JSON property humanReviewStatus
7214 7215 7216 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7214 def human_review_status @human_review_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7221 7222 7223 7224 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7221 def update!(**args) @document = args[:document] if args.key?(:document) @human_review_status = args[:human_review_status] if args.key?(:human_review_status) end |