Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Response message for the ProcessDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessResponse

Returns a new instance of GoogleCloudDocumentaiV1ProcessResponse.



7157
7158
7159
# File 'lib/google/apis/documentai_v1/classes.rb', line 7157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property document



7150
7151
7152
# File 'lib/google/apis/documentai_v1/classes.rb', line 7150

def document
  @document
end

#human_review_statusGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1HumanReviewStatus

The status of human review on a processed document. Corresponds to the JSON property humanReviewStatus



7155
7156
7157
# File 'lib/google/apis/documentai_v1/classes.rb', line 7155

def human_review_status
  @human_review_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7162
7163
7164
7165
# File 'lib/google/apis/documentai_v1/classes.rb', line 7162

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @human_review_status = args[:human_review_status] if args.key?(:human_review_status)
end