Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Processor
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Processor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.
Instance Attribute Summary collapse
-
#active_schema_version ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#default_processor_version ⇒ String
The default processor version.
-
#display_name ⇒ String
The display name of the processor.
-
#kms_key_name ⇒ String
The KMS key used for encryption and decryption in CMEK scenarios.
-
#name ⇒ String
Output only.
-
#process_endpoint ⇒ String
Output only.
-
#processor_version_aliases ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionAlias>
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
The processor type, such as:
OCR_PROCESSOR,INVOICE_PROCESSOR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1Processor
constructor
A new instance of GoogleCloudDocumentaiV1Processor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1Processor
Returns a new instance of GoogleCloudDocumentaiV1Processor.
7300 7301 7302 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_schema_version ⇒ String
Optional. SchemaVersion used by the Processor. It is the same as Processor's
DatasetSchema.schema_version Format is projects/project/locations/location
/schemas/schema/schemaVersions/schema_version
Corresponds to the JSON propertyactiveSchemaVersion`
7237 7238 7239 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7237 def active_schema_version @active_schema_version end |
#create_time ⇒ String
Output only. The time the processor was created.
Corresponds to the JSON property createTime
7242 7243 7244 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7242 def create_time @create_time end |
#default_processor_version ⇒ String
The default processor version.
Corresponds to the JSON property defaultProcessorVersion
7247 7248 7249 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7247 def default_processor_version @default_processor_version end |
#display_name ⇒ String
The display name of the processor.
Corresponds to the JSON property displayName
7252 7253 7254 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7252 def display_name @display_name end |
#kms_key_name ⇒ String
The KMS key used for
encryption and decryption in CMEK scenarios.
Corresponds to the JSON property kmsKeyName
7258 7259 7260 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7258 def kms_key_name @kms_key_name end |
#name ⇒ String
Output only. Immutable. The resource name of the processor. Format: projects/
project/locations/location/processors/processor`
Corresponds to the JSON propertyname`
7264 7265 7266 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7264 def name @name end |
#process_endpoint ⇒ String
Output only. Immutable. The http endpoint that can be called to invoke
processing.
Corresponds to the JSON property processEndpoint
7270 7271 7272 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7270 def process_endpoint @process_endpoint end |
#processor_version_aliases ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionAlias>
Output only. The processor version aliases.
Corresponds to the JSON property processorVersionAliases
7275 7276 7277 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7275 def processor_version_aliases @processor_version_aliases end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
7280 7281 7282 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7280 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
7286 7287 7288 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7286 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of the processor.
Corresponds to the JSON property state
7292 7293 7294 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7292 def state @state end |
#type ⇒ String
The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR. To get a
list of processor types, see FetchProcessorTypes.
Corresponds to the JSON property type
7298 7299 7300 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7298 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7305 7306 7307 7308 7309 7310 7311 7312 7313 7314 7315 7316 7317 7318 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7305 def update!(**args) @active_schema_version = args[:active_schema_version] if args.key?(:active_schema_version) @create_time = args[:create_time] if args.key?(:create_time) @default_processor_version = args[:default_processor_version] if args.key?(:default_processor_version) @display_name = args[:display_name] if args.key?(:display_name) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @name = args[:name] if args.key?(:name) @process_endpoint = args[:process_endpoint] if args.key?(:process_endpoint) @processor_version_aliases = args[:processor_version_aliases] if args.key?(:processor_version_aliases) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |