Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Processor
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Processor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.
Instance Attribute Summary collapse
-
#active_schema_version ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#default_processor_version ⇒ String
The default processor version.
-
#display_name ⇒ String
The display name of the processor.
-
#kms_key_name ⇒ String
The KMS key used for encryption and decryption in CMEK scenarios.
-
#name ⇒ String
Output only.
-
#process_endpoint ⇒ String
Output only.
-
#processor_version_aliases ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionAlias>
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
The processor type, such as:
OCR_PROCESSOR,INVOICE_PROCESSOR.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1Processor
constructor
A new instance of GoogleCloudDocumentaiV1Processor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1Processor
Returns a new instance of GoogleCloudDocumentaiV1Processor.
7241 7242 7243 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_schema_version ⇒ String
Optional. SchemaVersion used by the Processor. It is the same as Processor's
DatasetSchema.schema_version Format is projects/project/locations/location
/schemas/schema/schemaVersions/schema_version
Corresponds to the JSON propertyactiveSchemaVersion`
7178 7179 7180 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7178 def active_schema_version @active_schema_version end |
#create_time ⇒ String
Output only. The time the processor was created.
Corresponds to the JSON property createTime
7183 7184 7185 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7183 def create_time @create_time end |
#default_processor_version ⇒ String
The default processor version.
Corresponds to the JSON property defaultProcessorVersion
7188 7189 7190 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7188 def default_processor_version @default_processor_version end |
#display_name ⇒ String
The display name of the processor.
Corresponds to the JSON property displayName
7193 7194 7195 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7193 def display_name @display_name end |
#kms_key_name ⇒ String
The KMS key used for
encryption and decryption in CMEK scenarios.
Corresponds to the JSON property kmsKeyName
7199 7200 7201 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7199 def kms_key_name @kms_key_name end |
#name ⇒ String
Output only. Immutable. The resource name of the processor. Format: projects/
project/locations/location/processors/processor`
Corresponds to the JSON propertyname`
7205 7206 7207 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7205 def name @name end |
#process_endpoint ⇒ String
Output only. Immutable. The http endpoint that can be called to invoke
processing.
Corresponds to the JSON property processEndpoint
7211 7212 7213 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7211 def process_endpoint @process_endpoint end |
#processor_version_aliases ⇒ Array<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionAlias>
Output only. The processor version aliases.
Corresponds to the JSON property processorVersionAliases
7216 7217 7218 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7216 def processor_version_aliases @processor_version_aliases end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
7221 7222 7223 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7221 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
7227 7228 7229 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7227 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of the processor.
Corresponds to the JSON property state
7233 7234 7235 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7233 def state @state end |
#type ⇒ String
The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR. To get a
list of processor types, see FetchProcessorTypes.
Corresponds to the JSON property type
7239 7240 7241 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7239 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 7258 7259 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7246 def update!(**args) @active_schema_version = args[:active_schema_version] if args.key?(:active_schema_version) @create_time = args[:create_time] if args.key?(:create_time) @default_processor_version = args[:default_processor_version] if args.key?(:default_processor_version) @display_name = args[:display_name] if args.key?(:display_name) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @name = args[:name] if args.key?(:name) @process_endpoint = args[:process_endpoint] if args.key?(:process_endpoint) @processor_version_aliases = args[:processor_version_aliases] if args.key?(:processor_version_aliases) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |