Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersion
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
A processor version is an implementation of a processor. Each processor can have multiple versions, pretrained by Google internally or uptrained by the customer. A processor can only have one default version at a time. Its document-processing behavior is defined by that version.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deprecation_info ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo
Information about the upcoming deprecation of this processor version.
-
#display_name ⇒ String
The display name of the processor version.
-
#document_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
-
#gen_ai_model_info ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo
Information about Generative AI model-based processor versions.
-
#google_managed ⇒ Boolean
(also: #google_managed?)
Output only.
-
#kms_key_name ⇒ String
Output only.
-
#kms_key_version_name ⇒ String
Output only.
-
#latest_evaluation ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationReference
Gives a short summary of an evaluation, and links to the evaluation itself.
-
#model_type ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessorVersion
constructor
A new instance of GoogleCloudDocumentaiV1ProcessorVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessorVersion
Returns a new instance of GoogleCloudDocumentaiV1ProcessorVersion.
7423 7424 7425 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the processor version was created.
Corresponds to the JSON property createTime
7351 7352 7353 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7351 def create_time @create_time end |
#deprecation_info ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionDeprecationInfo
Information about the upcoming deprecation of this processor version.
Corresponds to the JSON property deprecationInfo
7356 7357 7358 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7356 def deprecation_info @deprecation_info end |
#display_name ⇒ String
The display name of the processor version.
Corresponds to the JSON property displayName
7361 7362 7363 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7361 def display_name @display_name end |
#document_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property documentSchema
7366 7367 7368 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7366 def document_schema @document_schema end |
#gen_ai_model_info ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo
Information about Generative AI model-based processor versions.
Corresponds to the JSON property genAiModelInfo
7371 7372 7373 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7371 def gen_ai_model_info @gen_ai_model_info end |
#google_managed ⇒ Boolean Also known as: google_managed?
Output only. Denotes that this ProcessorVersion is managed by Google.
Corresponds to the JSON property googleManaged
7376 7377 7378 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7376 def google_managed @google_managed end |
#kms_key_name ⇒ String
Output only. The KMS key name used for encryption.
Corresponds to the JSON property kmsKeyName
7382 7383 7384 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7382 def kms_key_name @kms_key_name end |
#kms_key_version_name ⇒ String
Output only. The KMS key version with which data is encrypted.
Corresponds to the JSON property kmsKeyVersionName
7387 7388 7389 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7387 def kms_key_version_name @kms_key_version_name end |
#latest_evaluation ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1EvaluationReference
Gives a short summary of an evaluation, and links to the evaluation itself.
Corresponds to the JSON property latestEvaluation
7392 7393 7394 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7392 def latest_evaluation @latest_evaluation end |
#model_type ⇒ String
Output only. The model type of this processor version.
Corresponds to the JSON property modelType
7397 7398 7399 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7397 def model_type @model_type end |
#name ⇒ String
Identifier. The resource name of the processor version. Format: projects/
project/locations/location/processors/processor/processorVersions/
processor_version`
Corresponds to the JSON propertyname`
7404 7405 7406 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7404 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
7409 7410 7411 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7409 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
7415 7416 7417 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7415 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of the processor version.
Corresponds to the JSON property state
7421 7422 7423 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7421 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7428 7429 7430 7431 7432 7433 7434 7435 7436 7437 7438 7439 7440 7441 7442 7443 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7428 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deprecation_info = args[:deprecation_info] if args.key?(:deprecation_info) @display_name = args[:display_name] if args.key?(:display_name) @document_schema = args[:document_schema] if args.key?(:document_schema) @gen_ai_model_info = args[:gen_ai_model_info] if args.key?(:gen_ai_model_info) @google_managed = args[:google_managed] if args.key?(:google_managed) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @kms_key_version_name = args[:kms_key_version_name] if args.key?(:kms_key_version_name) @latest_evaluation = args[:latest_evaluation] if args.key?(:latest_evaluation) @model_type = args[:model_type] if args.key?(:model_type) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) end |