Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Information about Generative AI model-based processor versions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfo.



7512
7513
7514
# File 'lib/google/apis/documentai_v1/classes.rb', line 7512

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_gen_ai_model_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoCustomGenAiModelInfo

Information for a custom Generative AI model created by the user. These are created with Create New Version in either the Call foundation model or Fine tuning tabs. Corresponds to the JSON property customGenAiModelInfo



7505
7506
7507
# File 'lib/google/apis/documentai_v1/classes.rb', line 7505

def custom_gen_ai_model_info
  @custom_gen_ai_model_info
end

#foundation_gen_ai_model_infoGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Information for a pretrained Google-managed foundation model. Corresponds to the JSON property foundationGenAiModelInfo



7510
7511
7512
# File 'lib/google/apis/documentai_v1/classes.rb', line 7510

def foundation_gen_ai_model_info
  @foundation_gen_ai_model_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7517
7518
7519
7520
# File 'lib/google/apis/documentai_v1/classes.rb', line 7517

def update!(**args)
  @custom_gen_ai_model_info = args[:custom_gen_ai_model_info] if args.key?(:custom_gen_ai_model_info)
  @foundation_gen_ai_model_info = args[:foundation_gen_ai_model_info] if args.key?(:foundation_gen_ai_model_info)
end