Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ReviewDocumentRequest
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ReviewDocumentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Request message for the ReviewDocument method.
Instance Attribute Summary collapse
-
#document_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
-
#enable_schema_validation ⇒ Boolean
(also: #enable_schema_validation?)
Whether the validation should be performed on the ad-hoc review request.
-
#inline_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document
Document represents the canonical document resource in Document AI.
-
#priority ⇒ String
The priority of the human review task.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ReviewDocumentRequest
constructor
A new instance of GoogleCloudDocumentaiV1ReviewDocumentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1ReviewDocumentRequest
Returns a new instance of GoogleCloudDocumentaiV1ReviewDocumentRequest.
7742 7743 7744 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7742 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property documentSchema
7721 7722 7723 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7721 def document_schema @document_schema end |
#enable_schema_validation ⇒ Boolean Also known as: enable_schema_validation?
Whether the validation should be performed on the ad-hoc review request.
Corresponds to the JSON property enableSchemaValidation
7726 7727 7728 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7726 def enable_schema_validation @enable_schema_validation end |
#inline_document ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document
Document represents the canonical document resource in Document AI. It is an
interchange format that provides insights into documents and allows for
collaboration between users and Document AI to iterate and optimize for
quality.
Corresponds to the JSON property inlineDocument
7735 7736 7737 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7735 def inline_document @inline_document end |
#priority ⇒ String
The priority of the human review task.
Corresponds to the JSON property priority
7740 7741 7742 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7740 def priority @priority end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7747 7748 7749 7750 7751 7752 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7747 def update!(**args) @document_schema = args[:document_schema] if args.key?(:document_schema) @enable_schema_validation = args[:enable_schema_validation] if args.key?(:enable_schema_validation) @inline_document = args[:inline_document] if args.key?(:inline_document) @priority = args[:priority] if args.key?(:priority) end |