Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1ReviewDocumentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Request message for the ReviewDocument method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1ReviewDocumentRequest

Returns a new instance of GoogleCloudDocumentaiV1ReviewDocumentRequest.



7683
7684
7685
# File 'lib/google/apis/documentai_v1/classes.rb', line 7683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_schemaGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema

The schema defines the output of the processed document by a processor. Corresponds to the JSON property documentSchema



7662
7663
7664
# File 'lib/google/apis/documentai_v1/classes.rb', line 7662

def document_schema
  @document_schema
end

#enable_schema_validationBoolean Also known as: enable_schema_validation?

Whether the validation should be performed on the ad-hoc review request. Corresponds to the JSON property enableSchemaValidation

Returns:

  • (Boolean)


7667
7668
7669
# File 'lib/google/apis/documentai_v1/classes.rb', line 7667

def enable_schema_validation
  @enable_schema_validation
end

#inline_documentGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1Document

Document represents the canonical document resource in Document AI. It is an interchange format that provides insights into documents and allows for collaboration between users and Document AI to iterate and optimize for quality. Corresponds to the JSON property inlineDocument



7676
7677
7678
# File 'lib/google/apis/documentai_v1/classes.rb', line 7676

def inline_document
  @inline_document
end

#priorityString

The priority of the human review task. Corresponds to the JSON property priority

Returns:

  • (String)


7681
7682
7683
# File 'lib/google/apis/documentai_v1/classes.rb', line 7681

def priority
  @priority
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7688
7689
7690
7691
7692
7693
# File 'lib/google/apis/documentai_v1/classes.rb', line 7688

def update!(**args)
  @document_schema = args[:document_schema] if args.key?(:document_schema)
  @enable_schema_validation = args[:enable_schema_validation] if args.key?(:enable_schema_validation)
  @inline_document = args[:inline_document] if args.key?(:inline_document)
  @priority = args[:priority] if args.key?(:priority)
end