Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaGenerationIteration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

A single iteration of the schema generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaGenerationIteration

Returns a new instance of GoogleCloudDocumentaiV1SchemaGenerationIteration.



7825
7826
7827
# File 'lib/google/apis/documentai_v1/classes.rb', line 7825

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjusted_schemaGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion

SchemaVersion is a version of the Schema which is created in SchemaGroup. Corresponds to the JSON property adjustedSchema



7813
7814
7815
# File 'lib/google/apis/documentai_v1/classes.rb', line 7813

def adjusted_schema
  @adjusted_schema
end

#generated_schemaGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion

SchemaVersion is a version of the Schema which is created in SchemaGroup. Corresponds to the JSON property generatedSchema



7818
7819
7820
# File 'lib/google/apis/documentai_v1/classes.rb', line 7818

def generated_schema
  @generated_schema
end

#promptString

Optional. The prompt used for the iteration. Corresponds to the JSON property prompt

Returns:

  • (String)


7823
7824
7825
# File 'lib/google/apis/documentai_v1/classes.rb', line 7823

def prompt
  @prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7830
7831
7832
7833
7834
# File 'lib/google/apis/documentai_v1/classes.rb', line 7830

def update!(**args)
  @adjusted_schema = args[:adjusted_schema] if args.key?(:adjusted_schema)
  @generated_schema = args[:generated_schema] if args.key?(:generated_schema)
  @prompt = args[:prompt] if args.key?(:prompt)
end