Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaGenerationIteration
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaGenerationIteration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
A single iteration of the schema generation.
Instance Attribute Summary collapse
-
#adjusted_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
-
#generated_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
-
#prompt ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaGenerationIteration
constructor
A new instance of GoogleCloudDocumentaiV1SchemaGenerationIteration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaGenerationIteration
Returns a new instance of GoogleCloudDocumentaiV1SchemaGenerationIteration.
7766 7767 7768 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adjusted_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Corresponds to the JSON property adjustedSchema
7754 7755 7756 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7754 def adjusted_schema @adjusted_schema end |
#generated_schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Corresponds to the JSON property generatedSchema
7759 7760 7761 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7759 def generated_schema @generated_schema end |
#prompt ⇒ String
Optional. The prompt used for the iteration.
Corresponds to the JSON property prompt
7764 7765 7766 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7764 def prompt @prompt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7771 7772 7773 7774 7775 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7771 def update!(**args) @adjusted_schema = args[:adjusted_schema] if args.key?(:adjusted_schema) @generated_schema = args[:generated_schema] if args.key?(:generated_schema) @prompt = args[:prompt] if args.key?(:prompt) end |