Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaVersion
constructor
A new instance of GoogleCloudDocumentaiV1SchemaVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaVersion
Returns a new instance of GoogleCloudDocumentaiV1SchemaVersion.
7867 7868 7869 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the SchemaVersion was created.
Corresponds to the JSON property createTime
7844 7845 7846 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7844 def create_time @create_time end |
#display_name ⇒ String
Required. The user-defined name of the SchemaVersion.
Corresponds to the JSON property displayName
7849 7850 7851 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7849 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. The gcp_name_short labels for the SchemaVersion.
Corresponds to the JSON property labels
7854 7855 7856 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7854 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the SchemaVersion. Format: projects/project
/locations/location/schemas/schema/schemaVersions/schema_version`
Corresponds to the JSON propertyname`
7860 7861 7862 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7860 def name @name end |
#schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property schema
7865 7866 7867 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7865 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7872 7873 7874 7875 7876 7877 7878 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7872 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) end |