Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1SchemaVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
SchemaVersion is a version of the Schema which is created in SchemaGroup.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaVersion
constructor
A new instance of GoogleCloudDocumentaiV1SchemaVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1SchemaVersion
Returns a new instance of GoogleCloudDocumentaiV1SchemaVersion.
7808 7809 7810 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7808 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the SchemaVersion was created.
Corresponds to the JSON property createTime
7785 7786 7787 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7785 def create_time @create_time end |
#display_name ⇒ String
Required. The user-defined name of the SchemaVersion.
Corresponds to the JSON property displayName
7790 7791 7792 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7790 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Optional. The GCP labels for the SchemaVersion.
Corresponds to the JSON property labels
7795 7796 7797 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7795 def labels @labels end |
#name ⇒ String
Identifier. The resource name of the SchemaVersion. Format: projects/project
/locations/location/schemas/schema/schemaVersions/schema_version`
Corresponds to the JSON propertyname`
7801 7802 7803 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7801 def name @name end |
#schema ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1DocumentSchema
The schema defines the output of the processed document by a processor.
Corresponds to the JSON property schema
7806 7807 7808 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7806 def schema @schema end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7813 7814 7815 7816 7817 7818 7819 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7813 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @schema = args[:schema] if args.key?(:schema) end |