Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The dataset validation information. This includes any and all errors with documents and the dataset.
Instance Attribute Summary collapse
-
#dataset_error_count ⇒ Fixnum
The total number of dataset errors.
-
#dataset_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information for the dataset as a whole.
-
#document_error_count ⇒ Fixnum
The total number of document errors.
-
#document_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information pertaining to specific documents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
constructor
A new instance of GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation
Returns a new instance of GoogleCloudDocumentaiV1TrainProcessorVersionMetadataDatasetValidation.
7995 7996 7997 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_error_count ⇒ Fixnum
The total number of dataset errors.
Corresponds to the JSON property datasetErrorCount
7975 7976 7977 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7975 def dataset_error_count @dataset_error_count end |
#dataset_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information for the dataset as a whole. A maximum of 10 dataset errors
will be returned. A single dataset error is terminal for training.
Corresponds to the JSON property datasetErrors
7981 7982 7983 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7981 def dataset_errors @dataset_errors end |
#document_error_count ⇒ Fixnum
The total number of document errors.
Corresponds to the JSON property documentErrorCount
7986 7987 7988 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7986 def document_error_count @document_error_count end |
#document_errors ⇒ Array<Google::Apis::DocumentaiV1::GoogleRpcStatus>
Error information pertaining to specific documents. A maximum of 10 document
errors will be returned. Any document with errors will not be used throughout
training.
Corresponds to the JSON property documentErrors
7993 7994 7995 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 7993 def document_errors @document_errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8000 8001 8002 8003 8004 8005 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8000 def update!(**args) @dataset_error_count = args[:dataset_error_count] if args.key?(:dataset_error_count) @dataset_errors = args[:dataset_errors] if args.key?(:dataset_errors) @document_error_count = args[:document_error_count] if args.key?(:document_error_count) @document_errors = args[:document_errors] if args.key?(:document_errors) end |