Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Options to control foundation model tuning of the processor.
Instance Attribute Summary collapse
-
#learning_rate_multiplier ⇒ Float
Optional.
-
#train_steps ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
constructor
A new instance of GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions
Returns a new instance of GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions.
8100 8101 8102 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#learning_rate_multiplier ⇒ Float
Optional. The multiplier to apply to the recommended learning rate. Valid
values are between 0.1 and 10. If not provided, recommended learning rate will
be used.
Corresponds to the JSON property learningRateMultiplier
8092 8093 8094 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8092 def learning_rate_multiplier @learning_rate_multiplier end |
#train_steps ⇒ Fixnum
Optional. The number of steps to run for model tuning. Valid values are
between 1 and 400. If not provided, recommended steps will be used.
Corresponds to the JSON property trainSteps
8098 8099 8100 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8098 def train_steps @train_steps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8105 8106 8107 8108 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8105 def update!(**args) @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier) @train_steps = args[:train_steps] if args.key?(:train_steps) end |