Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Options to control foundation model tuning of the processor.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions

Returns a new instance of GoogleCloudDocumentaiV1TrainProcessorVersionRequestFoundationModelTuningOptions.



8041
8042
8043
# File 'lib/google/apis/documentai_v1/classes.rb', line 8041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#learning_rate_multiplierFloat

Optional. The multiplier to apply to the recommended learning rate. Valid values are between 0.1 and 10. If not provided, recommended learning rate will be used. Corresponds to the JSON property learningRateMultiplier

Returns:

  • (Float)


8033
8034
8035
# File 'lib/google/apis/documentai_v1/classes.rb', line 8033

def learning_rate_multiplier
  @learning_rate_multiplier
end

#train_stepsFixnum

Optional. The number of steps to run for model tuning. Valid values are between 1 and 400. If not provided, recommended steps will be used. Corresponds to the JSON property trainSteps

Returns:

  • (Fixnum)


8039
8040
8041
# File 'lib/google/apis/documentai_v1/classes.rb', line 8039

def train_steps
  @train_steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8046
8047
8048
8049
# File 'lib/google/apis/documentai_v1/classes.rb', line 8046

def update!(**args)
  @learning_rate_multiplier = args[:learning_rate_multiplier] if args.key?(:learning_rate_multiplier)
  @train_steps = args[:train_steps] if args.key?(:train_steps)
end