Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

The status of each individual document in the batch delete process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus

Returns a new instance of GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus.



8282
8283
8284
# File 'lib/google/apis/documentai_v1/classes.rb', line 8282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_idGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentId

Document Identifier. Corresponds to the JSON property documentId



8270
8271
8272
# File 'lib/google/apis/documentai_v1/classes.rb', line 8270

def document_id
  @document_id
end

#statusGoogle::Apis::DocumentaiV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



8280
8281
8282
# File 'lib/google/apis/documentai_v1/classes.rb', line 8280

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8287
8288
8289
8290
# File 'lib/google/apis/documentai_v1/classes.rb', line 8287

def update!(**args)
  @document_id = args[:document_id] if args.key?(:document_id)
  @status = args[:status] if args.key?(:status)
end