Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The status of each individual document in the batch delete process.
Instance Attribute Summary collapse
-
#document_id ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentId
Document Identifier.
-
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus
constructor
A new instance of GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus
Returns a new instance of GoogleCloudDocumentaiV1beta3BatchDeleteDocumentsMetadataIndividualBatchDeleteStatus.
8223 8224 8225 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_id ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentId
Document Identifier.
Corresponds to the JSON property documentId
8211 8212 8213 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8211 def document_id @document_id end |
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
8221 8222 8223 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8221 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8228 8229 8230 8231 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8228 def update!(**args) @document_id = args[:document_id] if args.key?(:document_id) @status = args[:status] if args.key?(:status) end |