Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The status of a each individual document in the batch process.
Instance Attribute Summary collapse
-
#human_review_operation ⇒ String
The name of the operation triggered by the processed document.
-
#human_review_status ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3HumanReviewStatus
The status of human review on a processed document.
-
#input_gcs_source ⇒ String
The source of the document, same as the input_gcs_source field in the request when the batch process started.
-
#output_gcs_destination ⇒ String
The Cloud Storage output destination (in the request as DocumentOutputConfig. GcsOutputConfig.gcs_uri) of the processed document if it was successful, otherwise empty.
-
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus
constructor
A new instance of GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus
Returns a new instance of GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus.
8400 8401 8402 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#human_review_operation ⇒ String
The name of the operation triggered by the processed document. If the human
review process isn't triggered, this field will be empty. It has the same
response type and metadata as the long-running operation returned by the
ReviewDocument method.
Corresponds to the JSON property humanReviewOperation
8370 8371 8372 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8370 def human_review_operation @human_review_operation end |
#human_review_status ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3HumanReviewStatus
The status of human review on a processed document.
Corresponds to the JSON property humanReviewStatus
8375 8376 8377 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8375 def human_review_status @human_review_status end |
#input_gcs_source ⇒ String
The source of the document, same as the input_gcs_source field in the request
when the batch process started.
Corresponds to the JSON property inputGcsSource
8381 8382 8383 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8381 def input_gcs_source @input_gcs_source end |
#output_gcs_destination ⇒ String
The Cloud Storage output destination (in the request as DocumentOutputConfig.
GcsOutputConfig.gcs_uri) of the processed document if it was successful,
otherwise empty.
Corresponds to the JSON property outputGcsDestination
8388 8389 8390 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8388 def output_gcs_destination @output_gcs_destination end |
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
8398 8399 8400 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8398 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8405 8406 8407 8408 8409 8410 8411 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8405 def update!(**args) @human_review_operation = args[:human_review_operation] if args.key?(:human_review_operation) @human_review_status = args[:human_review_status] if args.key?(:human_review_status) @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source) @output_gcs_destination = args[:output_gcs_destination] if args.key?(:output_gcs_destination) @status = args[:status] if args.key?(:status) end |