Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

The status of a each individual document in the batch process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus

Returns a new instance of GoogleCloudDocumentaiV1beta3BatchProcessMetadataIndividualProcessStatus.



8390
8391
8392
# File 'lib/google/apis/documentai_v1/classes.rb', line 8390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#human_review_operationString

The name of the operation triggered by the processed document. If the human review process isn't triggered, this field will be empty. It has the same response type and metadata as the long-running operation returned by the ReviewDocument method. Corresponds to the JSON property humanReviewOperation

Returns:

  • (String)


8360
8361
8362
# File 'lib/google/apis/documentai_v1/classes.rb', line 8360

def human_review_operation
  @human_review_operation
end

#human_review_statusGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3HumanReviewStatus

The status of human review on a processed document. Corresponds to the JSON property humanReviewStatus



8365
8366
8367
# File 'lib/google/apis/documentai_v1/classes.rb', line 8365

def human_review_status
  @human_review_status
end

#input_gcs_sourceString

The source of the document, same as the input_gcs_source field in the request when the batch process started. Corresponds to the JSON property inputGcsSource

Returns:

  • (String)


8371
8372
8373
# File 'lib/google/apis/documentai_v1/classes.rb', line 8371

def input_gcs_source
  @input_gcs_source
end

#output_gcs_destinationString

The Cloud Storage output destination (in the request as DocumentOutputConfig. GcsOutputConfig.gcs_uri) of the processed document if it was successful, otherwise empty. Corresponds to the JSON property outputGcsDestination

Returns:

  • (String)


8378
8379
8380
# File 'lib/google/apis/documentai_v1/classes.rb', line 8378

def output_gcs_destination
  @output_gcs_destination
end

#statusGoogle::Apis::DocumentaiV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



8388
8389
8390
# File 'lib/google/apis/documentai_v1/classes.rb', line 8388

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8395
8396
8397
8398
8399
8400
8401
# File 'lib/google/apis/documentai_v1/classes.rb', line 8395

def update!(**args)
  @human_review_operation = args[:human_review_operation] if args.key?(:human_review_operation)
  @human_review_status = args[:human_review_status] if args.key?(:human_review_status)
  @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source)
  @output_gcs_destination = args[:output_gcs_destination] if args.key?(:output_gcs_destination)
  @status = args[:status] if args.key?(:status)
end