Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Defines properties that can be part of the entity type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty

Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty.



8931
8932
8933
# File 'lib/google/apis/documentai_v1/classes.rb', line 8931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

The description of the property. Could be used to provide more information about the property for model calls. Corresponds to the JSON property description

Returns:

  • (String)


8897
8898
8899
# File 'lib/google/apis/documentai_v1/classes.rb', line 8897

def description
  @description
end

#display_nameString

User defined name for the property. Corresponds to the JSON property displayName

Returns:

  • (String)


8902
8903
8904
# File 'lib/google/apis/documentai_v1/classes.rb', line 8902

def display_name
  @display_name
end

#method_propString

Specifies how the entity's value is obtained. Corresponds to the JSON property method

Returns:

  • (String)


8907
8908
8909
# File 'lib/google/apis/documentai_v1/classes.rb', line 8907

def method_prop
  @method_prop
end

#nameString

The name of the property. Follows the same guidelines as the EntityType name. Corresponds to the JSON property name

Returns:

  • (String)


8912
8913
8914
# File 'lib/google/apis/documentai_v1/classes.rb', line 8912

def name
  @name
end

#occurrence_typeString

Occurrence type limits the number of instances an entity type appears in the document. Corresponds to the JSON property occurrenceType

Returns:

  • (String)


8918
8919
8920
# File 'lib/google/apis/documentai_v1/classes.rb', line 8918

def occurrence_type
  @occurrence_type
end

#property_metadataGoogle::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3PropertyMetadata

Metadata about a property. Corresponds to the JSON property propertyMetadata



8923
8924
8925
# File 'lib/google/apis/documentai_v1/classes.rb', line 8923

def 
  @property_metadata
end

#value_typeString

A reference to the value type of the property. This type is subject to the same conventions as the Entity.base_types field. Corresponds to the JSON property valueType

Returns:

  • (String)


8929
8930
8931
# File 'lib/google/apis/documentai_v1/classes.rb', line 8929

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8936
8937
8938
8939
8940
8941
8942
8943
8944
# File 'lib/google/apis/documentai_v1/classes.rb', line 8936

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @method_prop = args[:method_prop] if args.key?(:method_prop)
  @name = args[:name] if args.key?(:name)
  @occurrence_type = args[:occurrence_type] if args.key?(:occurrence_type)
  @property_metadata = args[:property_metadata] if args.key?(:property_metadata)
  @value_type = args[:value_type] if args.key?(:value_type)
end