Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Defines properties that can be part of the entity type.
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the property.
-
#display_name ⇒ String
User defined name for the property.
-
#method_prop ⇒ String
Specifies how the entity's value is obtained.
-
#name ⇒ String
The name of the property.
-
#occurrence_type ⇒ String
Occurrence type limits the number of instances an entity type appears in the document.
-
#property_metadata ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3PropertyMetadata
Metadata about a property.
-
#value_type ⇒ String
A reference to the value type of the property.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaEntityTypeProperty.
8883 8884 8885 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The description of the property. Could be used to provide more information
about the property for model calls.
Corresponds to the JSON property description
8849 8850 8851 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8849 def description @description end |
#display_name ⇒ String
User defined name for the property.
Corresponds to the JSON property displayName
8854 8855 8856 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8854 def display_name @display_name end |
#method_prop ⇒ String
Specifies how the entity's value is obtained.
Corresponds to the JSON property method
8859 8860 8861 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8859 def method_prop @method_prop end |
#name ⇒ String
The name of the property. Follows the same guidelines as the EntityType name.
Corresponds to the JSON property name
8864 8865 8866 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8864 def name @name end |
#occurrence_type ⇒ String
Occurrence type limits the number of instances an entity type appears in the
document.
Corresponds to the JSON property occurrenceType
8870 8871 8872 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8870 def occurrence_type @occurrence_type end |
#property_metadata ⇒ Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3PropertyMetadata
Metadata about a property.
Corresponds to the JSON property propertyMetadata
8875 8876 8877 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8875 def @property_metadata end |
#value_type ⇒ String
A reference to the value type of the property. This type is subject to the
same conventions as the Entity.base_types field.
Corresponds to the JSON property valueType
8881 8882 8883 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8881 def value_type @value_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8888 8889 8890 8891 8892 8893 8894 8895 8896 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8888 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @method_prop = args[:method_prop] if args.key?(:method_prop) @name = args[:name] if args.key?(:name) @occurrence_type = args[:occurrence_type] if args.key?(:occurrence_type) @property_metadata = args[:property_metadata] if args.key?(:property_metadata) @value_type = args[:value_type] if args.key?(:value_type) end |