Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Metadata for global schema behavior.
Instance Attribute Summary collapse
-
#document_allow_multiple_labels ⇒ Boolean
(also: #document_allow_multiple_labels?)
If true, on a given page, there can be multiple
documentannotations covering it. -
#document_splitter ⇒ Boolean
(also: #document_splitter?)
If true, a
documententity type can be applied to subdocument (splitting). -
#prefixed_naming_on_properties ⇒ Boolean
(also: #prefixed_naming_on_properties?)
If set, all the nested entities must be prefixed with the parents.
-
#skip_naming_validation ⇒ Boolean
(also: #skip_naming_validation?)
If set, this will skip the naming format validation in the schema.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata.
8989 8990 8991 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_allow_multiple_labels ⇒ Boolean Also known as: document_allow_multiple_labels?
If true, on a given page, there can be multiple document annotations
covering it.
Corresponds to the JSON property documentAllowMultipleLabels
8965 8966 8967 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8965 def document_allow_multiple_labels @document_allow_multiple_labels end |
#document_splitter ⇒ Boolean Also known as: document_splitter?
If true, a document entity type can be applied to subdocument (splitting).
Otherwise, it can only be applied to the entire document (classification).
Corresponds to the JSON property documentSplitter
8972 8973 8974 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8972 def document_splitter @document_splitter end |
#prefixed_naming_on_properties ⇒ Boolean Also known as: prefixed_naming_on_properties?
If set, all the nested entities must be prefixed with the parents.
Corresponds to the JSON property prefixedNamingOnProperties
8978 8979 8980 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8978 def prefixed_naming_on_properties @prefixed_naming_on_properties end |
#skip_naming_validation ⇒ Boolean Also known as: skip_naming_validation?
If set, this will skip the naming format validation in the schema. So the
string values in DocumentSchema.EntityType.name and DocumentSchema.
EntityType.Property.name will not be checked.
Corresponds to the JSON property skipNamingValidation
8986 8987 8988 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8986 def skip_naming_validation @skip_naming_validation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8994 8995 8996 8997 8998 8999 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8994 def update!(**args) @document_allow_multiple_labels = args[:document_allow_multiple_labels] if args.key?(:document_allow_multiple_labels) @document_splitter = args[:document_splitter] if args.key?(:document_splitter) @prefixed_naming_on_properties = args[:prefixed_naming_on_properties] if args.key?(:prefixed_naming_on_properties) @skip_naming_validation = args[:skip_naming_validation] if args.key?(:skip_naming_validation) end |