Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Metadata for global schema behavior.
Instance Attribute Summary collapse
-
#document_allow_multiple_labels ⇒ Boolean
(also: #document_allow_multiple_labels?)
If true, on a given page, there can be multiple
documentannotations covering it. -
#document_splitter ⇒ Boolean
(also: #document_splitter?)
If true, a
documententity type can be applied to subdocument (splitting). -
#prefixed_naming_on_properties ⇒ Boolean
(also: #prefixed_naming_on_properties?)
If set, all the nested entities must be prefixed with the parents.
-
#skip_naming_validation ⇒ Boolean
(also: #skip_naming_validation?)
If set, we will skip the naming format validation in the schema.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
constructor
A new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata
Returns a new instance of GoogleCloudDocumentaiV1beta3DocumentSchemaMetadata.
8931 8932 8933 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_allow_multiple_labels ⇒ Boolean Also known as: document_allow_multiple_labels?
If true, on a given page, there can be multiple document annotations
covering it.
Corresponds to the JSON property documentAllowMultipleLabels
8907 8908 8909 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8907 def document_allow_multiple_labels @document_allow_multiple_labels end |
#document_splitter ⇒ Boolean Also known as: document_splitter?
If true, a document entity type can be applied to subdocument (splitting).
Otherwise, it can only be applied to the entire document (classification).
Corresponds to the JSON property documentSplitter
8914 8915 8916 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8914 def document_splitter @document_splitter end |
#prefixed_naming_on_properties ⇒ Boolean Also known as: prefixed_naming_on_properties?
If set, all the nested entities must be prefixed with the parents.
Corresponds to the JSON property prefixedNamingOnProperties
8920 8921 8922 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8920 def prefixed_naming_on_properties @prefixed_naming_on_properties end |
#skip_naming_validation ⇒ Boolean Also known as: skip_naming_validation?
If set, we will skip the naming format validation in the schema. So the string
values in DocumentSchema.EntityType.name and DocumentSchema.EntityType.
Property.name will not be checked.
Corresponds to the JSON property skipNamingValidation
8928 8929 8930 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8928 def skip_naming_validation @skip_naming_validation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8936 8937 8938 8939 8940 8941 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 8936 def update!(**args) @document_allow_multiple_labels = args[:document_allow_multiple_labels] if args.key?(:document_allow_multiple_labels) @document_splitter = args[:document_splitter] if args.key?(:document_splitter) @prefixed_naming_on_properties = args[:prefixed_naming_on_properties] if args.key?(:prefixed_naming_on_properties) @skip_naming_validation = args[:skip_naming_validation] if args.key?(:skip_naming_validation) end |