Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Evaluation metrics, either in aggregate or about a specific entity.
Instance Attribute Summary collapse
-
#f1_score ⇒ Float
The calculated F1 score.
-
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
-
#false_positives_count ⇒ Fixnum
The amount of false positives.
-
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
-
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
-
#precision ⇒ Float
The calculated precision.
-
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
-
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
-
#recall ⇒ Float
The calculated recall.
-
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
-
#true_positives_count ⇒ Fixnum
The amount of true positives.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMetrics
constructor
A new instance of GoogleCloudDocumentaiV1beta3EvaluationMetrics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMetrics
Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationMetrics.
9376 9377 9378 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#f1_score ⇒ Float
The calculated F1 score.
Corresponds to the JSON property f1Score
9324 9325 9326 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9324 def f1_score @f1_score end |
#false_negatives_count ⇒ Fixnum
The amount of false negatives.
Corresponds to the JSON property falseNegativesCount
9329 9330 9331 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9329 def false_negatives_count @false_negatives_count end |
#false_positives_count ⇒ Fixnum
The amount of false positives.
Corresponds to the JSON property falsePositivesCount
9334 9335 9336 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9334 def false_positives_count @false_positives_count end |
#ground_truth_document_count ⇒ Fixnum
The amount of documents with a ground truth occurrence.
Corresponds to the JSON property groundTruthDocumentCount
9339 9340 9341 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9339 def ground_truth_document_count @ground_truth_document_count end |
#ground_truth_occurrences_count ⇒ Fixnum
The amount of occurrences in ground truth documents.
Corresponds to the JSON property groundTruthOccurrencesCount
9344 9345 9346 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9344 def ground_truth_occurrences_count @ground_truth_occurrences_count end |
#precision ⇒ Float
The calculated precision.
Corresponds to the JSON property precision
9349 9350 9351 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9349 def precision @precision end |
#predicted_document_count ⇒ Fixnum
The amount of documents with a predicted occurrence.
Corresponds to the JSON property predictedDocumentCount
9354 9355 9356 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9354 def predicted_document_count @predicted_document_count end |
#predicted_occurrences_count ⇒ Fixnum
The amount of occurrences in predicted documents.
Corresponds to the JSON property predictedOccurrencesCount
9359 9360 9361 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9359 def predicted_occurrences_count @predicted_occurrences_count end |
#recall ⇒ Float
The calculated recall.
Corresponds to the JSON property recall
9364 9365 9366 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9364 def recall @recall end |
#total_documents_count ⇒ Fixnum
The amount of documents that had an occurrence of this label.
Corresponds to the JSON property totalDocumentsCount
9369 9370 9371 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9369 def total_documents_count @total_documents_count end |
#true_positives_count ⇒ Fixnum
The amount of true positives.
Corresponds to the JSON property truePositivesCount
9374 9375 9376 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9374 def true_positives_count @true_positives_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9381 9382 9383 9384 9385 9386 9387 9388 9389 9390 9391 9392 9393 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9381 def update!(**args) @f1_score = args[:f1_score] if args.key?(:f1_score) @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count) @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count) @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count) @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count) @precision = args[:precision] if args.key?(:precision) @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count) @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count) @recall = args[:recall] if args.key?(:recall) @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count) @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count) end |