Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Evaluation metrics, either in aggregate or about a specific entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMetrics

Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationMetrics.



9142
9143
9144
# File 'lib/google/apis/documentai_v1/classes.rb', line 9142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#f1_scoreFloat

The calculated F1 score. Corresponds to the JSON property f1Score

Returns:

  • (Float)


9090
9091
9092
# File 'lib/google/apis/documentai_v1/classes.rb', line 9090

def f1_score
  @f1_score
end

#false_negatives_countFixnum

The amount of false negatives. Corresponds to the JSON property falseNegativesCount

Returns:

  • (Fixnum)


9095
9096
9097
# File 'lib/google/apis/documentai_v1/classes.rb', line 9095

def false_negatives_count
  @false_negatives_count
end

#false_positives_countFixnum

The amount of false positives. Corresponds to the JSON property falsePositivesCount

Returns:

  • (Fixnum)


9100
9101
9102
# File 'lib/google/apis/documentai_v1/classes.rb', line 9100

def false_positives_count
  @false_positives_count
end

#ground_truth_document_countFixnum

The amount of documents with a ground truth occurrence. Corresponds to the JSON property groundTruthDocumentCount

Returns:

  • (Fixnum)


9105
9106
9107
# File 'lib/google/apis/documentai_v1/classes.rb', line 9105

def ground_truth_document_count
  @ground_truth_document_count
end

#ground_truth_occurrences_countFixnum

The amount of occurrences in ground truth documents. Corresponds to the JSON property groundTruthOccurrencesCount

Returns:

  • (Fixnum)


9110
9111
9112
# File 'lib/google/apis/documentai_v1/classes.rb', line 9110

def ground_truth_occurrences_count
  @ground_truth_occurrences_count
end

#precisionFloat

The calculated precision. Corresponds to the JSON property precision

Returns:

  • (Float)


9115
9116
9117
# File 'lib/google/apis/documentai_v1/classes.rb', line 9115

def precision
  @precision
end

#predicted_document_countFixnum

The amount of documents with a predicted occurrence. Corresponds to the JSON property predictedDocumentCount

Returns:

  • (Fixnum)


9120
9121
9122
# File 'lib/google/apis/documentai_v1/classes.rb', line 9120

def predicted_document_count
  @predicted_document_count
end

#predicted_occurrences_countFixnum

The amount of occurrences in predicted documents. Corresponds to the JSON property predictedOccurrencesCount

Returns:

  • (Fixnum)


9125
9126
9127
# File 'lib/google/apis/documentai_v1/classes.rb', line 9125

def predicted_occurrences_count
  @predicted_occurrences_count
end

#recallFloat

The calculated recall. Corresponds to the JSON property recall

Returns:

  • (Float)


9130
9131
9132
# File 'lib/google/apis/documentai_v1/classes.rb', line 9130

def recall
  @recall
end

#total_documents_countFixnum

The amount of documents that had an occurrence of this label. Corresponds to the JSON property totalDocumentsCount

Returns:

  • (Fixnum)


9135
9136
9137
# File 'lib/google/apis/documentai_v1/classes.rb', line 9135

def total_documents_count
  @total_documents_count
end

#true_positives_countFixnum

The amount of true positives. Corresponds to the JSON property truePositivesCount

Returns:

  • (Fixnum)


9140
9141
9142
# File 'lib/google/apis/documentai_v1/classes.rb', line 9140

def true_positives_count
  @true_positives_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9147
9148
9149
9150
9151
9152
9153
9154
9155
9156
9157
9158
9159
# File 'lib/google/apis/documentai_v1/classes.rb', line 9147

def update!(**args)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count)
  @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count)
  @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count)
  @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count)
  @precision = args[:precision] if args.key?(:precision)
  @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count)
  @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count)
  @recall = args[:recall] if args.key?(:recall)
  @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count)
  @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count)
end