Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3EvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Evaluation metrics, either in aggregate or about a specific entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3EvaluationMetrics

Returns a new instance of GoogleCloudDocumentaiV1beta3EvaluationMetrics.



9094
9095
9096
# File 'lib/google/apis/documentai_v1/classes.rb', line 9094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#f1_scoreFloat

The calculated f1 score. Corresponds to the JSON property f1Score

Returns:

  • (Float)


9042
9043
9044
# File 'lib/google/apis/documentai_v1/classes.rb', line 9042

def f1_score
  @f1_score
end

#false_negatives_countFixnum

The amount of false negatives. Corresponds to the JSON property falseNegativesCount

Returns:

  • (Fixnum)


9047
9048
9049
# File 'lib/google/apis/documentai_v1/classes.rb', line 9047

def false_negatives_count
  @false_negatives_count
end

#false_positives_countFixnum

The amount of false positives. Corresponds to the JSON property falsePositivesCount

Returns:

  • (Fixnum)


9052
9053
9054
# File 'lib/google/apis/documentai_v1/classes.rb', line 9052

def false_positives_count
  @false_positives_count
end

#ground_truth_document_countFixnum

The amount of documents with a ground truth occurrence. Corresponds to the JSON property groundTruthDocumentCount

Returns:

  • (Fixnum)


9057
9058
9059
# File 'lib/google/apis/documentai_v1/classes.rb', line 9057

def ground_truth_document_count
  @ground_truth_document_count
end

#ground_truth_occurrences_countFixnum

The amount of occurrences in ground truth documents. Corresponds to the JSON property groundTruthOccurrencesCount

Returns:

  • (Fixnum)


9062
9063
9064
# File 'lib/google/apis/documentai_v1/classes.rb', line 9062

def ground_truth_occurrences_count
  @ground_truth_occurrences_count
end

#precisionFloat

The calculated precision. Corresponds to the JSON property precision

Returns:

  • (Float)


9067
9068
9069
# File 'lib/google/apis/documentai_v1/classes.rb', line 9067

def precision
  @precision
end

#predicted_document_countFixnum

The amount of documents with a predicted occurrence. Corresponds to the JSON property predictedDocumentCount

Returns:

  • (Fixnum)


9072
9073
9074
# File 'lib/google/apis/documentai_v1/classes.rb', line 9072

def predicted_document_count
  @predicted_document_count
end

#predicted_occurrences_countFixnum

The amount of occurrences in predicted documents. Corresponds to the JSON property predictedOccurrencesCount

Returns:

  • (Fixnum)


9077
9078
9079
# File 'lib/google/apis/documentai_v1/classes.rb', line 9077

def predicted_occurrences_count
  @predicted_occurrences_count
end

#recallFloat

The calculated recall. Corresponds to the JSON property recall

Returns:

  • (Float)


9082
9083
9084
# File 'lib/google/apis/documentai_v1/classes.rb', line 9082

def recall
  @recall
end

#total_documents_countFixnum

The amount of documents that had an occurrence of this label. Corresponds to the JSON property totalDocumentsCount

Returns:

  • (Fixnum)


9087
9088
9089
# File 'lib/google/apis/documentai_v1/classes.rb', line 9087

def total_documents_count
  @total_documents_count
end

#true_positives_countFixnum

The amount of true positives. Corresponds to the JSON property truePositivesCount

Returns:

  • (Fixnum)


9092
9093
9094
# File 'lib/google/apis/documentai_v1/classes.rb', line 9092

def true_positives_count
  @true_positives_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9099
9100
9101
9102
9103
9104
9105
9106
9107
9108
9109
9110
9111
# File 'lib/google/apis/documentai_v1/classes.rb', line 9099

def update!(**args)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @false_negatives_count = args[:false_negatives_count] if args.key?(:false_negatives_count)
  @false_positives_count = args[:false_positives_count] if args.key?(:false_positives_count)
  @ground_truth_document_count = args[:ground_truth_document_count] if args.key?(:ground_truth_document_count)
  @ground_truth_occurrences_count = args[:ground_truth_occurrences_count] if args.key?(:ground_truth_occurrences_count)
  @precision = args[:precision] if args.key?(:precision)
  @predicted_document_count = args[:predicted_document_count] if args.key?(:predicted_document_count)
  @predicted_occurrences_count = args[:predicted_occurrences_count] if args.key?(:predicted_occurrences_count)
  @recall = args[:recall] if args.key?(:recall)
  @total_documents_count = args[:total_documents_count] if args.key?(:total_documents_count)
  @true_positives_count = args[:true_positives_count] if args.key?(:true_positives_count)
end