Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
The validation status of each import config. Status is set to an error if
there are no documents to import in the import_config, or OK if the
operation will try to proceed with at least one document.
Instance Attribute Summary collapse
-
#input_gcs_source ⇒ String
The source Cloud Storage URI specified in the import config.
-
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult
constructor
A new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult
Returns a new instance of GoogleCloudDocumentaiV1beta3ImportDocumentsMetadataImportConfigValidationResult.
9339 9340 9341 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_gcs_source ⇒ String
The source Cloud Storage URI specified in the import config.
Corresponds to the JSON property inputGcsSource
9327 9328 9329 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9327 def input_gcs_source @input_gcs_source end |
#status ⇒ Google::Apis::DocumentaiV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
9337 9338 9339 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9337 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9344 9345 9346 9347 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9344 def update!(**args) @input_gcs_source = args[:input_gcs_source] if args.key?(:input_gcs_source) @status = args[:status] if args.key?(:status) end |