Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3Processor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

The first-class citizen for Document AI. Each processor defines how to extract structural information from a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3Processor

Returns a new instance of GoogleCloudDocumentaiV1beta3Processor.



9500
9501
9502
# File 'lib/google/apis/documentai_v1/classes.rb', line 9500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_schema_versionString

Optional. SchemaVersion used by the Processor. It is the same as Processor's DatasetSchema.schema_version Format is projects/project/locations/location /schemas/schema/schemaVersions/schema_version Corresponds to the JSON propertyactiveSchemaVersion`

Returns:

  • (String)


9437
9438
9439
# File 'lib/google/apis/documentai_v1/classes.rb', line 9437

def active_schema_version
  @active_schema_version
end

#create_timeString

Output only. The time the processor was created. Corresponds to the JSON property createTime

Returns:

  • (String)


9442
9443
9444
# File 'lib/google/apis/documentai_v1/classes.rb', line 9442

def create_time
  @create_time
end

#default_processor_versionString

The default processor version. Corresponds to the JSON property defaultProcessorVersion

Returns:

  • (String)


9447
9448
9449
# File 'lib/google/apis/documentai_v1/classes.rb', line 9447

def default_processor_version
  @default_processor_version
end

#display_nameString

The display name of the processor. Corresponds to the JSON property displayName

Returns:

  • (String)


9452
9453
9454
# File 'lib/google/apis/documentai_v1/classes.rb', line 9452

def display_name
  @display_name
end

#kms_key_nameString

The KMS key used for encryption and decryption in CMEK scenarios. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


9458
9459
9460
# File 'lib/google/apis/documentai_v1/classes.rb', line 9458

def kms_key_name
  @kms_key_name
end

#nameString

Output only. Immutable. The resource name of the processor. Format: projects/ project/locations/location/processors/processor` Corresponds to the JSON propertyname`

Returns:

  • (String)


9464
9465
9466
# File 'lib/google/apis/documentai_v1/classes.rb', line 9464

def name
  @name
end

#process_endpointString

Output only. Immutable. The http endpoint that can be called to invoke processing. Corresponds to the JSON property processEndpoint

Returns:

  • (String)


9470
9471
9472
# File 'lib/google/apis/documentai_v1/classes.rb', line 9470

def process_endpoint
  @process_endpoint
end

#processor_version_aliasesArray<Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ProcessorVersionAlias>

Output only. The processor version aliases. Corresponds to the JSON property processorVersionAliases



9475
9476
9477
# File 'lib/google/apis/documentai_v1/classes.rb', line 9475

def processor_version_aliases
  @processor_version_aliases
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


9480
9481
9482
# File 'lib/google/apis/documentai_v1/classes.rb', line 9480

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


9486
9487
9488
# File 'lib/google/apis/documentai_v1/classes.rb', line 9486

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The state of the processor. Corresponds to the JSON property state

Returns:

  • (String)


9492
9493
9494
# File 'lib/google/apis/documentai_v1/classes.rb', line 9492

def state
  @state
end

#typeString

The processor type, such as: OCR_PROCESSOR, INVOICE_PROCESSOR. To get a list of processor types, see FetchProcessorTypes. Corresponds to the JSON property type

Returns:

  • (String)


9498
9499
9500
# File 'lib/google/apis/documentai_v1/classes.rb', line 9498

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9505
9506
9507
9508
9509
9510
9511
9512
9513
9514
9515
9516
9517
9518
# File 'lib/google/apis/documentai_v1/classes.rb', line 9505

def update!(**args)
  @active_schema_version = args[:active_schema_version] if args.key?(:active_schema_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @default_processor_version = args[:default_processor_version] if args.key?(:default_processor_version)
  @display_name = args[:display_name] if args.key?(:display_name)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @name = args[:name] if args.key?(:name)
  @process_endpoint = args[:process_endpoint] if args.key?(:process_endpoint)
  @processor_version_aliases = args[:processor_version_aliases] if args.key?(:processor_version_aliases)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end