Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Information for a pretrained Google-managed foundation model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo

Returns a new instance of GoogleCloudDocumentaiV1beta3ProcessorVersionGenAiModelInfoFoundationGenAiModelInfo.



9698
9699
9700
# File 'lib/google/apis/documentai_v1/classes.rb', line 9698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#finetuning_allowedBoolean Also known as: finetuning_allowed?

Whether finetuning is allowed for this base processor version. Corresponds to the JSON property finetuningAllowed

Returns:

  • (Boolean)


9689
9690
9691
# File 'lib/google/apis/documentai_v1/classes.rb', line 9689

def finetuning_allowed
  @finetuning_allowed
end

#min_train_labeled_documentsFixnum

The minimum number of labeled documents in the training dataset required for finetuning. Corresponds to the JSON property minTrainLabeledDocuments

Returns:

  • (Fixnum)


9696
9697
9698
# File 'lib/google/apis/documentai_v1/classes.rb', line 9696

def min_train_labeled_documents
  @min_train_labeled_documents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9703
9704
9705
9706
# File 'lib/google/apis/documentai_v1/classes.rb', line 9703

def update!(**args)
  @finetuning_allowed = args[:finetuning_allowed] if args.key?(:finetuning_allowed)
  @min_train_labeled_documents = args[:min_train_labeled_documents] if args.key?(:min_train_labeled_documents)
end