Class: Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ReviewDocumentResponse
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleCloudDocumentaiV1beta3ReviewDocumentResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Response message for the ReviewDocument method.
Instance Attribute Summary collapse
-
#gcs_destination ⇒ String
The Cloud Storage uri for the human reviewed document if the review is succeeded.
-
#rejection_reason ⇒ String
The reason why the review is rejected by reviewer.
-
#state ⇒ String
The state of the review operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentResponse
constructor
A new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDocumentaiV1beta3ReviewDocumentResponse
Returns a new instance of GoogleCloudDocumentaiV1beta3ReviewDocumentResponse.
9853 9854 9855 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_destination ⇒ String
The Cloud Storage uri for the human reviewed document if the review is
succeeded.
Corresponds to the JSON property gcsDestination
9841 9842 9843 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9841 def gcs_destination @gcs_destination end |
#rejection_reason ⇒ String
The reason why the review is rejected by reviewer.
Corresponds to the JSON property rejectionReason
9846 9847 9848 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9846 def rejection_reason @rejection_reason end |
#state ⇒ String
The state of the review operation.
Corresponds to the JSON property state
9851 9852 9853 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9851 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9858 9859 9860 9861 9862 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 9858 def update!(**args) @gcs_destination = args[:gcs_destination] if args.key?(:gcs_destination) @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason) @state = args[:state] if args.key?(:state) end |