Class: Google::Apis::DocumentaiV1::GoogleTypeDateTime
- Inherits:
-
Object
- Object
- Google::Apis::DocumentaiV1::GoogleTypeDateTime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb
Overview
Represents civil time (or occasionally physical time). This type can represent
a civil time in one of a few possible ways: * When utc_offset is set and
time_zone is unset: a civil time on a calendar day with a particular offset
from UTC. * When time_zone is set and utc_offset is unset: a civil time on a
calendar day in a particular time zone. * When neither time_zone nor
utc_offset is set: a civil time on a calendar day in local time. The date is
relative to the Proleptic Gregorian Calendar. If year, month, or day are 0,
the DateTime is considered not to have a specific year, month, or day
respectively. This type may also be used to represent a physical time if all
the date and time fields are set and either case of the time_offset oneof is
set. Consider using Timestamp message for physical time instead. If your use
case also would like to store the user's timezone, that can be done in another
field. This type is more flexible than some applications may want. Make sure
to document and validate your application's limitations.
Instance Attribute Summary collapse
-
#day ⇒ Fixnum
Optional.
-
#hours ⇒ Fixnum
Optional.
-
#minutes ⇒ Fixnum
Optional.
-
#month ⇒ Fixnum
Optional.
-
#nanos ⇒ Fixnum
Optional.
-
#seconds ⇒ Fixnum
Optional.
-
#time_zone ⇒ Google::Apis::DocumentaiV1::GoogleTypeTimeZone
Represents a time zone from the IANA Time Zone Database.
-
#utc_offset ⇒ String
UTC offset.
-
#year ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeDateTime
constructor
A new instance of GoogleTypeDateTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeDateTime
Returns a new instance of GoogleTypeDateTime.
10775 10776 10777 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10775 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ Fixnum
Optional. Day of month. Must be from 1 to 31 and valid for the year and month,
or 0 if specifying a datetime without a day.
Corresponds to the JSON property day
10725 10726 10727 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10725 def day @day end |
#hours ⇒ Fixnum
Optional. Hours of day in 24 hour format. Should be from 0 to 23, defaults to
0 (midnight). An API may choose to allow the value "24:00:00" for scenarios
like business closing time.
Corresponds to the JSON property hours
10732 10733 10734 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10732 def hours @hours end |
#minutes ⇒ Fixnum
Optional. Minutes of hour of day. Must be from 0 to 59, defaults to 0.
Corresponds to the JSON property minutes
10737 10738 10739 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10737 def minutes @minutes end |
#month ⇒ Fixnum
Optional. Month of year. Must be from 1 to 12, or 0 if specifying a datetime
without a month.
Corresponds to the JSON property month
10743 10744 10745 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10743 def month @month end |
#nanos ⇒ Fixnum
Optional. Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999,
defaults to 0.
Corresponds to the JSON property nanos
10749 10750 10751 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10749 def nanos @nanos end |
#seconds ⇒ Fixnum
Optional. Seconds of minutes of the time. Must normally be from 0 to 59,
defaults to 0. An API may allow the value 60 if it allows leap-seconds.
Corresponds to the JSON property seconds
10755 10756 10757 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10755 def seconds @seconds end |
#time_zone ⇒ Google::Apis::DocumentaiV1::GoogleTypeTimeZone
Represents a time zone from the IANA Time Zone Database.
Corresponds to the JSON property timeZone
10761 10762 10763 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10761 def time_zone @time_zone end |
#utc_offset ⇒ String
UTC offset. Must be whole seconds, between -18 hours and +18 hours. For
example, a UTC offset of -4:00 would be represented as seconds: -14400.
Corresponds to the JSON property utcOffset
10767 10768 10769 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10767 def utc_offset @utc_offset end |
#year ⇒ Fixnum
Optional. Year of date. Must be from 1 to 9999, or 0 if specifying a datetime
without a year.
Corresponds to the JSON property year
10773 10774 10775 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10773 def year @year end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10780 10781 10782 10783 10784 10785 10786 10787 10788 10789 10790 |
# File 'lib/google/apis/documentai_v1/classes.rb', line 10780 def update!(**args) @day = args[:day] if args.key?(:day) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @month = args[:month] if args.key?(:month) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) @time_zone = args[:time_zone] if args.key?(:time_zone) @utc_offset = args[:utc_offset] if args.key?(:utc_offset) @year = args[:year] if args.key?(:year) end |