Class: Google::Apis::DocumentaiV1::GoogleTypeDateTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/documentai_v1/classes.rb,
lib/google/apis/documentai_v1/representations.rb,
lib/google/apis/documentai_v1/representations.rb

Overview

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleTypeDateTime

Returns a new instance of GoogleTypeDateTime.



10493
10494
10495
# File 'lib/google/apis/documentai_v1/classes.rb', line 10493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayFixnum

Optional. Day of month. Must be from 1 to 31 and valid for the year and month, or 0 if specifying a datetime without a day. Corresponds to the JSON property day

Returns:

  • (Fixnum)


10443
10444
10445
# File 'lib/google/apis/documentai_v1/classes.rb', line 10443

def day
  @day
end

#hoursFixnum

Optional. Hours of day in 24 hour format. Should be from 0 to 23, defaults to 0 (midnight). An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


10450
10451
10452
# File 'lib/google/apis/documentai_v1/classes.rb', line 10450

def hours
  @hours
end

#minutesFixnum

Optional. Minutes of hour of day. Must be from 0 to 59, defaults to 0. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


10455
10456
10457
# File 'lib/google/apis/documentai_v1/classes.rb', line 10455

def minutes
  @minutes
end

#monthFixnum

Optional. Month of year. Must be from 1 to 12, or 0 if specifying a datetime without a month. Corresponds to the JSON property month

Returns:

  • (Fixnum)


10461
10462
10463
# File 'lib/google/apis/documentai_v1/classes.rb', line 10461

def month
  @month
end

#nanosFixnum

Optional. Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999, defaults to 0. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


10467
10468
10469
# File 'lib/google/apis/documentai_v1/classes.rb', line 10467

def nanos
  @nanos
end

#secondsFixnum

Optional. Seconds of minutes of the time. Must normally be from 0 to 59, defaults to 0. An API may allow the value 60 if it allows leap-seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


10473
10474
10475
# File 'lib/google/apis/documentai_v1/classes.rb', line 10473

def seconds
  @seconds
end

#time_zoneGoogle::Apis::DocumentaiV1::GoogleTypeTimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



10479
10480
10481
# File 'lib/google/apis/documentai_v1/classes.rb', line 10479

def time_zone
  @time_zone
end

#utc_offsetString

UTC offset. Must be whole seconds, between -18 hours and +18 hours. For example, a UTC offset of -4:00 would be represented as seconds: -14400. Corresponds to the JSON property utcOffset

Returns:

  • (String)


10485
10486
10487
# File 'lib/google/apis/documentai_v1/classes.rb', line 10485

def utc_offset
  @utc_offset
end

#yearFixnum

Optional. Year of date. Must be from 1 to 9999, or 0 if specifying a datetime without a year. Corresponds to the JSON property year

Returns:

  • (Fixnum)


10491
10492
10493
# File 'lib/google/apis/documentai_v1/classes.rb', line 10491

def year
  @year
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
# File 'lib/google/apis/documentai_v1/classes.rb', line 10498

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @month = args[:month] if args.key?(:month)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
  @year = args[:year] if args.key?(:year)
end